@@ -1,17 +1,3 @@
-# Copyright 2020 Google LLC. All Rights Reserved.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-#
 #  Copyright (c) ZenML GmbH 2022. All Rights Reserved.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
@@ -25,7 +11,7 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 #  or implied. See the License for the specific language governing
 #  permissions and limitations under the License.
-"""The `BaseArtifactStore` offers an interface for extending the ZenML artifact store."""
+"""The base interface to extend the ZenML artifact store."""
 import textwrap
 from abc import abstractmethod
 from typing import (
@@ -38,70 +24,167 @@ from typing import (
     Optional,
     Set,
     Tuple,
+    Type,
     Union,
+    cast,
 )
 
 from pydantic import root_validator
-from tfx.dsl.io.fileio import NotFoundError
 
 from zenml.enums import StackComponentType
 from zenml.exceptions import ArtifactStoreInterfaceError
-from zenml.stack import StackComponent
+from zenml.io import fileio
+from zenml.logger import get_logger
+from zenml.stack import Flavor, StackComponent, StackComponentConfig
+from zenml.utils import io_utils
+
+logger = get_logger(__name__)
 
 PathType = Union[bytes, str]
 
 
-def _catch_not_found_error(_func: Callable[..., Any]) -> Callable[..., Any]:
-    """Utility decorator used for catching a `FileNotFoundError`.
+def _sanitize_potential_path(potential_path: Any) -> Any:
+    """Sanitizes the input if it is a path.
 
-    Error is converted to a `NotFoundError` in order to deal with the TFX
-    exception handling.
+    If the input is a **remote** path, this function replaces backslash path
+    separators by forward slashes.
 
     Args:
-        _func: The function to decorate.
+        potential_path: Value that potentially refers to a (remote) path.
 
     Returns:
-        The decorated function.
+        The original input or a sanitized version of it in case of a remote
+        path.
+    """
+    if isinstance(potential_path, bytes):
+        path = fileio.convert_to_str(potential_path)
+    elif isinstance(potential_path, str):
+        path = potential_path
+    else:
+        # Neither string nor bytes, this is not a path
+        return potential_path
+
+    if io_utils.is_remote(path):
+        # If we have a remote path, replace windows path separators with
+        # slashes
+        import ntpath
+        import posixpath
+
+        path = path.replace(ntpath.sep, posixpath.sep)
+
+    return path
+
+
+def _sanitize_paths(_func: Callable[..., Any]) -> Callable[..., Any]:
+    """Sanitizes path inputs before calling the original function.
+
+    Args:
+        _func: The function for which to sanitize the inputs.
+
+    Returns:
+        Function that calls the input function with sanitized path inputs.
     """
 
     def inner_function(*args: Any, **kwargs: Any) -> Any:
-        """Inner function for the decorator.
-
-        It attempts to run the function
-        wrapped by the decorator and catches the FileNotFoundError if it is
-        thrown. In that case, the tfx.NotFoundError is raised instead.
+        """Inner function.
 
         Args:
-            *args: The positional arguments to pass to the function.
-            **kwargs: The keyword arguments to pass to the function.
+            *args: Positional args.
+            **kwargs: Keyword args.
 
         Returns:
-            The inner function.
-
-        Raises:
-            NotFoundError: If the function throws a FileNotFoundError.
+            Output of the input function called with sanitized paths.
         """
-        try:
-            return _func(*args, **kwargs)
-        except FileNotFoundError as e:
-            raise NotFoundError() from e
+        args = tuple(_sanitize_potential_path(arg) for arg in args)
+        kwargs = {
+            key: _sanitize_potential_path(value)
+            for key, value in kwargs.items()
+        }
+
+        return _func(*args, **kwargs)
 
     return inner_function
 
 
-class BaseArtifactStore(StackComponent):
-    """Base class for all ZenML artifact stores.
-
-    Attributes:
-        path: The root path of the artifact store.
-    """
+class BaseArtifactStoreConfig(StackComponentConfig):
+    """Config class for `BaseArtifactStore`."""
 
     path: str
 
-    # Class Configuration
-    TYPE: ClassVar[StackComponentType] = StackComponentType.ARTIFACT_STORE
     SUPPORTED_SCHEMES: ClassVar[Set[str]]
 
+    @root_validator(skip_on_failure=True)
+    def _ensure_artifact_store(cls, values: Dict[str, Any]) -> Any:
+        """Validator function for the Artifact Stores.
+
+        Checks whether supported schemes are defined and the given path is
+        supported.
+
+        Args:
+            values: The values to validate.
+
+        Returns:
+            The validated values.
+
+        Raises:
+            ArtifactStoreInterfaceError: If the scheme is not supported.
+        """
+        try:
+            getattr(cls, "SUPPORTED_SCHEMES")
+        except AttributeError:
+            raise ArtifactStoreInterfaceError(
+                textwrap.dedent(
+                    """
+                    When you are working with any classes which subclass from
+                    zenml.artifact_store.BaseArtifactStore please make sure
+                    that your class has a ClassVar named `SUPPORTED_SCHEMES`
+                    which should hold a set of supported file schemes such
+                    as {"s3://"} or {"gcs://"}.
+
+                    Example:
+
+                    class MyArtifactStoreConfig(BaseArtifactStoreConfig):
+                        ...
+                        # Class Variables
+                        SUPPORTED_SCHEMES: ClassVar[Set[str]] = {"s3://"}
+                        ...
+                    """
+                )
+            )
+        if not any(
+            values["path"].startswith(i) for i in cls.SUPPORTED_SCHEMES
+        ):
+            raise ArtifactStoreInterfaceError(
+                f"The path: '{values['path']}' you defined for your "
+                f"artifact store is not supported by the implementation of "
+                f"{cls.schema()['title']}, because it does not start with "
+                f"one of its supported schemes: {cls.SUPPORTED_SCHEMES}."
+            )
+
+        return values
+
+
+class BaseArtifactStore(StackComponent):
+    """Base class for all ZenML artifact stores."""
+
+    @property
+    def config(self) -> BaseArtifactStoreConfig:
+        """Returns the `BaseArtifactStoreConfig` config.
+
+        Returns:
+            The configuration.
+        """
+        return cast(BaseArtifactStoreConfig, self._config)
+
+    @property
+    def path(self) -> str:
+        """The path to the artifact store.
+
+        Returns:
+            The path.
+        """
+        return self.config.path
+
     # --- User interface ---
     @abstractmethod
     def open(self, name: PathType, mode: str = "r") -> Any:
@@ -226,6 +309,24 @@ class BaseArtifactStore(StackComponent):
             The stat descriptor.
         """
 
+    def size(self, path: PathType) -> Optional[int]:
+        """Get the size of a file in bytes.
+
+        Args:
+            path: The path to the file.
+
+        Returns:
+            The size of the file in bytes or `None` if the artifact store
+            does not implement the `size` method.
+        """
+        logger.warning(
+            "Cannot get size of file '%s' since the artifact store %s does not "
+            "implement the `size` method.",
+            path,
+            self.__class__.__name__,
+        )
+        return None
+
     @abstractmethod
     def walk(
         self,
@@ -255,89 +356,67 @@ class BaseArtifactStore(StackComponent):
         super(BaseArtifactStore, self).__init__(*args, **kwargs)
         self._register()
 
-    @root_validator(skip_on_failure=True)
-    def _ensure_artifact_store(cls, values: Dict[str, Any]) -> Any:
-        """Validator function for the Artifact Stores.
+    def _register(self) -> None:
+        """Create and register a filesystem within the filesystem registry."""
+        from zenml.io.filesystem import BaseFilesystem
+        from zenml.io.filesystem_registry import default_filesystem_registry
+        from zenml.io.local_filesystem import LocalFilesystem
 
-        Checks whether supported schemes are defined and the given path is
-        supported.
-
-        Args:
-            values: The values to validate.
-
-        Returns:
-            The validated values.
-
-        Raises:
-            ArtifactStoreInterfaceError: If the scheme is not supported.
-        """
-        try:
-            getattr(cls, "SUPPORTED_SCHEMES")
-        except AttributeError:
-            raise ArtifactStoreInterfaceError(
-                "When you are working with any classes which subclass from "
-                "'zenml.artifact_store.BaseArtifactStore' please make sure "
-                "that your class has a ClassVar named `SUPPORTED_SCHEMES` "
-                "which should hold a set of supported file schemes such "
-                "as {'s3://'} or {'gcs://'}. \n"
-                + textwrap.dedent(
-                    """
-                    When you are working with any classes which subclass from
-                    zenml.artifact_store.BaseArtifactStore please make sure
-                    that your class has a ClassVar named `SUPPORTED_SCHEMES`
-                    which should hold a set of supported file schemes such
-                    as {"s3://"} or {"gcs://"}.
-
-                    Example:
-
-                    class S3ArtifactStore(StackComponent):
-                        ...
-                        # Class Variables
-                        SUPPORTED_SCHEMES: ClassVar[Set[str]] = {"s3://"}
-                        ...
-                    """
-                )
-            )
-        if not any(values["path"].startswith(i) for i in cls.SUPPORTED_SCHEMES):
-            raise ArtifactStoreInterfaceError(
-                f"The path: '{values['path']}' you defined for your "
-                f"artifact store is not supported by the implementation of "
-                f"{cls.schema()['title']}, because it does not start with "
-                f"one of its supported schemes: {cls.SUPPORTED_SCHEMES}."
-            )
-
-        return values
-
-    def _register(self, priority: int = 5) -> None:
-        """Create and register a filesystem within the TFX registry.
-
-        Args:
-            priority: The priority of the filesystem.
-        """
-        from tfx.dsl.io.filesystem import Filesystem
-        from tfx.dsl.io.filesystem_registry import DEFAULT_FILESYSTEM_REGISTRY
+        # Local filesystem is always registered, no point in doing it again.
+        if isinstance(self, LocalFilesystem):
+            return
 
         filesystem_class = type(
             self.__class__.__name__,
-            (Filesystem,),
+            (BaseFilesystem,),
             {
-                "SUPPORTED_SCHEMES": self.SUPPORTED_SCHEMES,
-                "open": staticmethod(_catch_not_found_error(self.open)),
-                "copy": staticmethod(_catch_not_found_error(self.copyfile)),
-                "exists": staticmethod(self.exists),
-                "glob": staticmethod(self.glob),
-                "isdir": staticmethod(self.isdir),
-                "listdir": staticmethod(_catch_not_found_error(self.listdir)),
-                "makedirs": staticmethod(self.makedirs),
-                "mkdir": staticmethod(_catch_not_found_error(self.mkdir)),
-                "remove": staticmethod(_catch_not_found_error(self.remove)),
-                "rename": staticmethod(_catch_not_found_error(self.rename)),
-                "rmtree": staticmethod(_catch_not_found_error(self.rmtree)),
-                "stat": staticmethod(_catch_not_found_error(self.stat)),
-                "walk": staticmethod(_catch_not_found_error(self.walk)),
+                "SUPPORTED_SCHEMES": self.config.SUPPORTED_SCHEMES,
+                "open": staticmethod(_sanitize_paths(self.open)),
+                "copyfile": staticmethod(_sanitize_paths(self.copyfile)),
+                "exists": staticmethod(_sanitize_paths(self.exists)),
+                "glob": staticmethod(_sanitize_paths(self.glob)),
+                "isdir": staticmethod(_sanitize_paths(self.isdir)),
+                "listdir": staticmethod(_sanitize_paths(self.listdir)),
+                "makedirs": staticmethod(_sanitize_paths(self.makedirs)),
+                "mkdir": staticmethod(_sanitize_paths(self.mkdir)),
+                "remove": staticmethod(_sanitize_paths(self.remove)),
+                "rename": staticmethod(_sanitize_paths(self.rename)),
+                "rmtree": staticmethod(_sanitize_paths(self.rmtree)),
+                "size": staticmethod(_sanitize_paths(self.size)),
+                "stat": staticmethod(_sanitize_paths(self.stat)),
+                "walk": staticmethod(_sanitize_paths(self.walk)),
             },
         )
 
-        DEFAULT_FILESYSTEM_REGISTRY.register(
-            filesystem_class, priority=priority
-        )
+        default_filesystem_registry.register(filesystem_class)
+
+
+class BaseArtifactStoreFlavor(Flavor):
+    """Base class for artifact store flavors."""
+
+    @property
+    def type(self) -> StackComponentType:
+        """Returns the flavor type.
+
+        Returns:
+            The flavor type.
+        """
+        return StackComponentType.ARTIFACT_STORE
+
+    @property
+    def config_class(self) -> Type[StackComponentConfig]:
+        """Config class for this flavor.
+
+        Returns:
+            The config class.
+        """
+        return BaseArtifactStoreConfig
+
+    @property
+    @abstractmethod
+    def implementation_class(self) -> Type["BaseArtifactStore"]:
+        """Implementation class.
+
+        Returns:
+            The implementation class.
+        """
