@@ -78,8 +78,17 @@ You can also pass in a directory path manually using the
 
 ```bash
 zenml init --path /path/to/dir
+```
 
-If you wish to delete all data relating to your project from the
+If you wish to use one of [the available ZenML project templates](https://github.com/zenml-io/zenml-project-templates)
+to generate a ready-to-use project scaffold in your repository, you can do so by
+passing the ``--template`` option:
+
+```bash
+zenml init --template
+```
+
+If you wish to delete all data relating to your workspace from the
 directory, use the ``zenml clean`` command. This will:
 
 -  delete all pipelines and pipeline runs
@@ -188,6 +197,176 @@ Uninstalling a specific integration is as simple as typing:
 zenml integration uninstall INTEGRATION_NAME
 ```
 
+Secrets Management
+------------------
+
+ZenML offers a way to securely store secrets associated with your other
+stack components and infrastructure. A ZenML Secret is a collection or grouping
+of key-value pairs stored by the ZenML secrets store.
+ZenML Secrets are identified by a unique name which allows you to fetch or
+reference them in your pipelines and stacks.
+
+Depending on how you set up and deployed ZenML, the secrets store keeps secrets
+in the local database or uses the ZenML server your client is connected to:
+
+* if you are using the default ZenML client settings, or if you connect your
+ZenML client to a local ZenML server started with `zenml up`, the secrets store
+is using the same local SQLite database as the rest of ZenML
+* if you connect your ZenML client to a remote ZenML server, the
+secrets are no longer managed on your local machine, but through the remote
+server instead. Secrets are stored in whatever secrets store back-end the
+remote server is configured to use. This can be a SQL database, one of the
+managed cloud secrets management services, or even a custom back-end.
+
+To create a secret, use the `create` command and pass the key-value pairs
+as command-line arguments:
+
+```bash
+zenml secret create SECRET_NAME --key1=value1 --key2=value2 --key3=value3 ...
+```
+
+Note that when using the previous command the keys and values will be preserved in your `bash_history` file, so
+you may prefer to use the interactive `create` command instead:
+
+```shell
+zenml secret create SECRET_NAME -i
+```
+
+As an alternative to the interactive mode, also useful for values that
+are long or contain newline or special characters, you can also use the special
+`@` syntax to indicate to ZenML that the value needs to be read from a file:
+
+```bash
+zenml secret create SECRET_NAME \
+   --aws_access_key_id=1234567890 \
+   --aws_secret_access_key=abcdefghij \
+   --aws_session_token=@/path/to/token.txt
+```
+
+To list all the secrets available, use the `list` command:
+
+```bash
+zenml secret list
+```
+
+To get the key-value pairs for a particular secret, use the `get` command:
+
+```bash
+zenml secret get SECRET_NAME
+```
+
+To update a secret, use the `update` command:
+
+```bash
+zenml secret update SECRET_NAME --key1=value1 --key2=value2 --key3=value3 ...
+```
+
+Note that when using the previous command the keys and values will be preserved in your `bash_history` file, so
+you may prefer to use the interactive `update` command instead:
+
+```shell
+zenml secret update SECRET_NAME -i
+```
+
+Finally, to delete a secret, use the `delete` command:
+
+```bash
+zenml secret delete SECRET_NAME
+```
+
+Secrets can be scoped to a workspace or a user. By default, secrets
+are scoped to the current workspace. To scope a secret to a user, use the
+`--scope user` argument in the `register` command.
+
+Secrets Management with Secrets Managers
+----------------------------------------
+
+NOTE: this is a legacy feature that is being deprecated in favor of the
+centralized ZenML secrets store. Going forward, we recommend using centralized
+ZenML secrets instead of secrets manager stack components to configure and store
+secrets.
+
+Secrets can also be managed through the secrets manager stack component in your
+active stack. To set up a local file-based secrets manager, use the following
+CLI command:
+
+```bash
+zenml secrets-manager register SECRETS_MANAGER_NAME --flavor=local
+```
+
+This can then be used as part of your Stack (see below).
+
+When you use a secrets manager, ZenML secrets are managed through the secrets
+manager stack component in your active stack. This means that you can only
+use the CLI commands described here if the active stack contains a secrets
+manager. This is just one of the limitations of using secrets managers, as
+opposed to the centralized ZenML secrets store, and one of the reasons why we
+have deprecated them.
+
+Secret groupings come in different types, and certain types have predefined keys
+that should be used. For example, an AWS secret has predefined keys of
+`aws_access_key_id` and `aws_secret_access_key` (and an optional
+`aws_session_token`). If you do not have a specific secret type you wish to use,
+ZenML will use the `arbitrary` type to store your key-value pairs.
+
+To register a secret, use the `register` command and pass the key-value pairs
+as command line arguments:
+
+```bash
+zenml secrets-manager secret register SECRET_NAME --key1=value1 --key2=value2 --key3=value3 ...
+```
+
+Note that the keys and values will be preserved in your `bash_history` file, so
+you may prefer to use the interactive `register` command instead:
+
+```shell
+zenml secrets-manager secret register SECRET_NAME -i
+```
+
+As an alternative to the interactive mode, also useful for values that
+are long or contain newline or special characters, you can also use the special
+`@` syntax to indicate to ZenML that the value needs to be read from a file:
+
+```bash
+zenml secrets-manager secret register SECRET_NAME --schema=aws \
+   --aws_access_key_id=1234567890 \
+   --aws_secret_access_key=abcdefghij \
+   --aws_session_token=@/path/to/token.txt
+```
+
+
+To list all the secrets available, use the `list` command:
+
+```bash
+zenml secrets-manager secret list
+```
+
+To get the key-value pairs for a particular secret, use the `get` command:
+
+```bash
+zenml secrets-manager secret get SECRET_NAME
+```
+
+To update a secret, use the `update` command:
+
+```bash
+zenml secrets-manager secret update SECRET_NAME --key1=value1 --key2=value2 --key3=value3 ...
+```
+
+Note that the keys and values will be preserved in your `bash_history` file, so
+you may prefer to use the interactive `update` command instead:
+
+```shell
+zenml secrets-manager secret update SECRET_NAME -i
+```
+
+Finally, to delete a secret, use the `delete` command:
+
+```bash
+zenml secrets-manager secret delete SECRET_NAME
+```
+
+
 Customizing your Artifact Store
 -------------------------------
 
@@ -201,7 +380,7 @@ zenml artifact-store register ARTIFACT_STORE_NAME --flavor=ARTIFACT_STORE_FLAVOR
 ```
 
 If you wish to list the artifact stores that have already been
-registered within your ZenML project / repository, type:
+registered within your ZenML workspace / repository, type:
 
 ```bash
 zenml artifact-store list
@@ -232,7 +411,7 @@ zenml orchestrator register ORCHESTRATOR_NAME --flavor=ORCHESTRATOR_FLAVOR [--OR
 ```
 
 If you wish to list the orchestrators that have already been registered
-within your ZenML project / repository, type:
+within your ZenML workspace / repository, type:
 
 ```bash
 zenml orchestrator list
@@ -366,88 +545,6 @@ command:
 zenml step-operator delete STEP_OPERATOR_NAME
 ```
 
-Setting up a Secrets Manager
-----------------------------
-
-ZenML offers a way to securely store secrets associated with your project. To
-set up a local file-based secrets manager, use the following CLI command:
-
-```bash
-zenml secrets-manager register SECRETS_MANAGER_NAME --flavor=local
-```
-
-This can then be used as part of your Stack (see below).
-
-Using Secrets
--------------
-
-Secrets are administered by the Secrets Manager. You must first register that
-and then register a stack that includes the secrets manager before you can start
-to use it. To get a full list of all the possible commands, type `zenml secret
---help`. A ZenML Secret is a collection or grouping of key-value pairs. These
-Secret groupings come in different types, and certain types have predefined keys
-that should be used. For example, an AWS secret has predefined keys of
-`aws_access_key_id` and `aws_secret_access_key` (and an optional
-`aws_session_token`). If you do not have a specific secret type you wish to use,
-ZenML will use the `arbitrary` type to store your key-value pairs.
-
-To register a secret, use the `register` command and pass the key-value pairs
-as command line arguments:
-
-```bash
-zenml secrets-manager secret register SECRET_NAME --key1=value1 --key2=value2 --key3=value3 ...
-```
-
-Note that the keys and values will be preserved in your `bash_history` file, so
-you may prefer to use the interactive `register` command instead:
-
-```shell
-zenml secrets-manager secret register SECRET_NAME -i
-```
-
-As an alternative to the interactive mode, also useful for values that
-are long or contain newline or special characters, you can also use the special
-`@` syntax to indicate to ZenML that the value needs to be read from a file:
-
-```bash
-zenml secrets-manager secret register SECRET_NAME --schema=aws \
-   --aws_access_key_id=1234567890 \
-   --aws_secret_access_key=abcdefghij \
-   --aws_session_token=@/path/to/token.txt
-```
-
-
-To list all the secrets available, use the `list` command:
-
-```bash
-zenml secrets-manager secret list
-```
-
-To get the key-value pairs for a particular secret, use the `get` command:
-
-```bash
-zenml secrets-manager secret get SECRET_NAME
-```
-
-To update a secret, use the `update` command:
-
-```bash
-zenml secrets-manager secret update SECRET_NAME --key1=value1 --key2=value2 --key3=value3 ...
-```
-
-Note that the keys and values will be preserved in your `bash_history` file, so
-you may prefer to use the interactive `update` command instead:
-
-```shell
-zenml secrets-manager secret update SECRET_NAME -i
-```
-
-Finally, to delete a secret, use the `delete` command:
-
-```bash
-zenml secrets-manager secret delete SECRET_NAME
-```
-
 Add a Feature Store to your Stack
 ---------------------------------
 
@@ -477,14 +574,14 @@ zenml model-deployer register MODEL_DEPLOYER_NAME --flavor=MODEL_DEPLOYER_FLAVOR
 ```
 
 If you wish to list the model-deployers that have already been registered
-within your ZenML project / repository, type:
+within your ZenML workspace / repository, type:
 
 ```bash
 zenml model-deployer list
 ```
 
 If you wish to get more detailed information about a particular model deployer
-within your ZenML project / repository, type:
+within your ZenML workspace / repository, type:
 
 ```bash
 zenml model-deployer describe MODEL_DEPLOYER_NAME
@@ -595,7 +692,7 @@ zenml stack share STACK_NAME
 ```
 
 To list the stacks that you have registered within your current ZenML
-project, type:
+workspace, type:
 
 ```bash
 zenml stack list
@@ -715,8 +812,27 @@ Administering your Pipelines
 ZenML provides several CLI commands to help you administer your pipelines and
 pipeline runs.
 
-After you have run some pipelines by by executing the corresponding Python 
-scripts, you can list all pipelines via:
+To explicitly register a pipeline you need to point to a pipeline instance
+in your Python code. Let's say you have a Python file called `run.py` and
+it contains the following code:
+
+```python
+from zenml.pipelines import pipeline
+
+@pipeline
+def my_pipeline(...):
+   # Connect your pipeline steps here
+   pass
+
+pipeline_instance = my_pipeline(...)
+```
+
+You can register your pipeline like this:
+```bash
+zenml pipeline register run.pipeline_instance
+```
+
+To list all registered pipelines, use:
 
 ```bash
 zenml pipeline list
@@ -726,7 +842,7 @@ Since every pipeline run creates a new pipeline by default, you might
 occasionally want to delete a pipeline, which you can do via:
 
 ```bash
-zenml pipeline delete PIPELINE_NAME
+zenml pipeline delete <PIPELINE_NAME>
 ```
 
 This will delete the pipeline and change all corresponding pipeline runs to
@@ -738,21 +854,109 @@ To list all pipeline runs that you have executed, use:
 zenml pipeline runs list
 ```
 
-These are currently read-only and cannot be modified or deleted.
-
-If you would like to switch to a different ZenML deployment 
-(e.g., when switching from a local deployment to a cloud deployment), you can
-migrate your existing pipeline runs by exporting them to a YAML file via:
+To delete a pipeline run, use:
 
 ```bash
-zenml pipeline runs export FILENAME.yaml
+zenml pipeline runs delete <PIPELINE_RUN_NAME_OR_ID>
 ```
 
-This will create a FILENAME.yaml containing all your pipeline runs, which, after
-connecting to the new ZenML deployment, you can then import again like this:
+If you run any of your pipelines with `pipeline.run(schedule=...)`, ZenML keeps
+track of the schedule and you can list all schedules via:
 
 ```bash
-zenml pipeline runs import FILENAME.yaml
+zenml pipeline schedule list
+```
+
+To delete a schedule, use:
+
+```bash
+zenml pipeline schedule delete <SCHEDULE_NAME_OR_ID>
+```
+
+Note, however, that this will only delete the reference saved in ZenML and does
+NOT stop/delete the schedule in the respective orchestrator. This still needs to
+be done manually. For example, using the Airflow orchestrator you would have 
+to open the web UI to manually click to stop the schedule from executing.
+
+Each pipeline run automatically saves its artifacts in the artifact store. To
+list all artifacts that have been saved, use:
+
+```bash
+zenml artifact list
+```
+
+The metadata of an artifact can only be deleted if it is no longer linked to
+any pipeline runs, i.e., if the run that produced the artifact and all runs that
+cached any of its steps have been deleted.
+
+To delete all artifacts that are no longer linked to any pipeline runs, use:
+
+```bash
+zenml artifact prune
+```
+
+To delete a specific artifact, use:
+
+```bash
+zenml artifact delete <ARTIFACT_NAME_OR_ID>
+```
+
+Each pipeline run that requires Docker images also stores a build which
+contains the image names used for this run. To list all builds, use:
+
+```bash
+zenml pipeline builds list
+```
+
+To delete a specific build, use:
+
+```bash
+zenml pipeline builds delete <BUILD_ID>
+```
+
+Building an image without running your Pipelines
+----------------------------------
+
+To build Docker images for your pipeline without actually running the pipeline,
+use:
+
+```bash
+zenml pipeline build <PIPELINE_ID_OR_NAME>
+```
+
+To specify settings for the Docker builds, use the `--config/-c` option of the
+command. For more information about the structure of this configuration file,
+check out the `zenml.pipelines.base_pipeline.BasePipeline.build(...)` method.
+
+```bash
+zenml pipeline build <PIPELINE_ID_OR_NAME> --config=<PATH_TO_CONFIG_YAML>
+```
+
+If you want to build the pipeline for a stack different than your current active
+stack, use the `--stack` option.
+```bash
+zenml pipeline build <PIPELINE_ID_OR_NAME> --stack=<STACK_ID_OR_NAME>
+```
+
+
+To run a pipeline that was previously registered, use:
+
+```bash
+zenml pipeline run  <PIPELINE_ID_OR_NAME>
+```
+
+To specify settings for the pipeline, use the `--config/-c` option of the
+command. For more information about the structure of this configuration file,
+check out the `zenml.pipelines.base_pipeline.BasePipeline.run(...)` method.
+
+```bash
+zenml pipeline run <PIPELINE_ID_OR_NAME> --config=<PATH_TO_CONFIG_YAML>
+```
+
+If you want to run the pipeline on a stack different than your current active
+stack, use the `--stack` option.
+```bash
+zenml pipeline run <PIPELINE_ID_OR_NAME> --stack=<STACK_ID_OR_NAME>
 ```
 
 Managing the local ZenML Dashboard
@@ -927,7 +1131,7 @@ Example output:
 Running without an active repository root.
 Connected to a ZenML server: 'https://ac8ef63af203226194a7725ee71d85a-7635928635.us-east-1.elb.amazonaws.com'
 The current user is: 'default'
-The active project is: 'default' (global)
+The active workspace is: 'default' (global)
 The active stack is: 'default' (global)
 The status of the local dashboard:
               ZenML server 'local'              
@@ -973,11 +1177,11 @@ ssl_key: null
 ssl_verify_server_cert: false
 ```
 
-Managing users, teams, projects and roles
+Managing users, teams, workspaces and roles
 -----------------------------------------
 
 When using the ZenML service, you can manage permissions by managing users,
-teams, projects and roles using the CLI.
+teams, workspaces and roles using the CLI.
 If you want to create a new user or delete an existing one, run either
 
 ```bash
@@ -1161,14 +1365,16 @@ This deletes all the recipes from the default path where they were downloaded.
 """
 
 from zenml.cli.annotator import *  # noqa
+from zenml.cli.artifact import *  # noqa
 from zenml.cli.base import *  # noqa
 from zenml.cli.config import *  # noqa
 from zenml.cli.example import *  # noqa
 from zenml.cli.feature import *  # noqa
 from zenml.cli.integration import *  # noqa
+from zenml.cli.served_model import *  # noqa
 from zenml.cli.model import *  # noqa
 from zenml.cli.pipeline import *  # noqa
-from zenml.cli.project import *  # noqa
+from zenml.cli.workspace import *  # noqa
 from zenml.cli.role import *  # noqa
 from zenml.cli.secret import *  # noqa
 from zenml.cli.server import *  # noqa
