@@ -46,16 +46,21 @@ SHELL_EXECUTABLE = "SHELL_EXECUTABLE"
 class LocalExample:
     """Class to encapsulate the local example that can be run from the CLI."""
 
-    def __init__(self, path: Path, name: str) -> None:
+    def __init__(
+        self, path: Path, name: str, skip_manual_check: bool = False
+    ) -> None:
         """Create a new LocalExample instance.
 
         Args:
             name: The name of the example, specifically the name of the folder
                   on git
             path: Path at which the example is installed
+            skip_manual_check: Whether to skip checking whether the example
+                can be run manually or not.
         """
         self.name = name
         self.path = path
+        self.skip_manual_check = skip_manual_check
 
     @property
     def python_files_in_dir(self) -> List[str]:
@@ -134,7 +139,7 @@ class LocalExample:
             RuntimeError: If no runner script is present in the example.
             NotImplementedError: If the examples needs manual user setup.
         """
-        if self.needs_manual_user_setup:
+        if not self.skip_manual_check and self.needs_manual_user_setup:
             raise NotImplementedError(
                 "This example currently does not support being run from the "
                 "CLI as user specific setup is required. Consult the README.md "
@@ -164,6 +169,33 @@ class LocalExample:
         """
         return fileio.exists(str(self.path)) and fileio.isdir(str(self.path))
 
+    def run_example_directly(self, *args: str) -> None:
+        """Runs the example directly without going through setup/teardown.
+
+        Args:
+            *args: Arguments to pass to the example.
+
+        Raises:
+            RuntimeError: If running the example fails.
+        """
+        with event_handler(
+            event=AnalyticsEvent.RUN_EXAMPLE,
+            metadata={"example_name": self.name},
+        ):
+
+            call = [sys.executable, self.executable_python_example, *args]
+            try:
+                subprocess.check_call(
+                    call,
+                    cwd=str(self.path),
+                    shell=click._compat.WIN,
+                    env=os.environ.copy(),
+                )
+            except Exception as e:
+                raise RuntimeError(
+                    f"Failed to run example {self.name}."
+                ) from e
+
     def run_example(
         self,
         example_runner: List[str],
@@ -467,7 +499,9 @@ class GitExamplesHandler(object):
         Returns:
             Checks whether examples are on the same code version as ZenML.
         """
-        return zenml_version_installed == str(self.examples_repo.active_version)
+        return zenml_version_installed == str(
+            self.examples_repo.active_version
+        )
 
     def is_example(self, example_name: Optional[str] = None) -> bool:
         """Checks if the supplied example_name corresponds to an example.
@@ -485,7 +519,9 @@ class GitExamplesHandler(object):
 
         return False
 
-    def get_examples(self, example_name: Optional[str] = None) -> List[Example]:
+    def get_examples(
+        self, example_name: Optional[str] = None
+    ) -> List[Example]:
         """Method that allows you to get an example by name.
 
         If no example is supplied,  all examples are returned.
@@ -702,14 +738,6 @@ def info(git_examples_handler: GitExamplesHandler, example_name: str) -> None:
     help="Force the redownload of the examples folder to the ZenML config "
     "folder.",
 )
-@click.option(
-    "--force",
-    "-f",
-    "old_force",
-    is_flag=True,
-    help="DEPRECATED: Force the redownload of the examples folder to the ZenML "
-    "config folder. Use `-y/--yes` instead.",
-)
 @click.option(
     "--version",
     "-v",
@@ -737,7 +765,6 @@ def pull(
     git_examples_handler: GitExamplesHandler,
     example_name: str,
     force: bool,
-    old_force: bool,
     version: str,
     path: str,
     branch: Optional[str],
@@ -753,21 +780,12 @@ def pull(
         example_name: The name of the example.
         force: Force the redownload of the examples folder to the ZenML config
             folder.
-        old_force: DEPRECATED: Force the redownload of the examples folder to
-            the ZenML config folder.
         version: The version of ZenML to use for the force-redownloaded
             examples.
         path: The path at which you want to install the example(s).
         branch: The branch of the ZenML repo to use for the force-redownloaded
             examples.
     """
-    if old_force:
-        force = old_force
-        warning(
-            "The `--force` flag will soon be deprecated. Use `--yes` or "
-            "`-y` instead."
-        )
-
     branch = branch.strip() if branch else f"release/{version}"
     git_examples_handler.pull(branch=branch, force=force)
 
@@ -785,7 +803,9 @@ def pull(
                 event=AnalyticsEvent.PULL_EXAMPLE,
                 metadata={"example_name": example_.name},
             ):
-                destination_dir = os.path.join(os.getcwd(), path, example_.name)
+                destination_dir = os.path.join(
+                    os.getcwd(), path, example_.name
+                )
                 if LocalExample(
                     name=example_.name, path=Path(destination_dir)
                 ).is_present():
@@ -827,15 +847,6 @@ def pull(
     "example folder and force installs all necessary integration "
     "requirements.",
 )
-@click.option(
-    "--force",
-    "-f",
-    "old_force",
-    is_flag=True,
-    help="DEPRECATED: Force the run of the example. This deletes the .zen "
-    "folder from the example folder and force installs all necessary "
-    "integration requirements. Use `-y/--yes` instead.",
-)
 @click.option(
     "--shell-executable",
     "-x",
@@ -854,7 +865,6 @@ def run(
     example_name: str,
     path: str,
     force: bool,
-    old_force: bool,
     shell_executable: Optional[str],
 ) -> None:
     """Run the example at the specified relative path.
@@ -868,16 +878,9 @@ def run(
         example_name: The name of the example.
         path: The path at which you want to install the example(s).
         force: Force the run of the example.
-        old_force: DEPRECATED: Force the run of the example.
         shell_executable: Manually specify the path to the executable that
             runs .sh files.
     """
-    if old_force:
-        force = old_force
-        warning(
-            "The `--force` flag will soon be deprecated. Use `--yes` or "
-            "`-y` instead."
-        )
     check_for_version_mismatch(git_examples_handler)
 
     # TODO [ENG-272]: - create a post_run function inside individual setup.sh
