@@ -29,6 +29,7 @@ from zenml.config.global_config import GlobalConfiguration
 from zenml.console import console
 from zenml.constants import ENV_AUTO_OPEN_DASHBOARD, handle_bool_env_var
 from zenml.enums import ServerProviderType, StoreType
+from zenml.exceptions import IllegalOperationError
 from zenml.logger import get_logger
 from zenml.utils import yaml_utils
 from zenml.utils.analytics_utils import AnalyticsEvent, event_handler
@@ -149,7 +150,6 @@ def up(
         image: A custom Docker image to use for the server, when the
             `--docker` flag is set.
     """
-    # flake8: noqa: C901
     with event_handler(
         AnalyticsEvent.ZENML_SERVER_STARTED
     ) as analytics_handler:
@@ -196,7 +196,10 @@ def up(
             config_attrs["image"] = image
         if port is not None:
             config_attrs["port"] = port
-        if ip_address is not None and provider == ServerProviderType.DOCKER:
+        if ip_address is not None and provider in [
+            ServerProviderType.LOCAL,
+            ServerProviderType.DOCKER,
+        ]:
             config_attrs["ip_address"] = ip_address
 
         from zenml.zen_server.deploy.deployment import ServerDeploymentConfig
@@ -226,7 +229,6 @@ def up(
                 and gc.store.type == StoreType.REST
                 and not connect
             ):
-
                 try:
                     if gc.zen_store.is_local_store():
                         connect = True
@@ -484,14 +486,6 @@ def deploy(
         metadata = {
             "server_deployment": str(server.config.provider),
         }
-        from zenml.zen_server.deploy.terraform.terraform_zen_server import (
-            TerraformServerDeploymentConfig,
-        )
-
-        if isinstance(server.config, TerraformServerDeploymentConfig):
-            # TODO: maybe move the server ID into the ServerDeploymentConfig
-            #   class
-            metadata["server_id"] = str(server.config.server_id)
 
         analytics_handler.metadata = metadata
 
@@ -533,13 +527,6 @@ def destroy() -> None:
             "server_deployment": str(server.config.provider),
         }
 
-        from zenml.zen_server.deploy.terraform.terraform_zen_server import (
-            TerraformServerDeploymentConfig,
-        )
-
-        if isinstance(server.config, TerraformServerDeploymentConfig):
-            metadata["server_id"] = str(server.config.server_id)
-
         analytics_handler.metadata = metadata
 
         cli_utils.declare(
@@ -547,7 +534,9 @@ def destroy() -> None:
         )
 
 
-@cli.command("status", help="Show information about the current configuration.")
+@cli.command(
+    "status", help="Show information about the current configuration."
+)
 def status() -> None:
     """Show details about the current configuration."""
     gc = GlobalConfiguration()
@@ -556,18 +545,24 @@ def status() -> None:
     store_cfg = gc.store
 
     cli_utils.declare(f"Using configuration from: '{gc.config_directory}'")
+    cli_utils.declare(
+        f"Local store files are located at: '{gc.local_stores_path}'"
+    )
     if client.root:
         cli_utils.declare(f"Active repository root: {client.root}")
     if store_cfg is not None:
         if gc.uses_default_store():
             cli_utils.declare(f"Using the local database ('{store_cfg.url}')")
         else:
-            cli_utils.declare(f"Connected to a ZenML server: '{store_cfg.url}'")
+            cli_utils.declare(
+                f"Connected to a ZenML server: '{store_cfg.url}'"
+            )
 
     scope = "repository" if client.uses_local_configuration else "global"
     cli_utils.declare(f"The current user is: '{client.active_user.name}'")
     cli_utils.declare(
-        f"The active project is: '{client.active_project.name}' " f"({scope})"
+        f"The active workspace is: '{client.active_workspace.name}' "
+        f"({scope})"
     )
     cli_utils.declare(
         f"The active stack is: '{client.active_stack_model.name}' ({scope})"
@@ -589,7 +584,7 @@ def status() -> None:
 @cli.command(
     "connect",
     help=(
-        """Configure your client to connect to a remote ZenML server.
+        """Connect to a remote ZenML server.
 
     Examples:
 
@@ -662,8 +657,8 @@ def status() -> None:
     type=str,
 )
 @click.option(
-    "--project",
-    help="The project to use when connecting to the ZenML server.",
+    "--workspace",
+    help="The workspace to use when connecting to the ZenML server.",
     required=False,
     type=str,
 )
@@ -697,7 +692,7 @@ def connect(
     url: Optional[str] = None,
     username: Optional[str] = None,
     password: Optional[str] = None,
-    project: Optional[str] = None,
+    workspace: Optional[str] = None,
     no_verify_ssl: bool = False,
     ssl_ca_cert: Optional[str] = None,
     config: Optional[str] = None,
@@ -711,7 +706,7 @@ def connect(
             server.
         password: The password that is used to authenticate with the ZenML
             server.
-        project: The active project that is used to connect to the ZenML
+        workspace: The active workspace that is used to connect to the ZenML
             server.
         no_verify_ssl: Whether to verify the server's TLS certificate.
         ssl_ca_cert: A path to a CA bundle to use to verify the server's TLS
@@ -727,7 +722,6 @@ def connect(
     verify_ssl = ssl_ca_cert if ssl_ca_cert is not None else not no_verify_ssl
 
     if config:
-
         if os.path.isfile(config):
             store_dict = yaml_utils.read_yaml(config)
         else:
@@ -792,16 +786,24 @@ def connect(
     assert store_config_class is not None
 
     store_config = store_config_class.parse_obj(store_dict)
-    GlobalConfiguration().set_store(store_config)
+    try:
+        GlobalConfiguration().set_store(store_config)
+    except IllegalOperationError as e:
+        cli_utils.warning(
+            f"User '{username}' does not have sufficient permissions to "
+            f"to access the server at '{url}'. Please ask the server "
+            f"administrator to assign a role with permissions to your "
+            f"username: {str(e)}"
+        )
 
-    if project:
+    if workspace:
         try:
-            Client().set_active_project(project_name_or_id=project)
+            Client().set_active_workspace(workspace_name_or_id=workspace)
         except KeyError:
             cli_utils.warning(
-                f"The project {project} does not exist or is not accessible. "
-                f"Please set another project by running `zenml "
-                f"project set`."
+                f"The workspace {workspace} does not exist or is not accessible. "
+                f"Please set another workspace by running `zenml "
+                f"workspace set`."
             )
 
 
@@ -886,7 +888,9 @@ def logs(
 
     cli_utils.declare(f"Showing logs for server: {server_name}")
 
-    from zenml.zen_server.deploy.exceptions import ServerDeploymentNotFoundError
+    from zenml.zen_server.deploy.exceptions import (
+        ServerDeploymentNotFoundError,
+    )
 
     try:
         logs = deployer.get_server_logs(server_name, follow=follow, tail=tail)
