@@ -21,7 +21,12 @@ import click
 import zenml
 from zenml.cli import utils as cli_utils
 from zenml.cli.cli import TagGroup, cli
-from zenml.cli.utils import _component_display_name, print_stacks_table
+from zenml.cli.utils import (
+    _component_display_name,
+    list_options,
+    print_page_info,
+    print_stacks_table,
+)
 from zenml.client import Client
 from zenml.console import console
 from zenml.enums import CliCategories, StackComponentType
@@ -30,6 +35,7 @@ from zenml.exceptions import (
     ProvisioningError,
     StackExistsError,
 )
+from zenml.models import StackFilterModel
 from zenml.utils.analytics_utils import AnalyticsEvent, track
 from zenml.utils.yaml_utils import read_yaml, write_yaml
 
@@ -74,6 +80,14 @@ def stack() -> None:
     type=str,
     required=False,
 )
+@click.option(
+    "-r",
+    "--model_registry",
+    "model_registry",
+    help="Name of the model registry for this stack.",
+    type=str,
+    required=False,
+)
 @click.option(
     "-x",
     "--secrets_manager",
@@ -138,6 +152,14 @@ def stack() -> None:
     type=str,
     required=False,
 )
+@click.option(
+    "-i",
+    "--image_builder",
+    "image_builder",
+    help="Name of the image builder for this stack.",
+    type=str,
+    required=False,
+)
 @click.option(
     "--set",
     "set_stack",
@@ -157,6 +179,7 @@ def register_stack(
     artifact_store: str,
     orchestrator: str,
     container_registry: Optional[str] = None,
+    model_registry: Optional[str] = None,
     secrets_manager: Optional[str] = None,
     step_operator: Optional[str] = None,
     feature_store: Optional[str] = None,
@@ -165,6 +188,7 @@ def register_stack(
     alerter: Optional[str] = None,
     annotator: Optional[str] = None,
     data_validator: Optional[str] = None,
+    image_builder: Optional[str] = None,
     set_stack: bool = False,
     share: bool = False,
 ) -> None:
@@ -175,6 +199,7 @@ def register_stack(
         artifact_store: Name of the artifact store for this stack.
         orchestrator: Name of the orchestrator for this stack.
         container_registry: Name of the container registry for this stack.
+        model_registry: Name of the model registry for this stack.
         secrets_manager: Name of the secrets manager for this stack.
         step_operator: Name of the step operator for this stack.
         feature_store: Name of the feature store for this stack.
@@ -183,6 +208,7 @@ def register_stack(
         alerter: Name of the alerter for this stack.
         annotator: Name of the annotator for this stack.
         data_validator: Name of the data validator for this stack.
+        image_builder: Name of the new image builder for this stack.
         set_stack: Immediately set this stack as active.
         share: Share the stack with other users.
     """
@@ -202,8 +228,12 @@ def register_stack(
             components[StackComponentType.DATA_VALIDATOR] = data_validator
         if feature_store:
             components[StackComponentType.FEATURE_STORE] = feature_store
+        if image_builder:
+            components[StackComponentType.IMAGE_BUILDER] = image_builder
         if model_deployer:
             components[StackComponentType.MODEL_DEPLOYER] = model_deployer
+        if model_registry:
+            components[StackComponentType.MODEL_REGISTRY] = model_registry
         if secrets_manager:
             components[StackComponentType.SECRETS_MANAGER] = secrets_manager
         if step_operator:
@@ -221,11 +251,14 @@ def register_stack(
         if share is None:
             share = False
 
-        created_stack = client.create_stack(
-            name=stack_name,
-            components=components,
-            is_shared=share,
-        )
+        try:
+            created_stack = client.create_stack(
+                name=stack_name,
+                components=components,
+                is_shared=share,
+            )
+        except (KeyError, IllegalOperationError) as err:
+            cli_utils.error(str(err))
 
         cli_utils.declare(
             f"Stack '{created_stack.name}' successfully registered!"
@@ -235,7 +268,9 @@ def register_stack(
         client.activate_stack(created_stack.id)
 
         scope = "repository" if client.uses_local_configuration else "global"
-        cli_utils.declare(f"Active {scope} stack set to:'{created_stack.name}'")
+        cli_utils.declare(
+            f"Active {scope} stack set to:'{created_stack.name}'"
+        )
 
 
 @stack.command(
@@ -268,6 +303,14 @@ def register_stack(
     type=str,
     required=False,
 )
+@click.option(
+    "-r",
+    "--model_registry",
+    "model_registry",
+    help="Name of the model registry for this stack.",
+    type=str,
+    required=False,
+)
 @click.option(
     "-s",
     "--step_operator",
@@ -332,6 +375,14 @@ def register_stack(
     type=str,
     required=False,
 )
+@click.option(
+    "-i",
+    "--image_builder",
+    "image_builder",
+    help="Name of the image builder for this stack.",
+    type=str,
+    required=False,
+)
 def update_stack(
     stack_name_or_id: Optional[str] = None,
     artifact_store: Optional[str] = None,
@@ -345,6 +396,8 @@ def update_stack(
     alerter: Optional[str] = None,
     annotator: Optional[str] = None,
     data_validator: Optional[str] = None,
+    image_builder: Optional[str] = None,
+    model_registry: Optional[str] = None,
 ) -> None:
     """Update a stack.
 
@@ -362,6 +415,8 @@ def update_stack(
         alerter: Name of the new alerter for this stack.
         annotator: Name of the new annotator for this stack.
         data_validator: Name of the new data validator for this stack.
+        image_builder: Name of the new image builder for this stack.
+        model_registry: Name of the new model registry for this stack.
     """
     client = Client()
 
@@ -386,6 +441,10 @@ def update_stack(
             ]
         if feature_store:
             updates[StackComponentType.FEATURE_STORE] = [feature_store]
+        if model_registry:
+            updates[StackComponentType.MODEL_REGISTRY] = [model_registry]
+        if image_builder:
+            updates[StackComponentType.IMAGE_BUILDER] = [image_builder]
         if model_deployer:
             updates[StackComponentType.MODEL_DEPLOYER] = [model_deployer]
         if orchestrator:
@@ -401,10 +460,12 @@ def update_stack(
                 component_updates=updates,
             )
 
-        except IllegalOperationError as err:
+        except (KeyError, IllegalOperationError) as err:
             cli_utils.error(str(err))
 
-        cli_utils.declare(f"Stack `{updated_stack.name}` successfully updated!")
+        cli_utils.declare(
+            f"Stack `{updated_stack.name}` successfully updated!"
+        )
 
 
 @stack.command(
@@ -448,7 +509,7 @@ def share_stack(
                 name_id_or_prefix=stack_name_or_id,
                 is_shared=True,
             )
-        except (IllegalOperationError, StackExistsError) as err:
+        except (KeyError, IllegalOperationError, StackExistsError) as err:
             cli_utils.error(str(err))
         cli_utils.declare(f"Stack `{updated_stack.name}` successfully shared!")
 
@@ -475,6 +536,14 @@ def share_stack(
     is_flag=True,
     required=False,
 )
+@click.option(
+    "-r",
+    "--model_registry",
+    "model_registry_flag",
+    help="Include this to remove the the model registry from this stack.",
+    is_flag=True,
+    required=False,
+)
 @click.option(
     "-x",
     "--secrets_manager",
@@ -531,6 +600,14 @@ def share_stack(
     is_flag=True,
     required=False,
 )
+@click.option(
+    "-i",
+    "--image_builder",
+    "image_builder_flag",
+    help="Include this to remove the image builder from this stack.",
+    is_flag=True,
+    required=False,
+)
 def remove_stack_component(
     stack_name_or_id: Optional[str] = None,
     container_registry_flag: Optional[bool] = False,
@@ -542,6 +619,8 @@ def remove_stack_component(
     alerter_flag: Optional[bool] = False,
     annotator_flag: Optional[bool] = False,
     data_validator_flag: Optional[bool] = False,
+    image_builder_flag: Optional[bool] = False,
+    model_registry_flag: Optional[str] = None,
 ) -> None:
     """Remove stack components from a stack.
 
@@ -558,6 +637,8 @@ def remove_stack_component(
         alerter_flag: To remove the alerter from this stack.
         annotator_flag: To remove the annotator from this stack.
         data_validator_flag: To remove the data validator from this stack.
+        image_builder_flag: To remove the image builder from this stack.
+        model_registry_flag: To remove the model registry from this stack.
     """
     client = Client()
 
@@ -585,20 +666,28 @@ def remove_stack_component(
         if alerter_flag:
             stack_component_update[StackComponentType.ALERTER] = []
 
+        if model_registry_flag:
+            stack_component_update[StackComponentType.MODEL_REGISTRY] = []
+
         if annotator_flag:
             stack_component_update[StackComponentType.ANNOTATOR] = []
 
         if data_validator_flag:
             stack_component_update[StackComponentType.DATA_VALIDATOR] = []
 
+        if image_builder_flag:
+            stack_component_update[StackComponentType.IMAGE_BUILDER] = []
+
         try:
             updated_stack = client.update_stack(
                 name_id_or_prefix=stack_name_or_id,
                 component_updates=stack_component_update,
             )
-        except IllegalOperationError as err:
+        except (KeyError, IllegalOperationError) as err:
             cli_utils.error(str(err))
-        cli_utils.declare(f"Stack `{updated_stack.name}` successfully updated!")
+        cli_utils.declare(
+            f"Stack `{updated_stack.name}` successfully updated!"
+        )
 
 
 @stack.command("rename", help="Rename a stack.")
@@ -631,21 +720,22 @@ def rename_stack(
 
 
 @stack.command("list")
-@click.option("--just-mine", "-m", is_flag=True, required=False)
-def list_stacks(just_mine: bool = False) -> None:
-    """List all available stacks.
+@list_options(StackFilterModel)
+def list_stacks(**kwargs: Any) -> None:
+    """List all stacks that fulfill the filter requirements.
 
     Args:
-        just_mine: To list only the stacks that the current user has created.
+        kwargs: Keyword arguments to filter the stacks.
     """
     client = Client()
     with console.status("Listing stacks...\n"):
-        if just_mine:
-            stacks = client.list_stacks(user_name_or_id=client.active_user.id)
-        else:
-            stacks = client.list_stacks()
+        stacks = client.list_stacks(**kwargs)
+        if not stacks:
+            cli_utils.declare("No stacks found for the given filters.")
+            return
 
-        print_stacks_table(client, stacks)
+        print_stacks_table(client, stacks.items)
+        print_page_info(stacks)
 
 
 @stack.command(
@@ -666,7 +756,10 @@ def describe_stack(stack_name_or_id: Optional[str] = None) -> None:
     client = Client()
 
     with console.status("Describing stack...\n"):
-        stack_ = client.get_stack(name_id_or_prefix=stack_name_or_id)
+        try:
+            stack_ = client.get_stack(name_id_or_prefix=stack_name_or_id)
+        except KeyError as err:
+            cli_utils.error(str(err))
 
         cli_utils.print_stack_configuration(
             stack=stack_,
@@ -717,7 +810,11 @@ def set_active_stack_command(stack_name_or_id: str) -> None:
     with console.status(
         f"Setting the {scope} active stack to '{stack_name_or_id}'..."
     ):
-        client.activate_stack(stack_name_id_or_prefix=stack_name_or_id)
+        try:
+            client.activate_stack(stack_name_id_or_prefix=stack_name_or_id)
+        except KeyError as err:
+            cli_utils.error(str(err))
+
         cli_utils.declare(
             f"Active {scope} stack set to: "
             f"'{client.active_stack_model.name}'"
@@ -731,9 +828,12 @@ def get_active_stack() -> None:
 
     with console.status("Getting the active stack..."):
         client = Client()
-        cli_utils.declare(
-            f"The {scope} active stack is: '{client.active_stack_model.name}'"
-        )
+        try:
+            cli_utils.declare(
+                f"The {scope} active stack is: '{client.active_stack_model.name}'"
+            )
+        except KeyError as err:
+            cli_utils.error(str(err))
 
 
 @stack.command("up")
@@ -797,8 +897,10 @@ def export_stack(
     """
     # Get configuration of given stack
     client = Client()
-
-    stack_to_export = client.get_stack(name_id_or_prefix=stack_name_or_id)
+    try:
+        stack_to_export = client.get_stack(name_id_or_prefix=stack_name_or_id)
+    except KeyError as err:
+        cli_utils.error(str(err))
 
     # write zenml version and stack dict to YAML
     yaml_data = stack_to_export.to_yaml()
@@ -897,7 +999,9 @@ def import_stack(
         if filename is None:
             filename = stack_name + ".yaml"
         data = read_yaml(filename)
-        cli_utils.declare(f"Using '{filename}' to import '{stack_name}' stack.")
+        cli_utils.declare(
+            f"Using '{filename}' to import '{stack_name}' stack."
+        )
 
     # assert zenml version is the same if force is false
     if data["zenml_version"] != zenml.__version__:
@@ -968,9 +1072,12 @@ def copy_stack(
     client = Client()
 
     with console.status(f"Copying stack `{source_stack_name_or_id}`...\n"):
-        stack_to_copy = client.get_stack(
-            name_id_or_prefix=source_stack_name_or_id
-        )
+        try:
+            stack_to_copy = client.get_stack(
+                name_id_or_prefix=source_stack_name_or_id
+            )
+        except KeyError as err:
+            cli_utils.error(str(err))
 
         component_mapping: Dict[StackComponentType, Union[str, UUID]] = {}
 
@@ -1070,7 +1177,9 @@ def register_secrets(
             else:
                 value = None
                 while not value:
-                    value = getpass.getpass(f"Value for secret `{name}.{key}`:")
+                    value = getpass.getpass(
+                        f"Value for secret `{name}.{key}`:"
+                    )
                 value = cli_utils.expand_argument_value_from_file(
                     name=key, value=value
                 )
