@@ -15,7 +15,7 @@
 
 import time
 from importlib import import_module
-from typing import Callable, List, Optional
+from typing import Any, Callable, List, Optional
 
 import click
 from rich.markdown import Markdown
@@ -24,14 +24,21 @@ from zenml.cli import utils as cli_utils
 from zenml.cli.annotator import register_annotator_subcommands
 from zenml.cli.cli import TagGroup, cli
 from zenml.cli.feature import register_feature_store_subcommands
-from zenml.cli.model import register_model_deployer_subcommands
+from zenml.cli.model import register_model_registry_subcommands
 from zenml.cli.secret import register_secrets_manager_subcommands
-from zenml.cli.utils import _component_display_name
+from zenml.cli.served_model import register_model_deployer_subcommands
+from zenml.cli.utils import (
+    _component_display_name,
+    list_options,
+    print_page_info,
+    warn_deprecated_secrets_manager,
+)
 from zenml.client import Client
 from zenml.console import console
 from zenml.enums import CliCategories, StackComponentType
 from zenml.exceptions import IllegalOperationError
 from zenml.io import fileio
+from zenml.models import ComponentFilterModel
 from zenml.utils.analytics_utils import AnalyticsEvent, track
 
 
@@ -49,6 +56,9 @@ def generate_stack_component_get_command(
 
     def get_stack_component_command() -> None:
         """Prints the name of the active component."""
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
+
         client = Client()
         display_name = _component_display_name(component_type)
 
@@ -92,12 +102,17 @@ def generate_stack_component_describe_command(
         Args:
             name_id_or_prefix: Name or id of the component to describe.
         """
-        client = Client()
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
 
-        component_ = client.get_stack_component(
-            name_id_or_prefix=name_id_or_prefix,
-            component_type=component_type,
-        )
+        client = Client()
+        try:
+            component_ = client.get_stack_component(
+                name_id_or_prefix=name_id_or_prefix,
+                component_type=component_type,
+            )
+        except KeyError as err:
+            cli_utils.error(str(err))
 
         with console.status(f"Describing component '{component_.name}'..."):
             active_component_id = None
@@ -127,20 +142,30 @@ def generate_stack_component_list_command(
         A function that can be used as a `click` command.
     """
 
-    def list_stack_components_command() -> None:
-        """Prints a table of stack components."""
-        client = Client()
+    @list_options(ComponentFilterModel)
+    def list_stack_components_command(**kwargs: Any) -> None:
+        """Prints a table of stack components.
 
+        Args:
+            kwargs: Keyword arguments to filter the components.
+        """
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
+
+        client = Client()
         with console.status(f"Listing {component_type.plural}..."):
-            components = client.list_stack_components(
-                component_type=component_type
-            )
+            kwargs["type"] = component_type
+            components = client.list_stack_components(**kwargs)
+            if not components:
+                cli_utils.declare("No components found for the given filters.")
+                return
 
             cli_utils.print_components_table(
                 client=client,
                 component_type=component_type,
-                components=components,
+                components=components.items,
             )
+            print_page_info(components)
 
     return list_stack_components_command
 
@@ -192,6 +217,9 @@ def generate_stack_component_register_command(
             share: Share the stack with other users.
             args: Additional arguments to pass to the component.
         """
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
+
         client = Client()
 
         # Parse the given args
@@ -249,6 +277,9 @@ def generate_stack_component_update_command(
             name_id_or_prefix: The name or id of the stack component to update.
             args: Additional arguments to pass to the update command.
         """
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
+
         client = Client()
 
         # Parse the given args
@@ -263,11 +294,14 @@ def generate_stack_component_update_command(
         )
 
         with console.status(f"Updating {display_name}...\n"):
-            updated_component = client.update_stack_component(
-                name_id_or_prefix=name_or_id,
-                component_type=component_type,
-                configuration=parsed_args,
-            )
+            try:
+                updated_component = client.update_stack_component(
+                    name_id_or_prefix=name_or_id,
+                    component_type=component_type,
+                    configuration=parsed_args,
+                )
+            except KeyError as err:
+                cli_utils.error(str(err))
 
             cli_utils.declare(
                 f"Successfully updated {display_name} "
@@ -303,6 +337,9 @@ def generate_stack_component_share_command(
         Args:
             name_id_or_prefix: The name or id of the stack component to update.
         """
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
+
         client = Client()
 
         with console.status(
@@ -314,11 +351,12 @@ def generate_stack_component_share_command(
                     component_type=component_type,
                     is_shared=True,
                 )
-            except IllegalOperationError as err:
+            except (KeyError, IllegalOperationError) as err:
                 cli_utils.error(str(err))
 
             cli_utils.declare(
-                f"Successfully shared {display_name} " f"`{name_id_or_prefix}`."
+                f"Successfully shared {display_name} "
+                f"`{name_id_or_prefix}`."
             )
 
     return share_stack_component_command
@@ -353,6 +391,9 @@ def generate_stack_component_remove_attribute_command(
                 attribute from.
             args: Additional arguments to pass to the remove_attribute command.
         """
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
+
         client = Client()
 
         with console.status(
@@ -364,7 +405,7 @@ def generate_stack_component_remove_attribute_command(
                     component_type=component_type,
                     configuration={k: None for k in args},
                 )
-            except IllegalOperationError as err:
+            except (KeyError, IllegalOperationError) as err:
                 cli_utils.error(str(err))
 
             cli_utils.declare(
@@ -406,6 +447,9 @@ def generate_stack_component_rename_command(
             name_id_or_prefix: The name of the stack component to rename.
             new_name: The new name of the stack component.
         """
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
+
         client = Client()
 
         with console.status(
@@ -417,7 +461,7 @@ def generate_stack_component_rename_command(
                     component_type=component_type,
                     name=new_name,
                 )
-            except IllegalOperationError as err:
+            except (KeyError, IllegalOperationError) as err:
                 cli_utils.error(str(err))
 
             cli_utils.declare(
@@ -454,11 +498,11 @@ def generate_stack_component_delete_command(
             f"Deleting {display_name} '{name_id_or_prefix}'...\n"
         ):
             try:
-                client.deregister_stack_component(
+                client.delete_stack_component(
                     name_id_or_prefix=name_id_or_prefix,
                     component_type=component_type,
                 )
-            except IllegalOperationError as err:
+            except (KeyError, IllegalOperationError) as err:
                 cli_utils.error(str(err))
             cli_utils.declare(f"Deleted {display_name}: {name_id_or_prefix}")
 
@@ -494,16 +538,22 @@ def generate_stack_component_copy_command(
                                          component to copy.
             target_component: Name of the copied component.
         """
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
+
         client = Client()
 
         with console.status(
             f"Copying {display_name} "
             f"`{source_component_name_id_or_prefix}`..\n"
         ):
-            component_to_copy = client.get_stack_component(
-                name_id_or_prefix=source_component_name_id_or_prefix,
-                component_type=component_type,
-            )
+            try:
+                component_to_copy = client.get_stack_component(
+                    name_id_or_prefix=source_component_name_id_or_prefix,
+                    component_type=component_type,
+                )
+            except KeyError as err:
+                cli_utils.error(str(err))
 
             client.create_stack_component(
                 name=target_component,
@@ -541,11 +591,13 @@ def generate_stack_component_up_command(
         with console.status(
             f"Provisioning {display_name} '{name_id_or_prefix}' locally...\n"
         ):
-
-            component_model = client.get_stack_component(
-                name_id_or_prefix=name_id_or_prefix,
-                component_type=component_type,
-            )
+            try:
+                component_model = client.get_stack_component(
+                    name_id_or_prefix=name_id_or_prefix,
+                    component_type=component_type,
+                )
+            except KeyError as err:
+                cli_utils.error(str(err))
 
             from zenml.stack import StackComponent
 
@@ -620,10 +672,13 @@ def generate_stack_component_down_command(
         with console.status(
             f"De-provisioning {display_name} '{name_id_or_prefix}' locally...\n"
         ):
-            component_model = client.get_stack_component(
-                name_id_or_prefix=name_id_or_prefix,
-                component_type=component_type,
-            )
+            try:
+                component_model = client.get_stack_component(
+                    name_id_or_prefix=name_id_or_prefix,
+                    component_type=component_type,
+                )
+            except KeyError as err:
+                cli_utils.error(str(err))
 
             from zenml.stack import StackComponent
 
@@ -704,11 +759,13 @@ def generate_stack_component_logs_command(
             f"Fetching the logs for the {display_name} "
             f"'{name_id_or_prefix}'...\n"
         ):
-
-            component_model = client.get_stack_component(
-                name_id_or_prefix=name_id_or_prefix,
-                component_type=component_type,
-            )
+            try:
+                component_model = client.get_stack_component(
+                    name_id_or_prefix=name_id_or_prefix,
+                    component_type=component_type,
+                )
+            except KeyError as err:
+                cli_utils.error(str(err))
 
             from zenml.stack import StackComponent
 
@@ -767,6 +824,9 @@ def generate_stack_component_explain_command(
 
     def explain_stack_components_command() -> None:
         """Explains the concept of the stack component."""
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
+
         component_module = import_module(f"zenml.{component_type.plural}")
 
         if component_module.__doc__ is not None:
@@ -798,12 +858,16 @@ def generate_stack_component_flavor_list_command(
 
     def list_stack_component_flavor_command() -> None:
         """Lists the flavors for a single type of stack component."""
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
+
         client = Client()
 
         with console.status(f"Listing {display_name} flavors`...\n"):
             flavors = client.get_flavors_by_type(component_type=component_type)
 
             cli_utils.print_flavor_list(flavors=flavors)
+            cli_utils.print_page_info(flavors)
 
     return list_stack_component_flavor_command
 
@@ -819,6 +883,7 @@ def generate_stack_component_flavor_register_command(
     Returns:
         A function that can be used as a `click` command.
     """
+    command_name = component_type.value.replace("_", "-")
     display_name = _component_display_name(component_type)
 
     @click.argument(
@@ -829,18 +894,46 @@ def generate_stack_component_flavor_register_command(
     def register_stack_component_flavor_command(source: str) -> None:
         """Adds a flavor for a stack component type.
 
+        Example:
+            Let's say you create an artifact store flavor class `MyArtifactStoreFlavor`
+            in the file path `flavors/my_flavor.py`. You would register it as:
+
+            ```shell
+            zenml artifact-store flavor register flavors.my_flavor.MyArtifactStoreFlavor
+            ```
+
         Args:
-            source: The source file to read the flavor from.
+            source: The source path of the flavor class in dot notation format.
         """
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
+
         client = Client()
 
-        with console.status(f"Registering a new {display_name} flavor`...\n"):
-            # Register the new model
-            new_flavor = client.create_flavor(
-                source=source,
-                component_type=component_type,
+        if not client.root:
+            cli_utils.warning(
+                f"You're running the `zenml {command_name} flavor register` "
+                "command without a ZenML repository. Your current working "
+                "directory will be used as the source root relative to which "
+                "the `source` argument is expected. To silence this warning, "
+                "run `zenml init` at your source code root."
             )
 
+        with console.status(f"Registering a new {display_name} flavor`...\n"):
+            try:
+                # Register the new model
+                new_flavor = client.create_flavor(
+                    source=source,
+                    component_type=component_type,
+                )
+            except ValueError as e:
+                root_path = Client.find_repository()
+                cli_utils.error(
+                    f"Flavor registration failed! ZenML tried loading the module `{source}` from path "
+                    f"`{root_path}`. If this is not what you expect, then please ensure you have run "
+                    f"`zenml init` at the root of your repository.\n\nOriginal exception: {str(e)}"
+                )
+
             cli_utils.declare(
                 f"Successfully registered new flavor '{new_flavor.name}' "
                 f"for stack component '{new_flavor.type}'."
@@ -873,6 +966,9 @@ def generate_stack_component_flavor_describe_command(
         Args:
             name: The name of the flavor.
         """
+        if component_type == StackComponentType.SECRETS_MANAGER:
+            warn_deprecated_secrets_manager()
+
         client = Client()
 
         with console.status(f"Describing {display_name} flavor: {name}`...\n"):
@@ -952,7 +1048,9 @@ def register_single_stack_component_cli_commands(
     )(get_command)
 
     # zenml stack-component describe
-    describe_command = generate_stack_component_describe_command(component_type)
+    describe_command = generate_stack_component_describe_command(
+        component_type
+    )
     command_group.command(
         "describe",
         help=f"Show details about the (active) {singular_display_name}.",
@@ -965,7 +1063,9 @@ def register_single_stack_component_cli_commands(
     )(list_command)
 
     # zenml stack-component register
-    register_command = generate_stack_component_register_command(component_type)
+    register_command = generate_stack_component_register_command(
+        component_type
+    )
     context_settings = {"ignore_unknown_options": True}
     command_group.command(
         "register",
@@ -1061,7 +1161,7 @@ def register_single_stack_component_cli_commands(
     )
     flavor_group.command(
         "register",
-        help=f"Identify a new flavor for {plural_display_name}.",
+        help=f"Register a new {singular_display_name} flavor.",
     )(register_flavor_command)
 
     # zenml stack-component flavor list
@@ -1105,3 +1205,4 @@ register_annotator_subcommands()
 register_secrets_manager_subcommands()
 register_feature_store_subcommands()
 register_model_deployer_subcommands()
+register_model_registry_subcommands()
