@@ -16,20 +16,22 @@
 import json
 import os
 import uuid
-from pathlib import PurePath
+from pathlib import Path, PurePath
 from secrets import token_hex
 from typing import TYPE_CHECKING, Any, Dict, Optional, cast
 from uuid import UUID
 
 from packaging import version
-from pydantic import BaseModel, Field, ValidationError, validator
+from pydantic import BaseModel, Field, SecretStr, ValidationError, validator
 from pydantic.main import ModelMetaclass
 
 from zenml import __version__
+from zenml.config.secrets_store_config import SecretsStoreConfiguration
 from zenml.config.store_config import StoreConfiguration
 from zenml.constants import (
     DEFAULT_STORE_DIRECTORY_NAME,
     ENV_ZENML_LOCAL_STORES_PATH,
+    ENV_ZENML_SECRETS_STORE_PREFIX,
     ENV_ZENML_STORE_PREFIX,
     LOCAL_STORES_DIRECTORY_NAME,
 )
@@ -47,7 +49,7 @@ from zenml.utils.analytics_utils import (
 )
 
 if TYPE_CHECKING:
-    from zenml.models import ProjectResponseModel, StackResponseModel
+    from zenml.models import StackResponseModel, WorkspaceResponseModel
     from zenml.zen_stores.base_zen_store import BaseZenStore
 
 logger = get_logger(__name__)
@@ -133,24 +135,26 @@ class GlobalConfiguration(BaseModel, metaclass=GlobalConfigMetaClass):
             global config.
         store: Store configuration.
         active_stack_id: The ID of the active stack.
-        active_project_name: The name of the active project.
+        active_workspace_name: The name of the active workspace.
         jwt_secret_key: The secret key used to sign and verify JWT tokens.
         _config_path: Directory where the global config file is stored.
     """
 
-    user_id: uuid.UUID = Field(default_factory=uuid.uuid4, allow_mutation=False)
+    user_id: uuid.UUID = Field(
+        default_factory=uuid.uuid4, allow_mutation=False
+    )
     user_email: Optional[str] = None
     user_email_opt_in: Optional[bool] = None
     analytics_opt_in: bool = True
     version: Optional[str]
     store: Optional[StoreConfiguration]
     active_stack_id: Optional[uuid.UUID]
-    active_project_name: Optional[str]
+    active_workspace_name: Optional[str]
     jwt_secret_key: str = Field(default_factory=generate_jwt_secret_key)
 
     _config_path: str
     _zen_store: Optional["BaseZenStore"] = None
-    _active_project: Optional["ProjectResponseModel"] = None
+    _active_workspace: Optional["WorkspaceResponseModel"] = None
 
     def __init__(
         self, config_path: Optional[str] = None, **kwargs: Any
@@ -211,6 +215,8 @@ class GlobalConfiguration(BaseModel, metaclass=GlobalConfigMetaClass):
                 reset to an empty value.
         """
         cls._global_config = config
+        if config:
+            config._write_config()
 
     @validator("version")
     def _validate_version(cls, v: Optional[str]) -> Optional[str]:
@@ -232,7 +238,9 @@ class GlobalConfiguration(BaseModel, metaclass=GlobalConfigMetaClass):
             # If the version parsing fails, it returns a `LegacyVersion`
             # instead. Check to make sure it's an actual `Version` object
             # which represents a valid version.
-            raise RuntimeError(f"Invalid version in global configuration: {v}.")
+            raise RuntimeError(
+                f"Invalid version in global configuration: {v}."
+            )
 
         return v
 
@@ -394,7 +402,7 @@ class GlobalConfiguration(BaseModel, metaclass=GlobalConfigMetaClass):
             # We want to check if the active user has opted in or out for using
             # an email address for marketing purposes and if so, record it in
             # the analytics.
-            active_user = store.active_user
+            active_user = store.get_user(include_private=True)
             if active_user.email_opted_in is not None:
                 self.record_email_opt_in_out(
                     opted_in=active_user.email_opted_in,
@@ -407,18 +415,22 @@ class GlobalConfiguration(BaseModel, metaclass=GlobalConfigMetaClass):
             self._sanitize_config()
             self._write_config()
 
+            local_stores_path = Path(self.local_stores_path)
+            local_stores_path.mkdir(parents=True, exist_ok=True)
+
     def _sanitize_config(self) -> None:
         """Sanitize and save the global configuration.
 
-        This method is called to ensure that the active stack and project
+        This method is called to ensure that the active stack and workspace
         are set to their default values, if possible.
         """
-        active_project, active_stack = self.zen_store.validate_active_config(
-            self.active_project_name,
+        active_workspace, active_stack = self.zen_store.validate_active_config(
+            self.active_workspace_name,
             self.active_stack_id,
             config_name="global",
         )
-        self.set_active_project(active_project)
+        self.active_workspace_name = active_workspace.name
+        self._active_workspace = active_workspace
         self.set_active_stack(active_stack)
 
     @staticmethod
@@ -542,29 +554,52 @@ class GlobalConfiguration(BaseModel, metaclass=GlobalConfigMetaClass):
         """
         from zenml.zen_stores.base_zen_store import BaseZenStore
 
-        env_config: Dict[str, str] = {}
+        env_store_config: Dict[str, str] = {}
+        env_secrets_store_config: Dict[str, str] = {}
         for k, v in os.environ.items():
             if v == "":
                 continue
             if k.startswith(ENV_ZENML_STORE_PREFIX):
-                env_config[k[len(ENV_ZENML_STORE_PREFIX) :].lower()] = v
-        if len(env_config):
-            if "type" not in env_config and "url" in env_config:
-                env_config["type"] = BaseZenStore.get_store_type(
-                    env_config["url"]
+                env_store_config[k[len(ENV_ZENML_STORE_PREFIX) :].lower()] = v
+            elif k.startswith(ENV_ZENML_SECRETS_STORE_PREFIX):
+                env_secrets_store_config[
+                    k[len(ENV_ZENML_SECRETS_STORE_PREFIX) :].lower()
+                ] = v
+        if len(env_store_config):
+            if "type" not in env_store_config and "url" in env_store_config:
+                env_store_config["type"] = BaseZenStore.get_store_type(
+                    env_store_config["url"]
                 )
 
             logger.debug(
                 "Using environment variables to configure the default store"
             )
-            return StoreConfiguration(**env_config)
 
-        return BaseZenStore.get_default_store_config(
-            path=os.path.join(
-                self.local_stores_path,
-                DEFAULT_STORE_DIRECTORY_NAME,
+            config = StoreConfiguration(
+                **env_store_config,
             )
-        )
+        else:
+            config = BaseZenStore.get_default_store_config(
+                path=os.path.join(
+                    self.local_stores_path,
+                    DEFAULT_STORE_DIRECTORY_NAME,
+                )
+            )
+
+        if len(env_secrets_store_config):
+
+            if "type" not in env_secrets_store_config:
+                env_secrets_store_config["type"] = config.type.value
+
+            logger.debug(
+                "Using environment variables to configure the secrets store"
+            )
+
+            config.secrets_store = SecretsStoreConfiguration(
+                **env_secrets_store_config
+            )
+
+        return config
 
     def set_default_store(self) -> None:
         """Creates and sets the default store configuration.
@@ -624,7 +659,9 @@ class GlobalConfiguration(BaseModel, metaclass=GlobalConfigMetaClass):
                 # particular server at least once, but no information about the
                 # user account is recorded here.
 
-                with event_handler(event=AnalyticsEvent.ZENML_SERVER_CONNECTED):
+                with event_handler(
+                    event=AnalyticsEvent.ZENML_SERVER_CONNECTED
+                ):
                     server_info = self.zen_store.get_store_info()
 
                     identify_group(
@@ -632,7 +669,9 @@ class GlobalConfiguration(BaseModel, metaclass=GlobalConfigMetaClass):
                         group_id=str(server_info.id),
                         group_metadata={
                             "version": server_info.version,
-                            "deployment_type": str(server_info.deployment_type),
+                            "deployment_type": str(
+                                server_info.deployment_type
+                            ),
                             "database_type": str(server_info.database_type),
                         },
                     )
@@ -656,20 +695,22 @@ class GlobalConfiguration(BaseModel, metaclass=GlobalConfigMetaClass):
 
         return self._zen_store
 
-    def set_active_project(
-        self, project: "ProjectResponseModel"
-    ) -> "ProjectResponseModel":
-        """Set the project for the local client.
+    def set_active_workspace(
+        self, workspace: "WorkspaceResponseModel"
+    ) -> "WorkspaceResponseModel":
+        """Set the workspace for the local client.
 
         Args:
-            project: The project to set active.
+            workspace: The workspace to set active.
 
         Returns:
-            The project that was set active.
+            The workspace that was set active.
         """
-        self.active_project_name = project.name
-        self._active_project = project
-        return project
+        self.active_workspace_name = workspace.name
+        self._active_workspace = workspace
+        # Sanitize the global configuration to reflect the new workspace
+        self._sanitize_config()
+        return workspace
 
     def set_active_stack(self, stack: "StackResponseModel") -> None:
         """Set the active stack for the local client.
@@ -679,35 +720,35 @@ class GlobalConfiguration(BaseModel, metaclass=GlobalConfigMetaClass):
         """
         self.active_stack_id = stack.id
 
-    def get_active_project(self) -> "ProjectResponseModel":
-        """Get a model of the active project for the local client.
+    def get_active_workspace(self) -> "WorkspaceResponseModel":
+        """Get a model of the active workspace for the local client.
 
         Returns:
-            The model of the active project.
+            The model of the active workspace.
         """
-        project_name = self.get_active_project_name()
+        workspace_name = self.get_active_workspace_name()
 
-        if self._active_project is not None:
-            return self._active_project
+        if self._active_workspace is not None:
+            return self._active_workspace
 
-        project = self.zen_store.get_project(
-            project_name_or_id=project_name,
+        workspace = self.zen_store.get_workspace(
+            workspace_name_or_id=workspace_name,
         )
-        return self.set_active_project(project)
+        return self.set_active_workspace(workspace)
 
-    def get_active_project_name(self) -> str:
-        """Get the name of the active project.
+    def get_active_workspace_name(self) -> str:
+        """Get the name of the active workspace.
 
-        If the active project doesn't exist yet, the ZenStore is reinitialized.
+        If the active workspace doesn't exist yet, the ZenStore is reinitialized.
 
         Returns:
-            The name of the active project.
+            The name of the active workspace.
         """
-        if self.active_project_name is None:
+        if self.active_workspace_name is None:
             _ = self.zen_store
-            assert self.active_project_name is not None
+            assert self.active_workspace_name is not None
 
-        return self.active_project_name
+        return self.active_workspace_name
 
     def get_active_stack_id(self) -> UUID:
         """Get the ID of the active stack.
@@ -724,7 +765,10 @@ class GlobalConfiguration(BaseModel, metaclass=GlobalConfigMetaClass):
         return self.active_stack_id
 
     def record_email_opt_in_out(
-        self, opted_in: bool, email: Optional[str], source: AnalyticsEventSource
+        self,
+        opted_in: bool,
+        email: Optional[str],
+        source: AnalyticsEventSource,
     ) -> None:
         """Set the email address associated with this client.
 
@@ -773,3 +817,9 @@ class GlobalConfiguration(BaseModel, metaclass=GlobalConfigMetaClass):
         # all attributes with leading underscore are private and therefore
         # are mutable and not included in serialization
         underscore_attrs_are_private = True
+
+        # This is needed to allow correct handling of SecretStr values during
+        # serialization.
+        json_encoders = {
+            SecretStr: lambda v: v.get_secret_value() if v else None
+        }
