@@ -74,8 +74,9 @@ ENV_ZENML_JWT_SECRET_KEY = "ZENML_JWT_SECRET_KEY"
 ENV_ZENML_AUTH_TYPE = "ZENML_AUTH_TYPE"
 ENV_ZENML_DEFAULT_USER_NAME = "ZENML_DEFAULT_USER_NAME"
 ENV_ZENML_DEFAULT_USER_PASSWORD = "ZENML_DEFAULT_USER_PASSWORD"
-ENV_ZENML_DEFAULT_PROJECT_NAME = "ZENML_DEFAULT_PROJECT_NAME"
+ENV_ZENML_DEFAULT_WORKSPACE_NAME = "ZENML_DEFAULT_WORKSPACE_NAME"
 ENV_ZENML_STORE_PREFIX = "ZENML_STORE_"
+ENV_ZENML_SECRETS_STORE_PREFIX = "ZENML_SECRETS_STORE_"
 ENV_ZENML_SKIP_PIPELINE_REGISTRATION = "ZENML_SKIP_PIPELINE_REGISTRATION"
 ENV_ZENML_SERVER_ROOT_URL_PATH = "ZENML_SERVER_ROOT_URL_PATH"
 ENV_ZENML_SERVER_DEPLOYMENT_TYPE = "ZENML_SERVER_DEPLOYMENT_TYPE"
@@ -83,9 +84,13 @@ ENV_AUTO_OPEN_DASHBOARD = "AUTO_OPEN_DASHBOARD"
 ENV_ZENML_DISABLE_DATABASE_MIGRATION = "DISABLE_DATABASE_MIGRATION"
 ENV_ZENML_LOCAL_STORES_PATH = "ZENML_LOCAL_STORES_PATH"
 ENV_ZENML_CONTAINER = "ZENML_CONTAINER"
+ENV_ZENML_PAGINATION_DEFAULT_LIMIT = "ZENML_PAGINATION_DEFAULT_LIMIT"
 ENV_ZENML_DISABLE_CLIENT_SERVER_MISMATCH_WARNING = (
     "ZENML_DISABLE_CLIENT_SERVER_MISMATCH_WARNING"
 )
+ENV_ZENML_DISABLE_WORKSPACE_WARNINGS = "ZENML_DISABLE_WORKSPACE_WARNINGS"
+ENV_ZENML_SKIP_IMAGE_BUILDER_DEFAULT = "ZENML_SKIP_IMAGE_BUILDER_DEFAULT"
+
 
 # Logging variables
 IS_DEBUG_ENV: bool = handle_bool_env_var(ENV_ZENML_DEBUG, default=False)
@@ -145,7 +150,7 @@ DISABLE_CLIENT_SERVER_MISMATCH_WARNING = handle_bool_env_var(
 )
 
 # Services
-DEFAULT_SERVICE_START_STOP_TIMEOUT = 10
+DEFAULT_SERVICE_START_STOP_TIMEOUT = 60
 DEFAULT_LOCAL_SERVICE_IP_ADDRESS = "127.0.0.1"
 ZEN_SERVER_ENTRYPOINT = "zenml.zen_server.zen_server_api:app"
 
@@ -162,17 +167,22 @@ STATISTICS = "/statistics"
 USERS = "/users"
 CURRENT_USER = "/current-user"
 TEAMS = "/teams"
-PROJECTS = "/projects"
+WORKSPACES = "/workspaces"
 PERMISSIONS = "/permissions"
 ROLES = "/roles"
 FLAVORS = "/flavors"
-ROLE_ASSIGNMENTS = "/role_assignments"
+USER_ROLE_ASSIGNMENTS = "/role_assignments"
+TEAM_ROLE_ASSIGNMENTS = "/team_role_assignments"
 PIPELINE_RUNS = "/pipeline_runs"
 LOGIN = "/login"
 LOGOUT = "/logout"
 PIPELINES = "/pipelines"
+PIPELINE_BUILDS = "/pipeline_builds"
+PIPELINE_DEPLOYMENTS = "/pipeline_deployments"
 TRIGGERS = "/triggers"
 RUNS = "/runs"
+RUN_METADATA = "/run-metadata"
+SCHEDULES = "/schedules"
 DEFAULT_STACK = "/default-stack"
 PIPELINE_SPEC = "/pipeline-spec"
 PIPELINE_CONFIGURATION = "/pipeline-configuration"
@@ -181,7 +191,6 @@ GRAPH = "/graph"
 STEPS = "/steps"
 ARTIFACTS = "/artifacts"
 COMPONENT_TYPES = "/component-types"
-COMPONENT_SIDE_EFFECTS = "/component-side-effects"
 REPOSITORIES = "/repositories"
 DEACTIVATE = "/deactivate"
 EMAIL_ANALYTICS = "/email-opt-in"
@@ -189,6 +198,8 @@ ACTIVATE = "/activate"
 INFO = "/info"
 VERSION_1 = "/v1"
 STATUS = "/status"
+GET_OR_CREATE = "/get-or-create"
+SECRETS = "/secrets"
 
 # mandatory stack component attributes
 MANDATORY_COMPONENT_ATTRIBUTES = ["name", "uuid"]
@@ -198,8 +209,26 @@ MANDATORY_COMPONENT_ATTRIBUTES = ["name", "uuid"]
 MODEL_METADATA_YAML_FILE_NAME = "model_metadata.yaml"
 
 # orchestrator constants
-ORCHESTRATOR_DOCKER_IMAGE_KEY = "orchestrator_docker_image"
-DOCKER_IMAGE_DEPLOYMENT_CONFIG_FILE = ".zenml_deployment_config.yaml"
+ORCHESTRATOR_DOCKER_IMAGE_KEY = "orchestrator"
 
 # Secret constants
 ARBITRARY_SECRET_SCHEMA_TYPE = "arbitrary"
+
+# Pagination and filtering defaults
+PAGINATION_STARTING_PAGE: int = 1
+PAGE_SIZE_DEFAULT: int = handle_int_env_var(
+    ENV_ZENML_PAGINATION_DEFAULT_LIMIT, default=50
+)
+PAGE_SIZE_MAXIMUM: int = handle_int_env_var(
+    ENV_ZENML_PAGINATION_DEFAULT_LIMIT, default=10000
+)
+FILTERING_DATETIME_FORMAT: str = "%Y-%m-%d %H:%M:%S"
+
+# Metadata constants
+METADATA_ORCHESTRATOR_URL = "orchestrator_url"
+METADATA_EXPERIMENT_TRACKER_URL = "experiment_tracker_url"
+METADATA_DEPLOYED_MODEL_URL = "deployed_model_url"
+
+
+# Model registries constants
+MLFLOW_MODEL_FORMAT = "MLflow"
