@@ -12,7 +12,7 @@
 #  or implied. See the License for the specific language governing
 #  permissions and limitations under the License.
 """Implementation of a default container registry class."""
-
+from typing import Optional
 
 from zenml.container_registries.base_container_registry import (
     BaseContainerRegistryFlavor,
@@ -31,3 +31,30 @@ class DefaultContainerRegistryFlavor(BaseContainerRegistryFlavor):
             The name of the flavor.
         """
         return ContainerRegistryFlavor.DEFAULT.value
+
+    @property
+    def docs_url(self) -> Optional[str]:
+        """A url to point at docs explaining this flavor.
+
+        Returns:
+            A flavor docs url.
+        """
+        return self.generate_default_docs_url()
+
+    @property
+    def sdk_docs_url(self) -> Optional[str]:
+        """A url to point at docs explaining this flavor.
+
+        Returns:
+            A flavor docs url.
+        """
+        return self.generate_default_sdk_docs_url()
+
+    @property
+    def logo_url(self) -> str:
+        """A url to represent the flavor in the dashboard.
+
+        Returns:
+            The flavor logo.
+        """
+        return "https://public-flavor-logos.s3.eu-central-1.amazonaws.com/container_registry/local.svg"
