@@ -12,7 +12,6 @@
 #  or implied. See the License for the specific language governing
 #  permissions and limitations under the License.
 """ZenML enums."""
-
 import logging
 from enum import Enum
 
@@ -22,12 +21,12 @@ from zenml.utils.enum_utils import StrEnum
 class ArtifactType(StrEnum):
     """All possible types an artifact can have."""
 
-    DATAANALYSIS = "DataAnalysisArtifact"
+    DATA_ANALYSIS = "DataAnalysisArtifact"
     DATA = "DataArtifact"
     MODEL = "ModelArtifact"
-    SCHEMA = "SchemaArtifact"
+    SCHEMA = "SchemaArtifact"  # deprecated
     SERVICE = "ServiceArtifact"
-    STATISTICS = "StatisticsArtifact"
+    STATISTICS = "StatisticsArtifact"  # deprecated in favor of `DATA_ANALYSIS`
     BASE = "BaseArtifact"
 
 
@@ -61,10 +60,12 @@ class StackComponentType(StrEnum):
     DATA_VALIDATOR = "data_validator"
     EXPERIMENT_TRACKER = "experiment_tracker"
     FEATURE_STORE = "feature_store"
+    IMAGE_BUILDER = "image_builder"
     MODEL_DEPLOYER = "model_deployer"
     ORCHESTRATOR = "orchestrator"
     SECRETS_MANAGER = "secrets_manager"
     STEP_OPERATOR = "step_operator"
+    MODEL_REGISTRY = "model_registry"
 
     @property
     def plural(self) -> str:
@@ -79,13 +80,37 @@ class StackComponentType(StrEnum):
         return f"{self.value}s"
 
 
+class SecretScope(StrEnum):
+    """Enum for the scope of a secret."""
+
+    WORKSPACE = "workspace"
+    USER = "user"
+
+
 class StoreType(StrEnum):
-    """Repository Store Backend Types."""
+    """Zen Store Backend Types."""
 
     SQL = "sql"
     REST = "rest"
 
 
+class SecretsStoreType(StrEnum):
+    """Secrets Store Backend Types.
+
+    NOTE: this is a superset of the StoreType values because the set of secrets
+    store backends includes all the backends supported for zen stores.
+    """
+
+    NONE = "none"  # indicates that the secrets store is disabled
+    SQL = StoreType.SQL.value
+    REST = StoreType.REST.value
+    AWS = "aws"
+    GCP = "gcp"
+    AZURE = "azure"
+    HASHICORP = "hashicorp"
+    CUSTOM = "custom"  # indicates that the secrets store uses a custom backend
+
+
 class ContainerRegistryFlavor(StrEnum):
     """Flavors of container registries."""
 
@@ -141,6 +166,7 @@ class AnalyticsEventSource(StrEnum):
     """Enum to identify analytics events source."""
 
     ZENML_GO = "zenml go"
+    ZENML_INIT = "zenml init"
     ZENML_SERVER = "zenml server"
 
 
@@ -150,4 +176,41 @@ class PermissionType(StrEnum):
     # ANY CHANGES TO THIS ENUM WILL NEED TO BE DONE TOGETHER WITH A DB MIGRATION
     WRITE = "write"  # allows the user to create, update, delete everything
     READ = "read"  # allows the user to read everything
-    ME = "me"  # allows the user to self administrate (change name, password...)
+    ME = (
+        "me"  # allows the user to self administrate (change name, password...)
+    )
+
+
+class GenericFilterOps(StrEnum):
+    """Ops for all filters for string values on list methods."""
+
+    EQUALS = "equals"
+    CONTAINS = "contains"
+    STARTSWITH = "startswith"
+    ENDSWITH = "endswith"
+    GTE = "gte"
+    GT = "gt"
+    LTE = "lte"
+    LT = "lt"
+
+
+class SorterOps(StrEnum):
+    """Ops for all filters for string values on list methods."""
+
+    ASCENDING = "asc"
+    DESCENDING = "desc"
+
+
+class LogicalOperators(StrEnum):
+    """Logical Ops to use to combine filters on list methods."""
+
+    OR = "or"
+    AND = "and"
+
+
+class OperatingSystemType(StrEnum):
+    """Enum for OS types."""
+
+    LINUX = "Linux"
+    WINDOWS = "Windows"
+    MACOS = "Darwin"
