@@ -22,6 +22,7 @@ from typing import TYPE_CHECKING, Any, Dict, Optional, Tuple, Type, cast
 import distro
 
 from zenml import __version__
+from zenml.constants import INSIDE_ZENML_CONTAINER
 from zenml.logger import get_logger
 from zenml.utils.singleton import SingletonMetaClass
 
@@ -31,16 +32,47 @@ if TYPE_CHECKING:
 logger = get_logger(__name__)
 
 
+def get_run_environment_dict() -> Dict[str, str]:
+    """Returns a dictionary of the current run environment.
+
+    Everything that is returned here will be saved in the DB as
+    `pipeline_run.client_environment` and
+    `pipeline_run.orchestrator_environment` for client and orchestrator
+    respectively.
+
+    Returns:
+        A dictionary of the current run environment.
+    """
+    return {
+        "environment": get_environment(),
+        **Environment.get_system_info(),
+        "python_version": Environment.python_version(),
+    }
+
+
 def get_environment() -> str:
     """Returns a string representing the execution environment of the pipeline.
 
-    Currently, one of `docker`, `paperspace`, 'colab', or `native`.
-
     Returns:
         str: the execution environment
     """
-    if Environment.in_docker():
+    # Order is important here
+    if Environment.in_kubernetes():
+        return "kubernetes"
+    elif Environment.in_github_actions():
+        return "github_action"
+    elif Environment.in_gitlab_ci():
+        return "gitlab_ci"
+    elif Environment.in_circle_ci():
+        return "circle_ci"
+    elif Environment.in_bitbucket_ci():
+        return "bitbucket_ci"
+    elif Environment.in_ci():
+        return "generic_ci"
+    elif Environment.in_docker():
         return "docker"
+    elif Environment.in_container():
+        return "container"
     elif Environment.in_google_colab():
         return "colab"
     elif Environment.in_paperspace_gradient():
@@ -104,7 +136,7 @@ class Environment(metaclass=SingletonMetaClass):
         return self.has_component(STEP_ENVIRONMENT_NAME)
 
     @staticmethod
-    def get_system_info() -> Dict[str, Any]:
+    def get_system_info() -> Dict[str, str]:
         """Information about the operating system.
 
         Returns:
@@ -146,6 +178,17 @@ class Environment(metaclass=SingletonMetaClass):
         """
         return platform.python_version()
 
+    @staticmethod
+    def in_container() -> bool:
+        """If the current python process is running in a container.
+
+        Returns:
+            `True` if the current python process is running in a
+            container, `False` otherwise.
+        """
+        # TODO [ENG-167]: Make this more reliable and add test.
+        return INSIDE_ZENML_CONTAINER
+
     @staticmethod
     def in_docker() -> bool:
         """If the current python process is running in a docker container.
@@ -154,11 +197,31 @@ class Environment(metaclass=SingletonMetaClass):
             `True` if the current python process is running in a docker
             container, `False` otherwise.
         """
-        # TODO [ENG-167]: Make this more reliable and add test.
+        if os.path.exists("./dockerenv") or os.path.exists("/.dockerinit"):
+            return True
+
         try:
             with open("/proc/1/cgroup", "rt") as ifh:
                 info = ifh.read()
-                return "docker" in info or "kubepod" in info
+                return "docker" in info
+        except (FileNotFoundError, Exception):
+            return False
+
+    @staticmethod
+    def in_kubernetes() -> bool:
+        """If the current python process is running in a kubernetes pod.
+
+        Returns:
+            `True` if the current python process is running in a kubernetes
+            pod, `False` otherwise.
+        """
+        if "KUBERNETES_SERVICE_HOST" in os.environ:
+            return True
+
+        try:
+            with open("/proc/1/cgroup", "rt") as ifh:
+                info = ifh.read()
+                return "kubepod" in info
         except (FileNotFoundError, Exception):
             return False
 
@@ -206,6 +269,56 @@ class Environment(metaclass=SingletonMetaClass):
         """
         return "PAPERSPACE_NOTEBOOK_REPO_ID" in os.environ
 
+    @staticmethod
+    def in_github_actions() -> bool:
+        """If the current Python process is running in GitHub Actions.
+
+        Returns:
+            `True` if the current Python process is running in GitHub
+            Actions, `False` otherwise.
+        """
+        return "GITHUB_ACTIONS" in os.environ
+
+    @staticmethod
+    def in_gitlab_ci() -> bool:
+        """If the current Python process is running in GitLab CI.
+
+        Returns:
+            `True` if the current Python process is running in GitLab
+            CI, `False` otherwise.
+        """
+        return "GITLAB_CI" in os.environ
+
+    @staticmethod
+    def in_circle_ci() -> bool:
+        """If the current Python process is running in Circle CI.
+
+        Returns:
+            `True` if the current Python process is running in Circle
+            CI, `False` otherwise.
+        """
+        return "CIRCLECI" in os.environ
+
+    @staticmethod
+    def in_bitbucket_ci() -> bool:
+        """If the current Python process is running in Bitbucket CI.
+
+        Returns:
+            `True` if the current Python process is running in Bitbucket
+            CI, `False` otherwise.
+        """
+        return "BITBUCKET_BUILD_NUMBER" in os.environ
+
+    @staticmethod
+    def in_ci() -> bool:
+        """If the current Python process is running in any CI.
+
+        Returns:
+            `True` if the current Python process is running in any
+            CI, `False` otherwise.
+        """
+        return "CI" in os.environ
+
     def register_component(
         self, component: "BaseEnvironmentComponent"
     ) -> "BaseEnvironmentComponent":
@@ -239,7 +352,9 @@ class Environment(metaclass=SingletonMetaClass):
         """
         if self._components.get(component.NAME) is component:
             del self._components[component.NAME]
-            logger.debug(f"Deregistered environment component {component.NAME}")
+            logger.debug(
+                f"Deregistered environment component {component.NAME}"
+            )
 
         else:
             logger.warning(
@@ -270,7 +385,7 @@ class Environment(metaclass=SingletonMetaClass):
         return self._components.copy()
 
     def has_component(self, name: str) -> bool:
-        """Check if the environment component with a known name is currently available.
+        """Check if the environment component with a known name is available.
 
         Args:
             name: the environment component name.
@@ -292,7 +407,8 @@ class Environment(metaclass=SingletonMetaClass):
             given name.
 
         Raises:
-            KeyError: if no environment component is registered for the given name.
+            KeyError: if no environment component is registered for the given
+                name.
         """
         if name in self._components:
             return self._components[name]
@@ -324,7 +440,7 @@ _BASE_ENVIRONMENT_COMPONENT_NAME = "base_environment_component"
 
 
 class EnvironmentComponentMeta(type):
-    """Metaclass responsible for registering different EnvironmentComponent instances in the global Environment."""
+    """Metaclass registering environment components in the global Environment."""
 
     def __new__(
         mcs, name: str, bases: Tuple[Type[Any], ...], dct: Dict[str, Any]
@@ -344,9 +460,10 @@ class EnvironmentComponentMeta(type):
             super().__new__(mcs, name, bases, dct),
         )
         if name != "BaseEnvironmentComponent":
-            assert (
-                cls.NAME and cls.NAME != _BASE_ENVIRONMENT_COMPONENT_NAME
-            ), "You should specify a unique NAME when creating an EnvironmentComponent !"
+            assert cls.NAME and cls.NAME != _BASE_ENVIRONMENT_COMPONENT_NAME, (
+                "You should specify a unique NAME when creating an "
+                "EnvironmentComponent!"
+            )
         return cls
 
 
