@@ -21,7 +21,9 @@ like the ``facets`` library, as well as deep learning libraries like PyTorch.
 from zenml.integrations.airflow import AirflowIntegration  # noqa
 from zenml.integrations.aws import AWSIntegration  # noqa
 from zenml.integrations.azure import AzureIntegration  # noqa
+from zenml.integrations.bentoml import BentoMLIntegration  # noqa
 from zenml.integrations.dash import DashIntegration  # noqa
+from zenml.integrations.deepchecks import DeepchecksIntegration  # noqa
 from zenml.integrations.evidently import EvidentlyIntegration  # noqa
 from zenml.integrations.facets import FacetsIntegration  # noqa
 from zenml.integrations.feast import FeastIntegration  # noqa
@@ -32,11 +34,16 @@ from zenml.integrations.great_expectations import (  # noqa
     GreatExpectationsIntegration,
 )
 from zenml.integrations.huggingface import HuggingfaceIntegration  # noqa
+from zenml.integrations.kaniko import KanikoIntegration  # noqa
+from zenml.integrations.kserve import KServeIntegration  # noqa
 from zenml.integrations.kubeflow import KubeflowIntegration  # noqa
 from zenml.integrations.kubernetes import KubernetesIntegration  # noqa
+from zenml.integrations.label_studio import LabelStudioIntegration  # noqa
 from zenml.integrations.lightgbm import LightGBMIntegration  # noqa
 from zenml.integrations.mlflow import MlflowIntegration  # noqa
+from zenml.integrations.neptune import NeptuneIntegration  # noqa
 from zenml.integrations.neural_prophet import NeuralProphetIntegration  # noqa
+from zenml.integrations.pillow import PillowIntegration  # noqa
 from zenml.integrations.plotly import PlotlyIntegration  # noqa
 from zenml.integrations.pytorch import PytorchIntegration  # noqa
 from zenml.integrations.pytorch_lightning import (  # noqa
@@ -47,6 +54,9 @@ from zenml.integrations.scipy import ScipyIntegration  # noqa
 from zenml.integrations.seldon import SeldonIntegration  # noqa
 from zenml.integrations.sklearn import SklearnIntegration  # noqa
 from zenml.integrations.slack import SlackIntegration  # noqa
+from zenml.integrations.spark import SparkIntegration  # noqa
+from zenml.integrations.tekton import TektonIntegration  # noqa
+from zenml.integrations.tensorboard import TensorBoardIntegration  # noqa
 from zenml.integrations.tensorflow import TensorflowIntegration  # noqa
 from zenml.integrations.vault import VaultSecretsManagerIntegration  # noqa
 from zenml.integrations.wandb import WandbIntegration  # noqa
