@@ -17,12 +17,11 @@ The Airflow integration sub-module powers an alternative to the local
 orchestrator. You can enable it by registering the Airflow orchestrator with
 the CLI tool, then bootstrap using the ``zenml orchestrator up`` command.
 """
-from typing import List
+from typing import List, Optional, Type
 
-from zenml.enums import StackComponentType
 from zenml.integrations.constants import AIRFLOW
 from zenml.integrations.integration import Integration
-from zenml.zen_stores.models import FlavorWrapper
+from zenml.stack import Flavor
 
 AIRFLOW_ORCHESTRATOR_FLAVOR = "airflow"
 
@@ -31,23 +30,20 @@ class AirflowIntegration(Integration):
     """Definition of Airflow Integration for ZenML."""
 
     NAME = AIRFLOW
-    REQUIREMENTS = ["apache-airflow==2.2.0"]
+    REQUIREMENTS = ["apache-airflow~=2.4.0"]
 
     @classmethod
-    def flavors(cls) -> List[FlavorWrapper]:
+    def flavors(cls) -> List[Type[Flavor]]:
         """Declare the stack component flavors for the Airflow integration.
 
         Returns:
             List of stack component flavors for this integration.
         """
-        return [
-            FlavorWrapper(
-                name=AIRFLOW_ORCHESTRATOR_FLAVOR,
-                source="zenml.integrations.airflow.orchestrators.AirflowOrchestrator",
-                type=StackComponentType.ORCHESTRATOR,
-                integration=cls.NAME,
-            )
-        ]
+        from zenml.integrations.airflow.flavors import (
+            AirflowOrchestratorFlavor,
+        )
+
+        return [AirflowOrchestratorFlavor]
 
 
 AirflowIntegration.check_installation()
