@@ -132,7 +132,6 @@ class PipelineRunLineageVisualizer(BaseVisualizer):
         Returns:
             The Dash application.
         """
-        # flake8: noqa: C901
         external_stylesheets = [
             dbc.themes.BOOTSTRAP,
             dbc.icons.BOOTSTRAP,
@@ -208,6 +207,10 @@ class PipelineRunLineageVisualizer(BaseVisualizer):
         app.layout = dbc.Row(
             [
                 dbc.Container(f"Run: {object.name}", class_name="h2"),
+                *[
+                    dbc.Container(f"- {k}: {v} ({type_})" + "\n\n")
+                    for k, v, type_ in graph.run_metadata
+                ],
                 dbc.Row(
                     [
                         dbc.Col(
@@ -329,6 +332,10 @@ class PipelineRunLineageVisualizer(BaseVisualizer):
                         "uri",
                     ]:
                         text += f"**{item}**: {data[item]}" + "\n\n"
+                    if data["metadata"]:
+                        text += "#### Metadata:" + "\n\n"
+                        for k, v, type_ in data["metadata"]:
+                            text += f"**{k}**: {v} ({type_})" + "\n\n"
                 elif data["type"] == "step":
                     text += f"### Step '{data['name']}'" + "\n\n"
                     text += "#### Attributes:" + "\n\n"
@@ -353,6 +360,10 @@ class PipelineRunLineageVisualizer(BaseVisualizer):
                         text += "#### Configuration:" + "\n\n"
                         for k, v in data["configuration"].items():
                             text += f"**{k}**: {v}" + "\n\n"
+                    if data["metadata"]:
+                        text += "#### Metadata:" + "\n\n"
+                        for k, v, type_ in data["metadata"]:
+                            text += f"**{k}**: {v} ({type_})" + "\n\n"
             return text
 
         @app.callback(  # type: ignore[misc]
