@@ -13,8 +13,20 @@
 #  permissions and limitations under the License.
 """Initialization of the Evidently Standard Steps."""
 
+from zenml.integrations.evidently.column_mapping import EvidentlyColumnMapping
+from zenml.integrations.evidently.steps.evidently_report import (
+    EvidentlyReportParameters,
+    EvidentlyReportStep,
+    EvidentlySingleDatasetReportStep,
+    evidently_report_step,
+)
+from zenml.integrations.evidently.steps.evidently_test import (
+    EvidentlyTestParameters,
+    EvidentlySingleDatasetTestStep,
+    EvidentlyTestStep,
+    evidently_test_step,
+)
 from zenml.integrations.evidently.steps.evidently_profile import (
-    EvidentlyColumnMapping,
     EvidentlyProfileParameters,
     EvidentlyProfileStep,
     evidently_profile_step,
