@@ -16,12 +16,10 @@
 from typing import (
     Any,
     Callable,
-    ClassVar,
     Dict,
     Iterable,
     List,
     Optional,
-    Set,
     Tuple,
     Union,
     cast,
@@ -30,25 +28,30 @@ from typing import (
 import gcsfs
 
 from zenml.artifact_stores import BaseArtifactStore
-from zenml.integrations.gcp import GCP_ARTIFACT_STORE_FLAVOR
+from zenml.integrations.gcp.flavors.gcp_artifact_store_flavor import (
+    GCP_PATH_PREFIX,
+    GCPArtifactStoreConfig,
+)
+from zenml.io.fileio import convert_to_str
 from zenml.secret.schemas import GCPSecretSchema
 from zenml.stack.authentication_mixin import AuthenticationMixin
-from zenml.utils.io_utils import convert_to_str
 
 PathType = Union[bytes, str]
 
 
-GCP_PATH_PREFIX = "gs://"
-
-
 class GCPArtifactStore(BaseArtifactStore, AuthenticationMixin):
     """Artifact Store for Google Cloud Storage based artifacts."""
 
     _filesystem: Optional[gcsfs.GCSFileSystem] = None
 
-    # Class Configuration
-    FLAVOR: ClassVar[str] = GCP_ARTIFACT_STORE_FLAVOR
-    SUPPORTED_SCHEMES: ClassVar[Set[str]] = {GCP_PATH_PREFIX}
+    @property
+    def config(self) -> GCPArtifactStoreConfig:
+        """Returns the `GCPArtifactStoreConfig` config.
+
+        Returns:
+            The configuration.
+        """
+        return cast(GCPArtifactStoreConfig, self._config)
 
     @property
     def filesystem(self) -> gcsfs.GCSFileSystem:
@@ -176,6 +179,9 @@ class GCPArtifactStore(BaseArtifactStore, AuthenticationMixin):
         return [
             _extract_basename(dict_)
             for dict_ in self.filesystem.listdir(path=path)
+            # gcsfs.listdir also returns the root directory, so we filter
+            # it out here
+            if _extract_basename(dict_)
         ]
 
     def makedirs(self, path: PathType) -> None:
@@ -249,6 +255,17 @@ class GCPArtifactStore(BaseArtifactStore, AuthenticationMixin):
         """
         return self.filesystem.stat(path=path)  # type: ignore[no-any-return]
 
+    def size(self, path: PathType) -> int:
+        """Get the size of a file in bytes.
+
+        Args:
+            path: The path to the file.
+
+        Returns:
+            The size of the file in bytes.
+        """
+        return self.filesystem.size(path=path)  # type: ignore[no-any-return]
+
     def walk(
         self,
         top: PathType,
