@@ -31,3 +31,7 @@ VERTEX_JOB_STATES_FAILED = (
     _VERTEX_JOB_STATE_FAILED,
     _VERTEX_JOB_STATE_CANCELLED,
 )
+
+GKE_ACCELERATOR_NODE_SELECTOR_CONSTRAINT_LABEL = (
+    "cloud.google.com/gke-accelerator"
+)
