@@ -13,26 +13,45 @@
 #  permissions and limitations under the License.
 """Implementation of the Google credentials mixin."""
 
-from typing import TYPE_CHECKING, Optional, Tuple
+from typing import TYPE_CHECKING, Optional, Tuple, cast
 
-from google.auth import default, load_credentials_from_file
-from pydantic import BaseModel
+from zenml.logger import get_logger
+from zenml.stack.stack_component import StackComponent, StackComponentConfig
 
 if TYPE_CHECKING:
     from google.auth.credentials import Credentials
 
 
-class GoogleCredentialsMixin(BaseModel):
-    """Mixin for Google Cloud Platform credentials.
+logger = get_logger(__name__)
+
+
+class GoogleCredentialsConfigMixin(StackComponentConfig):
+    """Config mixin for Google Cloud Platform credentials.
 
     Attributes:
+        project: GCP project name. If `None`, the project will be inferred from
+            the environment.
         service_account_path: path to the service account credentials file to be
             used for authentication. If not provided, the default credentials
             will be used.
     """
 
+    project: Optional[str] = None
     service_account_path: Optional[str] = None
 
+
+class GoogleCredentialsMixin(StackComponent):
+    """StackComponent mixin to get Google Cloud Platform credentials."""
+
+    @property
+    def config(self) -> GoogleCredentialsConfigMixin:
+        """Returns the `GoogleCredentialsConfigMixin` config.
+
+        Returns:
+            The configuration.
+        """
+        return cast(GoogleCredentialsConfigMixin, self._config)
+
     def _get_authentication(self) -> Tuple["Credentials", str]:
         """Get GCP credentials and the project ID associated with the credentials.
 
@@ -44,10 +63,25 @@ class GoogleCredentialsMixin(BaseModel):
             A tuple containing the credentials and the project ID associated to
             the credentials.
         """
-        if self.service_account_path:
+        from google.auth import default, load_credentials_from_file
+
+        if self.config.service_account_path:
             credentials, project_id = load_credentials_from_file(
-                self.service_account_path
+                self.config.service_account_path
             )
         else:
             credentials, project_id = default()
+
+        if self.config.project and self.config.project != project_id:
+            logger.warning(
+                "Authenticated with project `%s`, but this %s is "
+                "configured to use the project `%s`.",
+                project_id,
+                self.type,
+                self.config.project,
+            )
+
+        # If the project was set in the configuration, use it. Otherwise, use
+        # the project that was used to authenticate.
+        project_id = self.config.project if self.config.project else project_id
         return credentials, project_id
