@@ -31,6 +31,7 @@
 
 import os
 from typing import TYPE_CHECKING, Any, Dict, Optional, Tuple, Type, cast
+from uuid import UUID
 
 import kfp
 from google.api_core import exceptions as google_exceptions
@@ -39,7 +40,9 @@ from kfp import dsl
 from kfp.v2 import dsl as dslv2
 from kfp.v2.compiler import Compiler as KFPV2Compiler
 
-from zenml.constants import ORCHESTRATOR_DOCKER_IMAGE_KEY
+from zenml.constants import (
+    METADATA_ORCHESTRATOR_URL,
+)
 from zenml.entrypoints import StepEntrypointConfiguration
 from zenml.enums import StackComponentType
 from zenml.integrations.gcp import GCP_ARTIFACT_STORE_FLAVOR
@@ -72,18 +75,18 @@ from zenml.integrations.gcp.orchestrators.vertex_scheduler.main import (
 from zenml.integrations.kubeflow.utils import apply_pod_settings
 from zenml.io import fileio
 from zenml.logger import get_logger
-from zenml.orchestrators.base_orchestrator import BaseOrchestrator
+from zenml.metadata.metadata_types import MetadataType, Uri
+from zenml.orchestrators import ContainerizedOrchestrator
 from zenml.orchestrators.utils import get_orchestrator_run_name
 from zenml.stack.stack_validator import StackValidator
 from zenml.utils.io_utils import get_global_config_directory
-from zenml.utils.pipeline_docker_image_builder import PipelineDockerImageBuilder
 
 if TYPE_CHECKING:
-    from google.auth.credentials import Credentials
-
     from zenml.config.base_settings import BaseSettings
-    from zenml.config.pipeline_deployment import PipelineDeployment
     from zenml.config.schedule import Schedule
+    from zenml.models.pipeline_deployment_models import (
+        PipelineDeploymentResponseModel,
+    )
     from zenml.stack import Stack
     from zenml.steps import ResourceSettings
 
@@ -103,7 +106,7 @@ def _clean_pipeline_name(pipeline_name: str) -> str:
     return pipeline_name.replace("_", "-").lower()
 
 
-class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
+class VertexOrchestrator(ContainerizedOrchestrator, GoogleCredentialsMixin):
     """Orchestrator responsible for running pipelines on Vertex AI."""
 
     _pipeline_root: str
@@ -196,7 +199,10 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
             return True, ""
 
         return StackValidator(
-            required_components={StackComponentType.CONTAINER_REGISTRY},
+            required_components={
+                StackComponentType.CONTAINER_REGISTRY,
+                StackComponentType.IMAGE_BUILDER,
+            },
             custom_validation_function=_validate_stack_requirements,
         )
 
@@ -221,33 +227,9 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
         """
         return os.path.join(self.root_directory, "pipelines")
 
-    def _get_authentication(self) -> Tuple["Credentials", str]:
-        """Get GCP credentials and the project ID associated with the credentials.
-
-        This function is the same as the super function except that it also checks
-        against the value of the `config` class of this orchestrator.
-
-        Returns:
-            A tuple containing the credentials and the project ID associated to
-            the credentials.
-        """
-        credentials, project_id = super()._get_authentication()
-        if self.config.project and self.config.project != project_id:
-            logger.warning(
-                "Authenticated with project `%s`, but this orchestrator is "
-                "configured to use the project `%s`.",
-                project_id,
-                self.config.project,
-            )
-
-        # If the project was set in the configuration, use it. Otherwise, use
-        # the project that was used to authenticate.
-        project_id = self.config.project if self.config.project else project_id
-        return credentials, project_id
-
     def prepare_pipeline_deployment(
         self,
-        deployment: "PipelineDeployment",
+        deployment: "PipelineDeploymentResponseModel",
         stack: "Stack",
     ) -> None:
         """Build a Docker image and push it to the container registry.
@@ -277,12 +259,6 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
                     "schedule to a Vertex orchestrator."
                 )
 
-        docker_image_builder = PipelineDockerImageBuilder()
-        repo_digest = docker_image_builder.build_and_push_docker_image(
-            deployment=deployment, stack=stack
-        )
-        deployment.add_extra(ORCHESTRATOR_DOCKER_IMAGE_KEY, repo_digest)
-
     def _configure_container_resources(
         self,
         container_op: dsl.ContainerOp,
@@ -334,7 +310,7 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
 
     def prepare_or_run_pipeline(
         self,
-        deployment: "PipelineDeployment",
+        deployment: "PipelineDeploymentResponseModel",
         stack: "Stack",
     ) -> Any:
         """Creates a KFP JSON pipeline.
@@ -377,7 +353,7 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
                 `zenml.integrations.gcp.artifact_store.GCPArtifactStore`.
         """
         orchestrator_run_name = get_orchestrator_run_name(
-            pipeline_name=deployment.pipeline.name
+            pipeline_name=deployment.pipeline_configuration.name
         )
         # If the `pipeline_root` has not been defined in the orchestrator
         # configuration,
@@ -385,7 +361,7 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
         # `GCPArtifactStore`.
         if not self.config.pipeline_root:
             artifact_store = stack.artifact_store
-            self._pipeline_root = f"{artifact_store.path.rstrip('/')}/vertex_pipeline_root/{deployment.pipeline.name}/{orchestrator_run_name}"
+            self._pipeline_root = f"{artifact_store.path.rstrip('/')}/vertex_pipeline_root/{deployment.pipeline_configuration.name}/{orchestrator_run_name}"
             logger.info(
                 "The attribute `pipeline_root` has not been set in the "
                 "orchestrator configuration. One has been generated "
@@ -397,8 +373,6 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
         else:
             self._pipeline_root = self.config.pipeline_root
 
-        image_name = deployment.pipeline.extra[ORCHESTRATOR_DOCKER_IMAGE_KEY]
-
         def _construct_kfp_pipeline() -> None:
             """Create a `ContainerOp` for each step.
 
@@ -415,10 +389,13 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
             command = StepEntrypointConfiguration.get_entrypoint_command()
             step_name_to_container_op: Dict[str, dsl.ContainerOp] = {}
 
-            for step_name, step in deployment.steps.items():
+            for step_name, step in deployment.step_configurations.items():
+                image = self.get_image(
+                    deployment=deployment, step_name=step_name
+                )
                 arguments = (
                     StepEntrypointConfiguration.get_entrypoint_arguments(
-                        step_name=step_name,
+                        step_name=step_name, deployment_id=deployment.id
                     )
                 )
 
@@ -430,7 +407,7 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
                     name: {step.config.name}
                     implementation:
                         container:
-                            image: {image_name}
+                            image: {image}
                             command: {command + arguments}"""
                 )()
 
@@ -478,7 +455,9 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
         KFPV2Compiler().compile(
             pipeline_func=_construct_kfp_pipeline,
             package_path=pipeline_file_path,
-            pipeline_name=_clean_pipeline_name(deployment.pipeline.name),
+            pipeline_name=_clean_pipeline_name(
+                deployment.pipeline_configuration.name
+            ),
         )
         logger.info(
             "Writing Vertex workflow definition to `%s`.", pipeline_file_path
@@ -493,7 +472,7 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
                 "Scheduling job using Google Cloud Scheduler and Google Cloud Functions..."
             )
             self._upload_and_schedule_pipeline(
-                pipeline_name=deployment.pipeline.name,
+                pipeline_name=deployment.pipeline_configuration.name,
                 run_name=orchestrator_run_name,
                 stack=stack,
                 schedule=deployment.schedule,
@@ -507,7 +486,7 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
             # pipeline
             # on the Vertex AI Pipelines service.
             self._upload_and_run_pipeline(
-                pipeline_name=deployment.pipeline.name,
+                pipeline_name=deployment.pipeline_configuration.name,
                 pipeline_file_path=pipeline_file_path,
                 run_name=orchestrator_run_name,
                 settings=settings,
@@ -705,3 +684,25 @@ class VertexOrchestrator(BaseOrchestrator, GoogleCredentialsMixin):
                 "Unable to read run id from environment variable "
                 f"{ENV_ZENML_VERTEX_RUN_ID}."
             )
+
+    def get_pipeline_run_metadata(
+        self, run_id: UUID
+    ) -> Dict[str, "MetadataType"]:
+        """Get general component-specific metadata for a pipeline run.
+
+        Args:
+            run_id: The ID of the pipeline run.
+
+        Returns:
+            A dictionary of metadata.
+        """
+        run_url = (
+            f"https://console.cloud.google.com/vertex-ai/locations/"
+            f"{self.config.location}/pipelines/runs/"
+            f"{self.get_orchestrator_run_id()}"
+        )
+        if self.config.project:
+            run_url += f"?project={self.config.project}"
+        return {
+            METADATA_ORCHESTRATOR_URL: Uri(run_url),
+        }
