@@ -19,14 +19,13 @@ google_cloud_ai_platform/training_clients.py
 """
 
 import time
-from typing import ClassVar, List, Optional, Tuple
+from typing import TYPE_CHECKING, Any, List, Optional, Tuple, Type, cast
 
 from google.cloud import aiplatform
-from pydantic import validator as property_validator
 
 from zenml import __version__
+from zenml.config.build_configuration import BuildConfiguration
 from zenml.enums import StackComponentType
-from zenml.integrations.gcp import GCP_VERTEX_STEP_OPERATOR_FLAVOR
 from zenml.integrations.gcp.constants import (
     CONNECTION_ERROR_RETRY_LIMIT,
     POLLING_INTERVAL_IN_SECONDS,
@@ -34,213 +33,225 @@ from zenml.integrations.gcp.constants import (
     VERTEX_JOB_STATES_COMPLETED,
     VERTEX_JOB_STATES_FAILED,
 )
+from zenml.integrations.gcp.flavors.vertex_step_operator_flavor import (
+    VertexStepOperatorConfig,
+    VertexStepOperatorSettings,
+)
 from zenml.integrations.gcp.google_credentials_mixin import (
     GoogleCredentialsMixin,
 )
 from zenml.logger import get_logger
-from zenml.repository import Repository
 from zenml.stack import Stack, StackValidator
 from zenml.step_operators import BaseStepOperator
-from zenml.utils import docker_utils
-from zenml.utils.source_utils import get_source_root_path
+
+if TYPE_CHECKING:
+    from zenml.config.base_settings import BaseSettings
+    from zenml.config.step_run_info import StepRunInfo
+    from zenml.models.pipeline_deployment_models import (
+        PipelineDeploymentBaseModel,
+    )
 
 logger = get_logger(__name__)
 
+VERTEX_DOCKER_IMAGE_KEY = "vertex_step_operator"
+
+
+def validate_accelerator_type(accelerator_type: Optional[str] = None) -> None:
+    """Validates that the accelerator type is valid.
+
+    Args:
+        accelerator_type: The accelerator type to validate.
+
+    Raises:
+        ValueError: If the accelerator type is not valid.
+    """
+    accepted_vals = list(aiplatform.gapic.AcceleratorType.__members__.keys())
+    if accelerator_type and accelerator_type.upper() not in accepted_vals:
+        raise ValueError(
+            f"Accelerator must be one of the following: {accepted_vals}"
+        )
+
 
 class VertexStepOperator(BaseStepOperator, GoogleCredentialsMixin):
     """Step operator to run a step on Vertex AI.
 
     This class defines code that can set up a Vertex AI environment and run the
     ZenML entrypoint command in it.
-
-    Attributes:
-        region: Region name, e.g., `europe-west1`.
-        project: [Optional] GCP project name. If left None, inferred from the
-            environment.
-        accelerator_type: [Optional] Accelerator type from list: https://cloud.google.com/vertex-ai/docs/reference/rest/v1/MachineSpec#AcceleratorType
-        accelerator_count: [Optional] Defines number of accelerators to be
-            used for the job.
-        machine_type: [Optional] Machine type specified here: https://cloud.google.com/vertex-ai/docs/training/configure-compute#machine-types
-        base_image: [Optional] Base image for building the custom job container.
-        encryption_spec_key_name: [Optional]: Encryption spec key name.
     """
 
-    region: str
-    project: Optional[str] = None
-    accelerator_type: Optional[str] = None
-    accelerator_count: int = 0
-    machine_type: str = "n1-standard-4"
-    base_image: Optional[str] = None
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        """Initializes the step operator and validates the accelerator type.
 
-    # customer managed encryption key resource name
-    # will be applied to all Vertex AI resources if set
-    encryption_spec_key_name: Optional[str] = None
+        Args:
+            *args: Variable length argument list.
+            **kwargs: Arbitrary keyword arguments.
+        """
+        super().__init__(*args, **kwargs)
 
-    # Class configuration
-    FLAVOR: ClassVar[str] = GCP_VERTEX_STEP_OPERATOR_FLAVOR
+    @property
+    def config(self) -> VertexStepOperatorConfig:
+        """Returns the `VertexStepOperatorConfig` config.
+
+        Returns:
+            The configuration.
+        """
+        return cast(VertexStepOperatorConfig, self._config)
+
+    @property
+    def settings_class(self) -> Optional[Type["BaseSettings"]]:
+        """Settings class for the Vertex step operator.
+
+        Returns:
+            The settings class.
+        """
+        return VertexStepOperatorSettings
 
     @property
     def validator(self) -> Optional[StackValidator]:
-        """Validates that the stack contains a container registry.
+        """Validates the stack.
 
         Returns:
-            StackValidator: Validator for the stack.
+            A validator that checks that the stack contains a remote container
+            registry and a remote artifact store.
         """
 
-        def _ensure_local_orchestrator(stack: Stack) -> Tuple[bool, str]:
-            # For now this only works on local orchestrator and GCP artifact
-            #  store
-            return (
-                (
-                    stack.orchestrator.FLAVOR == "local"
-                    and stack.artifact_store.FLAVOR == "gcp"
-                ),
-                "Only local orchestrator and GCP artifact store are currently "
-                "supported",
-            )
+        def _validate_remote_components(stack: "Stack") -> Tuple[bool, str]:
+            if stack.artifact_store.config.is_local:
+                return False, (
+                    "The Vertex step operator runs code remotely and "
+                    "needs to write files into the artifact store, but the "
+                    f"artifact store `{stack.artifact_store.name}` of the "
+                    "active stack is local. Please ensure that your stack "
+                    "contains a remote artifact store when using the Vertex "
+                    "step operator."
+                )
+
+            container_registry = stack.container_registry
+            assert container_registry is not None
+
+            if container_registry.config.is_local:
+                return False, (
+                    "The Vertex step operator runs code remotely and "
+                    "needs to push/pull Docker images, but the "
+                    f"container registry `{container_registry.name}` of the "
+                    "active stack is local. Please ensure that your stack "
+                    "contains a remote container registry when using the "
+                    "Vertex step operator."
+                )
+
+            return True, ""
 
         return StackValidator(
-            required_components={StackComponentType.CONTAINER_REGISTRY},
-            custom_validation_function=_ensure_local_orchestrator,
+            required_components={
+                StackComponentType.CONTAINER_REGISTRY,
+                StackComponentType.IMAGE_BUILDER,
+            },
+            custom_validation_function=_validate_remote_components,
         )
 
-    @property_validator("accelerator_type")
-    def validate_accelerator_enum(cls, accelerator_type: Optional[str]) -> None:
-        """Validates that the accelerator type is valid.
+    def get_docker_builds(
+        self, deployment: "PipelineDeploymentBaseModel"
+    ) -> List["BuildConfiguration"]:
+        """Gets the Docker builds required for the component.
 
         Args:
-            accelerator_type: Accelerator type
-
-        Raises:
-            ValueError: If the accelerator type is not valid.
-        """
-        accepted_vals = list(
-            aiplatform.gapic.AcceleratorType.__members__.keys()
-        )
-        if accelerator_type and accelerator_type.upper() not in accepted_vals:
-            raise ValueError(
-                f"Accelerator must be one of the following: {accepted_vals}"
-            )
-
-    def _build_and_push_docker_image(
-        self,
-        pipeline_name: str,
-        requirements: List[str],
-        entrypoint_command: List[str],
-    ) -> str:
-        """Builds and pushes a docker image.
-
-        Args:
-            pipeline_name: Pipeline name
-            requirements: Requirements
-            entrypoint_command: Entrypoint command
+            deployment: The pipeline deployment for which to get the builds.
 
         Returns:
-            Docker image name
-
-        Raises:
-            RuntimeError: If no container registry is found in the stack.
+            The required Docker builds.
         """
-        repo = Repository()
-        container_registry = repo.active_stack.container_registry
+        builds = []
+        for step_name, step in deployment.step_configurations.items():
+            if step.config.step_operator == self.name:
+                build = BuildConfiguration(
+                    key=VERTEX_DOCKER_IMAGE_KEY,
+                    settings=step.config.docker_settings,
+                    step_name=step_name,
+                )
+                builds.append(build)
 
-        if not container_registry:
-            raise RuntimeError("Missing container registry")
-
-        registry_uri = container_registry.uri.rstrip("/")
-        image_name = f"{registry_uri}/zenml-vertex:{pipeline_name}"
-
-        docker_utils.build_docker_image(
-            build_context_path=get_source_root_path(),
-            image_name=image_name,
-            entrypoint=" ".join(entrypoint_command),
-            requirements=set(requirements),
-            base_image=self.base_image,
-        )
-        container_registry.push_image(image_name)
-        return docker_utils.get_image_digest(image_name) or image_name
+        return builds
 
     def launch(
         self,
-        pipeline_name: str,
-        run_name: str,
-        requirements: List[str],
+        info: "StepRunInfo",
         entrypoint_command: List[str],
     ) -> None:
-        """Launches a step on Vertex AI.
+        """Launches a step on VertexAI.
 
         Args:
-            pipeline_name: Name of the pipeline which the step to be executed
-                is part of.
-            run_name: Name of the pipeline run which the step to be executed
-                is part of.
+            info: Information about the step run.
             entrypoint_command: Command that executes the step.
-            requirements: List of pip requirements that must be installed
-                inside the step operator environment.
 
         Raises:
             RuntimeError: If the run fails.
             ConnectionError: If the run fails due to a connection error.
         """
+        resource_settings = info.config.resource_settings
+        if resource_settings.cpu_count or resource_settings.memory:
+            logger.warning(
+                "Specifying cpus or memory is not supported for "
+                "the Vertex step operator. If you want to run this step "
+                "operator on specific resources, you can do so by configuring "
+                "a different machine_type type like this: "
+                "`zenml step-operator update %s "
+                "--machine_type=<MACHINE_TYPE>`",
+                self.name,
+            )
+        settings = cast(VertexStepOperatorSettings, self.get_settings(info))
+        validate_accelerator_type(settings.accelerator_type)
+
         job_labels = {"source": f"zenml-{__version__.replace('.', '_')}"}
 
         # Step 1: Authenticate with Google
         credentials, project_id = self._get_authentication()
-        if self.project:
-            if self.project != project_id:
-                logger.warning(
-                    "Authenticated with project `%s`, but this orchestrator is "
-                    "configured to use the project `%s`.",
-                    project_id,
-                    self.project,
-                )
-        else:
-            self.project = project_id
 
-        # Step 2: Build and push image
-        image_name = self._build_and_push_docker_image(
-            pipeline_name=pipeline_name,
-            requirements=requirements,
-            entrypoint_command=entrypoint_command,
-        )
+        image_name = info.get_image(key=VERTEX_DOCKER_IMAGE_KEY)
 
         # Step 3: Launch the job
         # The AI Platform services require regional API endpoints.
-        client_options = {"api_endpoint": self.region + VERTEX_ENDPOINT_SUFFIX}
+        client_options = {
+            "api_endpoint": self.config.region + VERTEX_ENDPOINT_SUFFIX
+        }
         # Initialize client that will be used to create and send requests.
         # This client only needs to be created once, and can be reused for multiple requests.
         client = aiplatform.gapic.JobServiceClient(
             credentials=credentials, client_options=client_options
         )
+        accelerator_count = (
+            resource_settings.gpu_count or settings.accelerator_count
+        )
         custom_job = {
-            "display_name": run_name,
+            "display_name": info.run_name,
             "job_spec": {
                 "worker_pool_specs": [
                     {
                         "machine_spec": {
-                            "machine_type": self.machine_type,
-                            "accelerator_type": self.accelerator_type,
-                            "accelerator_count": self.accelerator_count
-                            if self.accelerator_type
+                            "machine_type": settings.machine_type,
+                            "accelerator_type": settings.accelerator_type,
+                            "accelerator_count": accelerator_count
+                            if settings.accelerator_type
                             else 0,
                         },
                         "replica_count": 1,
                         "container_spec": {
                             "image_uri": image_name,
-                            "command": [],
+                            "command": entrypoint_command,
                             "args": [],
                         },
                     }
                 ]
             },
             "labels": job_labels,
-            "encryption_spec": {"kmsKeyName": self.encryption_spec_key_name}
-            if self.encryption_spec_key_name
+            "encryption_spec": {
+                "kmsKeyName": self.config.encryption_spec_key_name
+            }
+            if self.config.encryption_spec_key_name
             else {},
         }
         logger.debug("Vertex AI Job=%s", custom_job)
 
-        parent = f"projects/{self.project}/locations/{self.region}"
+        parent = f"projects/{project_id}/locations/{self.config.region}"
         logger.info(
             "Submitting custom job='%s', path='%s' to Vertex AI Training.",
             custom_job["display_name"],
