@@ -22,7 +22,6 @@ from typing import TYPE_CHECKING, Any, Dict, Optional, Tuple, cast
 from git.exc import InvalidGitRepositoryError
 from git.repo.base import Repo
 
-from zenml.constants import ORCHESTRATOR_DOCKER_IMAGE_KEY
 from zenml.container_registries import (
     BaseContainerRegistry,
     GitHubContainerRegistryFlavor,
@@ -30,6 +29,7 @@ from zenml.container_registries import (
 from zenml.entrypoints.step_entrypoint_configuration import (
     StepEntrypointConfiguration,
 )
+from zenml.enums import StackComponentType
 from zenml.integrations.github.flavors.github_actions_orchestrator_flavor import (
     GitHubActionsOrchestratorConfig,
 )
@@ -39,17 +39,15 @@ from zenml.integrations.github.secrets_managers.github_secrets_manager import (
 )
 from zenml.io import fileio
 from zenml.logger import get_logger
-from zenml.orchestrators import BaseOrchestrator
+from zenml.orchestrators import ContainerizedOrchestrator
 from zenml.secrets_managers.base_secrets_manager import BaseSecretsManager
-from zenml.stack import Stack
+from zenml.stack import Stack, StackValidator
 from zenml.utils import yaml_utils
-from zenml.utils.pipeline_docker_image_builder import PipelineDockerImageBuilder
 
 if TYPE_CHECKING:
-    from zenml.config.pipeline_deployment import PipelineDeployment
-
-from zenml.enums import StackComponentType
-from zenml.stack import StackValidator
+    from zenml.models.pipeline_deployment_models import (
+        PipelineDeploymentResponseModel,
+    )
 
 logger = get_logger(__name__)
 
@@ -61,7 +59,7 @@ DOCKER_LOGIN_ACTION = "docker/login-action@v1"
 ENV_ZENML_GH_ACTIONS_RUN_ID = "ZENML_GH_ACTIONS_RUN_ID"
 
 
-class GitHubActionsOrchestrator(BaseOrchestrator):
+class GitHubActionsOrchestrator(ContainerizedOrchestrator):
     """Orchestrator responsible for running pipelines using GitHub Actions."""
 
     _git_repo: Optional[Repo] = None
@@ -100,7 +98,9 @@ class GitHubActionsOrchestrator(BaseOrchestrator):
                 remote_url.startswith(prefix)
                 for prefix in GITHUB_REMOTE_URL_PREFIXES
             )
-            if not (is_github_repo or self.config.skip_github_repository_check):
+            if not (
+                is_github_repo or self.config.skip_github_repository_check
+            ):
                 raise RuntimeError(
                     f"The remote URL '{remote_url}' of your git repo "
                     f"({self._git_repo.git_dir}) is not pointing to a GitHub "
@@ -172,7 +172,10 @@ class GitHubActionsOrchestrator(BaseOrchestrator):
             return True, ""
 
         return StackValidator(
-            required_components={StackComponentType.CONTAINER_REGISTRY},
+            required_components={
+                StackComponentType.CONTAINER_REGISTRY,
+                StackComponentType.IMAGE_BUILDER,
+            },
             custom_validation_function=_validate_local_requirements,
         )
 
@@ -287,7 +290,7 @@ class GitHubActionsOrchestrator(BaseOrchestrator):
 
     def prepare_pipeline_deployment(
         self,
-        deployment: "PipelineDeployment",
+        deployment: "PipelineDeploymentResponseModel",
         stack: "Stack",
     ) -> None:
         """Build a Docker image and push it to the container registry.
@@ -312,15 +315,9 @@ class GitHubActionsOrchestrator(BaseOrchestrator):
                 "--skip_dirty_repository_check=true`"
             )
 
-        docker_image_builder = PipelineDockerImageBuilder()
-        repo_digest = docker_image_builder.build_and_push_docker_image(
-            deployment=deployment, stack=stack
-        )
-        deployment.add_extra(ORCHESTRATOR_DOCKER_IMAGE_KEY, repo_digest)
-
     def prepare_or_run_pipeline(
         self,
-        deployment: "PipelineDeployment",
+        deployment: "PipelineDeploymentResponseModel",
         stack: "Stack",
     ) -> Any:
         """Writes a GitHub Action workflow yaml and optionally pushes it.
@@ -335,11 +332,11 @@ class GitHubActionsOrchestrator(BaseOrchestrator):
         """
         schedule = deployment.schedule
 
-        workflow_name = deployment.pipeline.name
+        workflow_name = deployment.pipeline_configuration.name
         if schedule:
             # Add a suffix to the workflow filename so we don't overwrite
             # scheduled pipeline by future schedules or single pipeline runs.
-            datetime_string = datetime.now().strftime("%y_%m_%d_%H_%M_%S")
+            datetime_string = datetime.utcnow().strftime("%y_%m_%d_%H_%M_%S")
             workflow_name += f"-scheduled-{datetime_string}"
 
         workflow_path = os.path.join(
@@ -398,8 +395,6 @@ class GitHubActionsOrchestrator(BaseOrchestrator):
             )
             workflow_dict["on"] = {"push": {"paths": [workflow_path_in_repo]}}
 
-        image_name = deployment.pipeline.extra[ORCHESTRATOR_DOCKER_IMAGE_KEY]
-
         # Prepare the step that writes an environment file which will get
         # passed to the docker image
         env_file_name = ".zenml_docker_env"
@@ -418,11 +413,10 @@ class GitHubActionsOrchestrator(BaseOrchestrator):
             "docker",
             "run",
             *docker_run_args,
-            image_name,
-        ] + StepEntrypointConfiguration.get_entrypoint_command()
+        ]
 
         jobs = {}
-        for step_name, step in deployment.steps.items():
+        for step_name, step in deployment.step_configurations.items():
             if self.requires_resources_in_orchestration_environment(step):
                 logger.warning(
                     "Specifying step resources is not supported for the "
@@ -440,13 +434,20 @@ class GitHubActionsOrchestrator(BaseOrchestrator):
             if docker_login_step:
                 job_steps.append(copy.deepcopy(docker_login_step))
 
+            image = self.get_image(deployment=deployment, step_name=step_name)
+
+            entrypoint_command = (
+                StepEntrypointConfiguration.get_entrypoint_command()
+            )
             entrypoint_args = (
                 StepEntrypointConfiguration.get_entrypoint_arguments(
-                    step_name=step_name,
+                    step_name=step_name, deployment_id=deployment.id
                 )
             )
 
-            command = base_command + entrypoint_args
+            command = (
+                base_command + [image] + entrypoint_command + entrypoint_args
+            )
             docker_run_step = {
                 "name": "Run the docker image",
                 "run": " ".join(command),
@@ -471,7 +472,7 @@ class GitHubActionsOrchestrator(BaseOrchestrator):
             self.git_repo.index.add(workflow_path)
             self.git_repo.index.commit(
                 "[ZenML GitHub Actions Orchestrator] Add github workflow for "
-                f"pipeline {deployment.pipeline.name}."
+                f"pipeline {deployment.pipeline_configuration.name}."
             )
             self.git_repo.remote().push()
             logger.info("Pushed workflow file '%s'", workflow_path)
