@@ -26,9 +26,9 @@ from great_expectations.exceptions import (  # type: ignore[import]
     StoreBackendError,
 )
 
+from zenml.client import Client
 from zenml.io import fileio
 from zenml.logger import get_logger
-from zenml.repository import Repository
 from zenml.utils import io_utils
 
 logger = get_logger(__name__)
@@ -52,14 +52,16 @@ class ZenMLArtifactStoreBackend(TupleStoreBackend):  # type: ignore[misc]
         """
         super().__init__(**kwargs)
 
-        repo = Repository(skip_repository_check=True)  # type: ignore[call-arg]
-        artifact_store = repo.active_stack.artifact_store
-        self.root_path = os.path.join(artifact_store.path, "great_expectations")
+        client = Client()
+        artifact_store = client.active_stack.artifact_store
+        self.root_path = os.path.join(
+            artifact_store.path, "great_expectations"
+        )
 
         # extract the protocol used in the artifact store root path
         protocols = [
             scheme
-            for scheme in artifact_store.SUPPORTED_SCHEMES
+            for scheme in artifact_store.config.SUPPORTED_SCHEMES
             if self.root_path.startswith(scheme)
         ]
         if protocols:
@@ -101,7 +103,7 @@ class ZenMLArtifactStoreBackend(TupleStoreBackend):  # type: ignore[misc]
             The file path pointing to where the object is stored.
         """
         if not isinstance(key, tuple):
-            key = key.to_tuple()  # type: ignore[attr-defined]
+            key = key.to_tuple()
         if not is_prefix:
             object_relative_path = self._convert_key_to_filepath(key)
         elif key:
