@@ -14,17 +14,22 @@
 """Implementation of the Huggingface datasets materializer."""
 
 import os
+from collections import defaultdict
 from tempfile import TemporaryDirectory, mkdtemp
-from typing import Any, Type
+from typing import TYPE_CHECKING, Dict, Type, Union
 
-from datasets import Dataset, load_from_disk  # type: ignore[attr-defined]
+from datasets import Dataset, load_from_disk
 from datasets.dataset_dict import DatasetDict
 
-from zenml.artifacts import DataArtifact
+from zenml.enums import ArtifactType
 from zenml.io import fileio
 from zenml.materializers.base_materializer import BaseMaterializer
+from zenml.materializers.pandas_materializer import PandasMaterializer
 from zenml.utils import io_utils
 
+if TYPE_CHECKING:
+    from zenml.metadata.metadata_types import MetadataType
+
 DEFAULT_DATASET_DIR = "hf_datasets"
 
 
@@ -32,9 +37,11 @@ class HFDatasetMaterializer(BaseMaterializer):
     """Materializer to read data to and from huggingface datasets."""
 
     ASSOCIATED_TYPES = (Dataset, DatasetDict)
-    ASSOCIATED_ARTIFACT_TYPES = (DataArtifact,)
+    ASSOCIATED_ARTIFACT_TYPE = ArtifactType.DATA_ANALYSIS
 
-    def handle_input(self, data_type: Type[Any]) -> Dataset:
+    def load(
+        self, data_type: Union[Type[Dataset], Type[DatasetDict]]
+    ) -> Union[Dataset, DatasetDict]:
         """Reads Dataset.
 
         Args:
@@ -43,28 +50,57 @@ class HFDatasetMaterializer(BaseMaterializer):
         Returns:
             The dataset read from the specified dir.
         """
-        super().handle_input(data_type)
+        super().load(data_type)
         temp_dir = mkdtemp()
         io_utils.copy_dir(
-            os.path.join(self.artifact.uri, DEFAULT_DATASET_DIR),
+            os.path.join(self.uri, DEFAULT_DATASET_DIR),
             temp_dir,
         )
         return load_from_disk(temp_dir)
 
-    def handle_return(self, ds: Type[Any]) -> None:
+    def save(self, ds: Union[Dataset, DatasetDict]) -> None:
         """Writes a Dataset to the specified dir.
 
         Args:
             ds: The Dataset to write.
         """
-        super().handle_return(ds)
+        super().save(ds)
         temp_dir = TemporaryDirectory()
         path = os.path.join(temp_dir.name, DEFAULT_DATASET_DIR)
         try:
             ds.save_to_disk(path)
             io_utils.copy_dir(
                 path,
-                os.path.join(self.artifact.uri, DEFAULT_DATASET_DIR),
+                os.path.join(self.uri, DEFAULT_DATASET_DIR),
             )
         finally:
             fileio.rmtree(temp_dir.name)
+
+    def extract_metadata(
+        self, ds: Union[Dataset, DatasetDict]
+    ) -> Dict[str, "MetadataType"]:
+        """Extract metadata from the given `Dataset` object.
+
+        Args:
+            ds: The `Dataset` object to extract metadata from.
+
+        Returns:
+            The extracted metadata as a dictionary.
+
+        Raises:
+            ValueError: If the given object is not a `Dataset` or `DatasetDict`.
+        """
+        super().extract_metadata(ds)
+        pandas_materializer = PandasMaterializer(self.uri)
+        if isinstance(ds, Dataset):
+            return pandas_materializer.extract_metadata(ds.to_pandas())
+        elif isinstance(ds, DatasetDict):
+            metadata: Dict[str, Dict[str, "MetadataType"]] = defaultdict(dict)
+            for dataset_name, dataset in ds.items():
+                dataset_metadata = pandas_materializer.extract_metadata(
+                    dataset.to_pandas()
+                )
+                for key, value in dataset_metadata.items():
+                    metadata[key][dataset_name] = value
+            return dict(metadata)
+        raise ValueError(f"Unsupported type {type(ds)}")
