@@ -30,7 +30,9 @@ from kserve import KServeClient, V1beta1InferenceService, constants, utils
 from kubernetes import client
 
 from zenml.client import Client
+from zenml.config.build_configuration import BuildConfiguration
 from zenml.config.global_config import GlobalConfiguration
+from zenml.enums import StackComponentType
 from zenml.integrations.kserve.constants import (
     KSERVE_CUSTOM_DEPLOYMENT,
     KSERVE_DOCKER_IMAGE_KEY,
@@ -48,12 +50,13 @@ from zenml.logger import get_logger
 from zenml.model_deployers import BaseModelDeployer, BaseModelDeployerFlavor
 from zenml.secrets_managers.base_secrets_manager import BaseSecretsManager
 from zenml.services.service import BaseService, ServiceConfig
-from zenml.stack.stack import Stack
+from zenml.stack import StackValidator
 from zenml.utils.analytics_utils import AnalyticsEvent, event_handler
-from zenml.utils.pipeline_docker_image_builder import PipelineDockerImageBuilder
 
 if TYPE_CHECKING:
-    from zenml.config.pipeline_deployment import PipelineDeployment
+    from zenml.models.pipeline_deployment_models import (
+        PipelineDeploymentBaseModel,
+    )
 
 logger = get_logger(__name__)
 
@@ -77,6 +80,20 @@ class KServeModelDeployer(BaseModelDeployer):
         """
         return cast(KServeModelDeployerConfig, self._config)
 
+    @property
+    def validator(self) -> Optional[StackValidator]:
+        """Ensures there is a container registry and image builder in the stack.
+
+        Returns:
+            A `StackValidator` instance.
+        """
+        return StackValidator(
+            required_components={
+                StackComponentType.CONTAINER_REGISTRY,
+                StackComponentType.IMAGE_BUILDER,
+            }
+        )
+
     @staticmethod
     def get_model_server_info(  # type: ignore[override]
         service_instance: "KServeDeploymentService",
@@ -110,28 +127,28 @@ class KServeModelDeployer(BaseModelDeployer):
             )
         return self._client
 
-    def prepare_pipeline_deployment(
-        self,
-        deployment: "PipelineDeployment",
-        stack: "Stack",
-    ) -> None:
-        """Build a Docker image and push it to the container registry.
+    def get_docker_builds(
+        self, deployment: "PipelineDeploymentBaseModel"
+    ) -> List["BuildConfiguration"]:
+        """Gets the Docker builds required for the component.
 
         Args:
-            deployment: The pipeline deployment configuration.
-            stack: The stack on which the pipeline will be deployed.
-        """
-        needs_docker_image = False
-        for step in deployment.steps.values():
-            if step.config.extra.get(KSERVE_CUSTOM_DEPLOYMENT, False) is True:
-                needs_docker_image = True
+            deployment: The pipeline deployment for which to get the builds.
 
-        if needs_docker_image:
-            docker_image_builder = PipelineDockerImageBuilder()
-            repo_digest = docker_image_builder.build_and_push_docker_image(
-                deployment=deployment, stack=stack
-            )
-            deployment.add_extra(KSERVE_DOCKER_IMAGE_KEY, repo_digest)
+        Returns:
+            The required Docker builds.
+        """
+        builds = []
+        for step_name, step in deployment.step_configurations.items():
+            if step.config.extra.get(KSERVE_CUSTOM_DEPLOYMENT, False) is True:
+                build = BuildConfiguration(
+                    key=KSERVE_DOCKER_IMAGE_KEY,
+                    settings=step.config.docker_settings,
+                    step_name=step_name,
+                )
+                builds.append(build)
+
+        return builds
 
     def _set_credentials(self) -> None:
         """Set the credentials for the given service instance.
