@@ -1,4 +1,4 @@
-#  Copyright (c) ZenML GmbH 2021. All Rights Reserved.
+#  Copyright (c) ZenML GmbH 2022. All Rights Reserved.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -17,14 +17,12 @@ The Kubeflow integration sub-module powers an alternative to the local
 orchestrator. You can enable it by registering the Kubeflow orchestrator with
 the CLI tool.
 """
-from typing import List
+from typing import List, Type
 
-from zenml.enums import StackComponentType
 from zenml.integrations.constants import KUBEFLOW
 from zenml.integrations.integration import Integration
-from zenml.zen_stores.models import FlavorWrapper
+from zenml.stack import Flavor
 
-KUBEFLOW_METADATA_STORE_FLAVOR = "kubeflow"
 KUBEFLOW_ORCHESTRATOR_FLAVOR = "kubeflow"
 
 
@@ -32,29 +30,20 @@ class KubeflowIntegration(Integration):
     """Definition of Kubeflow Integration for ZenML."""
 
     NAME = KUBEFLOW
-    REQUIREMENTS = ["kfp==1.8.9"]
+    REQUIREMENTS = ["kfp==1.8.16"]
 
     @classmethod
-    def flavors(cls) -> List[FlavorWrapper]:
+    def flavors(cls) -> List[Type[Flavor]]:
         """Declare the stack component flavors for the Kubeflow integration.
 
         Returns:
             List of stack component flavors for this integration.
         """
-        return [
-            FlavorWrapper(
-                name=KUBEFLOW_METADATA_STORE_FLAVOR,
-                source="zenml.integrations.kubeflow.metadata_stores.KubeflowMetadataStore",
-                type=StackComponentType.METADATA_STORE,
-                integration=cls.NAME,
-            ),
-            FlavorWrapper(
-                name=KUBEFLOW_ORCHESTRATOR_FLAVOR,
-                source="zenml.integrations.kubeflow.orchestrators.KubeflowOrchestrator",
-                type=StackComponentType.ORCHESTRATOR,
-                integration=cls.NAME,
-            ),
-        ]
+        from zenml.integrations.kubeflow.flavors import (
+            KubeflowOrchestratorFlavor,
+        )
+
+        return [KubeflowOrchestratorFlavor]
 
 
 KubeflowIntegration.check_installation()
