@@ -14,20 +14,27 @@
 """Entrypoint of the Kubernetes master/orchestrator pod."""
 
 import argparse
-import json
 import socket
-from typing import List
 
 from kubernetes import client as k8s_client
 
+from zenml.client import Client
+from zenml.entrypoints.step_entrypoint_configuration import (
+    StepEntrypointConfiguration,
+)
+from zenml.integrations.kubernetes.flavors.kubernetes_orchestrator_flavor import (
+    KubernetesOrchestratorSettings,
+)
 from zenml.integrations.kubernetes.orchestrators import kube_utils
-from zenml.integrations.kubernetes.orchestrators.dag_runner import (
-    ThreadedDagRunner,
+from zenml.integrations.kubernetes.orchestrators.kubernetes_orchestrator import (
+    ENV_ZENML_KUBERNETES_RUN_ID,
+    KubernetesOrchestrator,
 )
 from zenml.integrations.kubernetes.orchestrators.manifest_utils import (
     build_pod_manifest,
 )
 from zenml.logger import get_logger
+from zenml.orchestrators.dag_runner import ThreadedDagRunner
 
 logger = get_logger(__name__)
 
@@ -40,48 +47,11 @@ def parse_args() -> argparse.Namespace:
     """
     parser = argparse.ArgumentParser()
     parser.add_argument("--run_name", type=str, required=True)
-    parser.add_argument("--pipeline_name", type=str, required=True)
-    parser.add_argument("--image_name", type=str, required=True)
+    parser.add_argument("--deployment_id", type=str, required=True)
     parser.add_argument("--kubernetes_namespace", type=str, required=True)
-    parser.add_argument("--pipeline_config", type=json.loads, required=True)
     return parser.parse_args()
 
 
-def patch_run_name_for_cron_scheduling(
-    run_name: str, fixed_step_args: List[str]
-) -> str:
-    """Adjust run name according to the Kubernetes orchestrator pod name.
-
-    This is required for scheduling via CRON jobs, since each job would
-    otherwise have the same run name, which zenml does not support.
-
-    Args:
-        run_name: Initial run name.
-        fixed_step_args: Fixed entrypoint args for the step pods.
-            We also need to patch the run name in there.
-
-    Returns:
-        New unique run name.
-    """
-    # Get name of the orchestrator pod.
-    host_name = socket.gethostname()
-
-    # If we are not running as CRON job, we don't need to do anything.
-    if host_name == kube_utils.sanitize_pod_name(run_name):
-        return run_name
-
-    # Otherwise, define new run_name.
-    job_id = host_name.split("-")[-1]
-    run_name = f"{run_name}-{job_id}"
-
-    # Then also adjust run_name in fixed_step_args.
-    for i, arg in enumerate(fixed_step_args):
-        if arg == "--run_name":
-            fixed_step_args[i + 1] = run_name
-
-    return run_name
-
-
 def main() -> None:
     """Entrypoint of the k8s master/orchestrator pod."""
     # Log to the container's stdout so it can be streamed by the client.
@@ -89,20 +59,28 @@ def main() -> None:
 
     # Parse / extract args.
     args = parse_args()
-    pipeline_config = args.pipeline_config
-    step_command = pipeline_config["step_command"]
-    fixed_step_args = pipeline_config["fixed_step_args"]
-    step_specific_args = pipeline_config["step_specific_args"]
-    pipeline_dag = pipeline_config["pipeline_dag"]
 
     # Get Kubernetes Core API for running kubectl commands later.
     kube_utils.load_kube_config()
     core_api = k8s_client.CoreV1Api()
 
-    # Patch run name (only needed for CRON scheduling)
-    run_name = patch_run_name_for_cron_scheduling(
-        args.run_name, fixed_step_args
-    )
+    orchestrator_run_id = socket.gethostname()
+
+    deployment_config = Client().get_deployment(args.deployment_id)
+
+    pipeline_dag = {}
+    step_name_to_pipeline_step_name = {}
+    for (
+        name_in_pipeline,
+        step,
+    ) in deployment_config.step_configurations.items():
+        step_name_to_pipeline_step_name[step.config.name] = name_in_pipeline
+        pipeline_dag[step.config.name] = step.spec.upstream_steps
+
+    step_command = StepEntrypointConfiguration.get_entrypoint_command()
+
+    active_stack = Client().active_stack
+    mount_local_stores = active_stack.orchestrator.config.is_local
 
     def run_step_on_kubernetes(step_name: str) -> None:
         """Run a pipeline step in a separate Kubernetes pod.
@@ -111,20 +89,35 @@ def main() -> None:
             step_name: Name of the step.
         """
         # Define Kubernetes pod name.
-        pod_name = f"{run_name}-{step_name}"
+        pod_name = f"{orchestrator_run_id}-{step_name}"
         pod_name = kube_utils.sanitize_pod_name(pod_name)
 
-        # Build list of args for this step.
-        step_args = [*fixed_step_args, *step_specific_args[step_name]]
+        pipeline_step_name = step_name_to_pipeline_step_name[step_name]
+        image = KubernetesOrchestrator.get_image(
+            deployment=deployment_config, step_name=pipeline_step_name
+        )
+        step_args = StepEntrypointConfiguration.get_entrypoint_arguments(
+            step_name=pipeline_step_name, deployment_id=deployment_config.id
+        )
+
+        step_config = deployment_config.step_configurations[
+            pipeline_step_name
+        ].config
+        settings = KubernetesOrchestratorSettings.parse_obj(
+            step_config.settings.get("orchestrator.kubernetes", {})
+        )
 
         # Define Kubernetes pod manifest.
         pod_manifest = build_pod_manifest(
             pod_name=pod_name,
-            run_name=run_name,
-            pipeline_name=args.pipeline_name,
-            image_name=args.image_name,
+            run_name=args.run_name,
+            pipeline_name=deployment_config.pipeline_configuration.name,
+            image_name=image,
             command=step_command,
             args=step_args,
+            env={ENV_ZENML_KUBERNETES_RUN_ID: orchestrator_run_id},
+            settings=settings,
+            mount_local_stores=mount_local_stores,
         )
 
         # Create and run pod.
