@@ -15,14 +15,17 @@
 
 import os
 import tempfile
-from typing import Any, Type
+from typing import TYPE_CHECKING, Any, Dict, Type
 
 import lightgbm as lgb
 
-from zenml.artifacts import DataArtifact
+from zenml.enums import ArtifactType
 from zenml.io import fileio
 from zenml.materializers.base_materializer import BaseMaterializer
 
+if TYPE_CHECKING:
+    from zenml.metadata.metadata_types import MetadataType
+
 DEFAULT_FILENAME = "data.binary"
 
 
@@ -30,9 +33,9 @@ class LightGBMDatasetMaterializer(BaseMaterializer):
     """Materializer to read data to and from lightgbm.Dataset."""
 
     ASSOCIATED_TYPES = (lgb.Dataset,)
-    ASSOCIATED_ARTIFACT_TYPES = (DataArtifact,)
+    ASSOCIATED_ARTIFACT_TYPE = ArtifactType.DATA
 
-    def handle_input(self, data_type: Type[Any]) -> lgb.Dataset:
+    def load(self, data_type: Type[Any]) -> lgb.Dataset:
         """Reads a lightgbm.Dataset binary file and loads it.
 
         Args:
@@ -41,8 +44,8 @@ class LightGBMDatasetMaterializer(BaseMaterializer):
         Returns:
             A lightgbm.Dataset object.
         """
-        super().handle_input(data_type)
-        filepath = os.path.join(self.artifact.uri, DEFAULT_FILENAME)
+        super().load(data_type)
+        filepath = os.path.join(self.uri, DEFAULT_FILENAME)
 
         # Create a temporary folder
         temp_dir = tempfile.mkdtemp(prefix="zenml-temp-")
@@ -55,14 +58,14 @@ class LightGBMDatasetMaterializer(BaseMaterializer):
         # No clean up this time because matrix is lazy loaded
         return matrix
 
-    def handle_return(self, matrix: lgb.Dataset) -> None:
+    def save(self, matrix: lgb.Dataset) -> None:
         """Creates a binary serialization for a lightgbm.Dataset object.
 
         Args:
             matrix: A lightgbm.Dataset object.
         """
-        super().handle_return(matrix)
-        filepath = os.path.join(self.artifact.uri, DEFAULT_FILENAME)
+        super().save(matrix)
+        filepath = os.path.join(self.uri, DEFAULT_FILENAME)
 
         # Make a temporary phantom artifact
         temp_dir = tempfile.mkdtemp(prefix="zenml-temp-")
@@ -72,3 +75,19 @@ class LightGBMDatasetMaterializer(BaseMaterializer):
         # Copy it into artifact store
         fileio.copy(temp_file, filepath)
         fileio.rmtree(temp_dir)
+
+    def extract_metadata(
+        self, matrix: lgb.Dataset
+    ) -> Dict[str, "MetadataType"]:
+        """Extract metadata from the given `Dataset` object.
+
+        Args:
+            matrix: The `Dataset` object to extract metadata from.
+
+        Returns:
+            The extracted metadata as a dictionary.
+        """
+        super().extract_metadata(matrix)
+        return {
+            "shape": (matrix.num_data(), matrix.num_feature()),
+        }
