@@ -1,4 +1,4 @@
-#  Copyright (c) ZenML GmbH 2022. All Rights Reserved.
+#  Copyright (c) ZenML GmbH 2023. All Rights Reserved.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 """Initialization of the MLflow standard interface steps."""
 
 from zenml.integrations.mlflow.steps.mlflow_deployer import (
-    MLFlowDeployerConfig,
+    MLFlowDeployerParameters,
     mlflow_deployer_step,
     mlflow_model_deployer_step,
 )
