@@ -13,6 +13,8 @@
 #  permissions and limitations under the License.
 """Initialization of the PyTorch integration."""
 
+import platform
+from typing import List, Optional
 from zenml.integrations.constants import PYTORCH
 from zenml.integrations.integration import Integration
 from zenml.utils.source_utils import import_class_by_path
