@@ -14,15 +14,19 @@
 """Implementation of the PyTorch Module materializer."""
 
 import os
-from typing import Any, Type
+from typing import TYPE_CHECKING, Any, Dict, Type, cast
 
 import torch
-from torch.nn import Module  # type: ignore[attr-defined]
+from torch.nn import Module
 
-from zenml.artifacts import ModelArtifact
+from zenml.enums import ArtifactType
+from zenml.integrations.pytorch.utils import count_module_params
 from zenml.io import fileio
 from zenml.materializers.base_materializer import BaseMaterializer
 
+if TYPE_CHECKING:
+    from zenml.metadata.metadata_types import MetadataType
+
 DEFAULT_FILENAME = "entire_model.pt"
 CHECKPOINT_FILENAME = "checkpoint.pt"
 
@@ -35,9 +39,9 @@ class PyTorchModuleMaterializer(BaseMaterializer):
     """
 
     ASSOCIATED_TYPES = (Module,)
-    ASSOCIATED_ARTIFACT_TYPES = (ModelArtifact,)
+    ASSOCIATED_ARTIFACT_TYPE = ArtifactType.MODEL
 
-    def handle_input(self, data_type: Type[Any]) -> Module:
+    def load(self, data_type: Type[Any]) -> Module:
         """Reads and returns a PyTorch model.
 
         Only loads the model, not the checkpoint.
@@ -48,31 +52,39 @@ class PyTorchModuleMaterializer(BaseMaterializer):
         Returns:
             A loaded pytorch model.
         """
-        super().handle_input(data_type)
-        with fileio.open(
-            os.path.join(self.artifact.uri, DEFAULT_FILENAME), "rb"
-        ) as f:
-            return torch.load(f)  # type: ignore[no-untyped-call]  # noqa
+        super().load(data_type)
+        with fileio.open(os.path.join(self.uri, DEFAULT_FILENAME), "rb") as f:
+            return cast(Module, torch.load(f))
 
-    def handle_return(self, model: Module) -> None:
+    def save(self, model: Module) -> None:
         """Writes a PyTorch model, as a model and a checkpoint.
 
         Args:
             model: A torch.nn.Module or a dict to pass into model.save
         """
-        super().handle_return(model)
+        super().save(model)
 
         # Save entire model to artifact directory, This is the default behavior
         # for loading model in development phase (training, evaluation)
-        with fileio.open(
-            os.path.join(self.artifact.uri, DEFAULT_FILENAME), "wb"
-        ) as f:
+        with fileio.open(os.path.join(self.uri, DEFAULT_FILENAME), "wb") as f:
             torch.save(model, f)
 
         # Also save model checkpoint to artifact directory,
         # This is the default behavior for loading model in production phase (inference)
         if isinstance(model, Module):
             with fileio.open(
-                os.path.join(self.artifact.uri, CHECKPOINT_FILENAME), "wb"
+                os.path.join(self.uri, CHECKPOINT_FILENAME), "wb"
             ) as f:
                 torch.save(model.state_dict(), f)
+
+    def extract_metadata(self, model: Module) -> Dict[str, "MetadataType"]:
+        """Extract metadata from the given `Model` object.
+
+        Args:
+            model: The `Model` object to extract metadata from.
+
+        Returns:
+            The extracted metadata as a dictionary.
+        """
+        super().extract_metadata(model)
+        return {**count_module_params(model)}
