@@ -16,12 +16,12 @@
 The S3 integration allows the use of cloud artifact stores and file
 operations on S3 buckets.
 """
-from typing import List
+from typing import List, Type
 
 from zenml.enums import StackComponentType
 from zenml.integrations.constants import S3
 from zenml.integrations.integration import Integration
-from zenml.zen_stores.models import FlavorWrapper
+from zenml.stack import Flavor
 
 S3_ARTIFACT_STORE_FLAVOR = "s3"
 
@@ -30,23 +30,18 @@ class S3Integration(Integration):
     """Definition of S3 integration for ZenML."""
 
     NAME = S3
-    REQUIREMENTS = ["s3fs==2022.3.0"]
+    REQUIREMENTS = ["s3fs>2022.3.0,<=2022.11.0"]
 
     @classmethod
-    def flavors(cls) -> List[FlavorWrapper]:
+    def flavors(cls) -> List[Type[Flavor]]:
         """Declare the stack component flavors for the s3 integration.
 
         Returns:
             List of stack component flavors for this integration.
         """
-        return [
-            FlavorWrapper(
-                name=S3_ARTIFACT_STORE_FLAVOR,
-                source="zenml.integrations.s3.artifact_stores.S3ArtifactStore",
-                type=StackComponentType.ARTIFACT_STORE,
-                integration=cls.NAME,
-            )
-        ]
+        from zenml.integrations.s3.flavors import S3ArtifactStoreFlavor
+
+        return [S3ArtifactStoreFlavor]
 
 
 S3Integration.check_installation()
