@@ -14,13 +14,14 @@
 """Implementation of the Scipy Sparse Materializer."""
 
 import os
-from typing import Any, Type
+from typing import Any, Dict, Type
 
 from scipy.sparse import load_npz, save_npz, spmatrix
 
-from zenml.artifacts import DataArtifact
+from zenml.enums import ArtifactType
 from zenml.io import fileio
 from zenml.materializers.base_materializer import BaseMaterializer
+from zenml.metadata.metadata_types import DType, MetadataType
 
 DATA_FILENAME = "data.npz"
 
@@ -29,9 +30,9 @@ class SparseMaterializer(BaseMaterializer):
     """Materializer to read and write scipy sparse matrices."""
 
     ASSOCIATED_TYPES = (spmatrix,)
-    ASSOCIATED_ARTIFACT_TYPES = (DataArtifact,)
+    ASSOCIATED_ARTIFACT_TYPE = ArtifactType.DATA
 
-    def handle_input(self, data_type: Type[Any]) -> spmatrix:
+    def load(self, data_type: Type[Any]) -> spmatrix:
         """Reads spmatrix from npz file.
 
         Args:
@@ -40,21 +41,33 @@ class SparseMaterializer(BaseMaterializer):
         Returns:
             A spmatrix object.
         """
-        super().handle_input(data_type)
-        with fileio.open(
-            os.path.join(self.artifact.uri, DATA_FILENAME), "rb"
-        ) as f:
+        super().load(data_type)
+        with fileio.open(os.path.join(self.uri, DATA_FILENAME), "rb") as f:
             mat = load_npz(f)
         return mat
 
-    def handle_return(self, mat: spmatrix) -> None:
+    def save(self, mat: spmatrix) -> None:
         """Writes a spmatrix to the artifact store as a npz file.
 
         Args:
             mat: The spmatrix to write.
         """
-        super().handle_return(mat)
-        with fileio.open(
-            os.path.join(self.artifact.uri, DATA_FILENAME), "wb"
-        ) as f:
+        super().save(mat)
+        with fileio.open(os.path.join(self.uri, DATA_FILENAME), "wb") as f:
             save_npz(f, mat)
+
+    def extract_metadata(self, mat: spmatrix) -> Dict[str, "MetadataType"]:
+        """Extract metadata from the given `spmatrix` object.
+
+        Args:
+            mat: The `spmatrix` object to extract metadata from.
+
+        Returns:
+            The extracted metadata as a dictionary.
+        """
+        super().extract_metadata(mat)
+        return {
+            "shape": mat.shape,
+            "dtype": DType(mat.dtype),
+            "nnz": mat.nnz,
+        }
