@@ -19,6 +19,8 @@ from typing import TYPE_CHECKING, ClassVar, Dict, List, Optional, Type, cast
 from uuid import UUID
 
 from zenml.client import Client
+from zenml.config.build_configuration import BuildConfiguration
+from zenml.enums import StackComponentType
 from zenml.integrations.seldon.constants import (
     SELDON_CUSTOM_DEPLOYMENT,
     SELDON_DOCKER_IMAGE_KEY,
@@ -36,12 +38,13 @@ from zenml.logger import get_logger
 from zenml.model_deployers import BaseModelDeployer, BaseModelDeployerFlavor
 from zenml.secrets_managers import BaseSecretsManager
 from zenml.services.service import BaseService, ServiceConfig
-from zenml.stack.stack import Stack
+from zenml.stack import StackValidator
 from zenml.utils.analytics_utils import AnalyticsEvent, event_handler
-from zenml.utils.pipeline_docker_image_builder import PipelineDockerImageBuilder
 
 if TYPE_CHECKING:
-    from zenml.config.pipeline_deployment import PipelineDeployment
+    from zenml.models.pipeline_deployment_models import (
+        PipelineDeploymentBaseModel,
+    )
 
 logger = get_logger(__name__)
 
@@ -65,6 +68,20 @@ class SeldonModelDeployer(BaseModelDeployer):
         """
         return cast(SeldonModelDeployerConfig, self._config)
 
+    @property
+    def validator(self) -> Optional[StackValidator]:
+        """Ensures there is a container registry and image builder in the stack.
+
+        Returns:
+            A `StackValidator` instance.
+        """
+        return StackValidator(
+            required_components={
+                StackComponentType.CONTAINER_REGISTRY,
+                StackComponentType.IMAGE_BUILDER,
+            }
+        )
+
     @staticmethod
     def get_model_server_info(  # type: ignore[override]
         service_instance: "SeldonDeploymentService",
@@ -111,7 +128,9 @@ class SeldonModelDeployer(BaseModelDeployer):
             The Seldon Core Kubernetes secret name, or None if no secret is
             configured.
         """
-        if not self.config.secret:
+        if self.config.kubernetes_secret_name and not self.config.secret:
+            return self.config.kubernetes_secret_name
+        elif not self.config.secret:
             return None
         return (
             re.sub(
@@ -123,28 +142,28 @@ class SeldonModelDeployer(BaseModelDeployer):
             .lower()
         )
 
-    def prepare_pipeline_deployment(
-        self,
-        deployment: "PipelineDeployment",
-        stack: "Stack",
-    ) -> None:
-        """Build a Docker image and push it to the container registry.
+    def get_docker_builds(
+        self, deployment: "PipelineDeploymentBaseModel"
+    ) -> List["BuildConfiguration"]:
+        """Gets the Docker builds required for the component.
 
         Args:
-            deployment: The pipeline deployment configuration.
-            stack: The stack on which the pipeline will be deployed.
-        """
-        needs_docker_image = False
-        for step in deployment.steps.values():
-            if step.config.extra.get(SELDON_CUSTOM_DEPLOYMENT, False) is True:
-                needs_docker_image = True
+            deployment: The pipeline deployment for which to get the builds.
 
-        if needs_docker_image:
-            docker_image_builder = PipelineDockerImageBuilder()
-            repo_digest = docker_image_builder.build_and_push_docker_image(
-                deployment=deployment, stack=stack
-            )
-            deployment.add_extra(SELDON_DOCKER_IMAGE_KEY, repo_digest)
+        Returns:
+            The required Docker builds.
+        """
+        builds = []
+        for step_name, step in deployment.step_configurations.items():
+            if step.config.extra.get(SELDON_CUSTOM_DEPLOYMENT, False) is True:
+                build = BuildConfiguration(
+                    key=SELDON_DOCKER_IMAGE_KEY,
+                    settings=step.config.docker_settings,
+                    step_name=step_name,
+                )
+                builds.append(build)
+
+        return builds
 
     def _create_or_update_kubernetes_secret(self) -> Optional[str]:
         """Create or update a Kubernetes secret.
@@ -161,7 +180,9 @@ class SeldonModelDeployer(BaseModelDeployer):
         # if a ZenML secret was configured in the model deployer,
         # create a Kubernetes secret as a means to pass this information
         # to the Seldon Core deployment
-        if self.config.secret:
+        if self.config.kubernetes_secret_name and not self.config.secret:
+            return self.config.kubernetes_secret_name
+        elif self.config.secret:
 
             secret_manager = Client().active_stack.secrets_manager
 
@@ -196,7 +217,11 @@ class SeldonModelDeployer(BaseModelDeployer):
 
         Do this if no Seldon Core deployments are using it.
         """
-        if self.kubernetes_secret_name:
+        if (
+            self.kubernetes_secret_name
+            and self.kubernetes_secret_name
+            != self.config.kubernetes_secret_name
+        ):
 
             # fetch all the Seldon Core deployments that currently
             # configured to use this secret
@@ -275,7 +300,8 @@ class SeldonModelDeployer(BaseModelDeployer):
             # SeldonDeploymentConfig, try to create one from the ZenML secret
             # configured for the model deployer
             config.secret_name = (
-                config.secret_name or self._create_or_update_kubernetes_secret()
+                config.secret_name
+                or self._create_or_update_kubernetes_secret()
             )
 
             # if replace is True, find equivalent Seldon Core deployments
