@@ -17,7 +17,7 @@ import base64
 import json
 import re
 import time
-from typing import Dict, Generator, List, Optional
+from typing import Any, Dict, Generator, List, Optional
 
 from kubernetes import client as k8s_client
 from kubernetes import config as k8s_config
@@ -29,11 +29,46 @@ from zenml.utils.enum_utils import StrEnum
 
 logger = get_logger(__name__)
 
+api = k8s_client.ApiClient()
 
 SELDON_DEPLOYMENT_KIND = "SeldonDeployment"
 SELDON_DEPLOYMENT_API_VERSION = "machinelearning.seldon.io/v1"
 
 
+class SeldonDeploymentPredictorParameter(BaseModel):
+    """Parameter for Seldon Deployment predictor.
+
+    Attributes:
+        name: parameter name
+        type: parameter, can be INT, FLOAT, DOUBLE, STRING, BOOL
+        value: parameter value
+    """
+
+    name: str = ""
+    type: str = ""
+    value: str = ""
+
+    class Config:
+        """Pydantic configuration class."""
+
+        # validate attribute assignments
+        validate_assignment = True
+        # Ignore extra attributes from the CRD that are not reflected here
+        extra = "ignore"
+
+
+class SeldonResourceRequirements(BaseModel):
+    """Resource requirements for a Seldon deployed model.
+
+    Attributes:
+        limits: an upper limit of resources to be used by the model
+        requests: resources requested by the model
+    """
+
+    limits: Dict[str, str] = Field(default_factory=dict)
+    requests: Dict[str, str] = Field(default_factory=dict)
+
+
 class SeldonDeploymentMetadata(BaseModel):
     """Metadata for a Seldon Deployment.
 
@@ -92,6 +127,7 @@ class SeldonDeploymentPredictiveUnit(BaseModel):
     ] = SeldonDeploymentPredictiveUnitType.MODEL
     implementation: Optional[str]
     modelUri: Optional[str]
+    parameters: Optional[List[SeldonDeploymentPredictorParameter]]
     serviceAccountName: Optional[str]
     envSecretRefName: Optional[str]
     children: List["SeldonDeploymentPredictiveUnit"] = Field(
@@ -107,6 +143,25 @@ class SeldonDeploymentPredictiveUnit(BaseModel):
         extra = "ignore"
 
 
+class SeldonDeploymentComponentSpecs(BaseModel):
+    """Component specs for a Seldon Deployment.
+
+    Attributes:
+        spec: the component spec.
+    """
+
+    spec: Optional[Dict[str, Any]]
+    # TODO [HIGH]: Add graph field to ComponentSpecs. graph: Optional[SeldonDeploymentPredictiveUnit]
+
+    class Config:
+        """Pydantic configuration class."""
+
+        # validate attribute assignments
+        validate_assignment = True
+        # Ignore extra attributes from the CRD that are not reflected here
+        extra = "ignore"
+
+
 class SeldonDeploymentPredictor(BaseModel):
     """Seldon Deployment predictor.
 
@@ -118,9 +173,13 @@ class SeldonDeploymentPredictor(BaseModel):
 
     name: str
     replicas: int = 1
-    graph: SeldonDeploymentPredictiveUnit = Field(
+    graph: Optional[SeldonDeploymentPredictiveUnit] = Field(
         default_factory=SeldonDeploymentPredictiveUnit
     )
+    engineResources: Optional[SeldonResourceRequirements] = Field(
+        default_factory=SeldonResourceRequirements
+    )
+    componentSpecs: Optional[List[SeldonDeploymentComponentSpecs]]
 
     class Config:
         """Pydantic configuration class."""
@@ -261,9 +320,13 @@ class SeldonDeployment(BaseModel):
         model_uri: Optional[str] = None,
         model_name: Optional[str] = None,
         implementation: Optional[str] = None,
+        parameters: Optional[List[SeldonDeploymentPredictorParameter]] = None,
+        engineResources: Optional[SeldonResourceRequirements] = None,
         secret_name: Optional[str] = None,
         labels: Optional[Dict[str, str]] = None,
         annotations: Optional[Dict[str, str]] = None,
+        is_custom_deployment: Optional[bool] = False,
+        spec: Optional[Dict[Any, Any]] = None,
     ) -> "SeldonDeployment":
         """Build a basic Seldon Deployment object.
 
@@ -273,12 +336,16 @@ class SeldonDeployment(BaseModel):
             model_uri: The URI of the model.
             model_name: The name of the model.
             implementation: The implementation of the model.
+            parameters: The predictor graph parameters.
+            engineResources: The resources to be allocated to the model.
             secret_name: The name of the Kubernetes secret containing
                 environment variable values (e.g. with credentials for the
                 artifact store) to use with the deployment service.
             labels: A dictionary of labels to apply to the Seldon Deployment.
             annotations: A dictionary of annotations to apply to the Seldon
                 Deployment.
+            spec: A Kubernetes pod spec to use for the Seldon Deployment.
+            is_custom_deployment: Whether the Seldon Deployment is a custom or a built-in one.
 
         Returns:
             A minimal SeldonDeployment object built from the provided
@@ -292,25 +359,45 @@ class SeldonDeployment(BaseModel):
         if annotations is None:
             annotations = {}
 
+        if is_custom_deployment:
+            predictors = [
+                SeldonDeploymentPredictor(
+                    name=model_name or "",
+                    graph=SeldonDeploymentPredictiveUnit(
+                        name="classifier",
+                        type=SeldonDeploymentPredictiveUnitType.MODEL,
+                        parameters=parameters,
+                    ),
+                    engineResources=engineResources,
+                    componentSpecs=[
+                        SeldonDeploymentComponentSpecs(
+                            spec=spec
+                            # TODO [HIGH]: Add support for other component types (e.g. graph)
+                        )
+                    ],
+                )
+            ]
+        else:
+            predictors = [
+                SeldonDeploymentPredictor(
+                    name=model_name or "",
+                    graph=SeldonDeploymentPredictiveUnit(
+                        name="classifier",
+                        type=SeldonDeploymentPredictiveUnitType.MODEL,
+                        modelUri=model_uri or "",
+                        implementation=implementation or "",
+                        envSecretRefName=secret_name,
+                        parameters=parameters,
+                    ),
+                    engineResources=engineResources,
+                )
+            ]
+
         return SeldonDeployment(
             metadata=SeldonDeploymentMetadata(
                 name=name, labels=labels, annotations=annotations
             ),
-            spec=SeldonDeploymentSpec(
-                name=name,
-                predictors=[
-                    SeldonDeploymentPredictor(
-                        name=model_name or "",
-                        graph=SeldonDeploymentPredictiveUnit(
-                            name="default",
-                            type=SeldonDeploymentPredictiveUnitType.MODEL,
-                            modelUri=model_uri or "",
-                            implementation=implementation or "",
-                            envSecretRefName=secret_name,
-                        ),
-                    )
-                ],
-            ),
+            spec=SeldonDeploymentSpec(name=name, predictors=predictors),
         )
 
     def is_managed_by_zenml(self) -> bool:
@@ -546,13 +633,16 @@ class SeldonClient:
             # are not
             deployment.mark_as_managed_by_zenml()
 
-            response = self._custom_objects_api.create_namespaced_custom_object(
-                group="machinelearning.seldon.io",
-                version="v1",
-                namespace=self._namespace,
-                plural="seldondeployments",
-                body=deployment.dict(exclude_none=True),
-                _request_timeout=poll_timeout or None,
+            body_deploy = deployment.dict(exclude_none=True)
+            response = (
+                self._custom_objects_api.create_namespaced_custom_object(
+                    group="machinelearning.seldon.io",
+                    version="v1",
+                    namespace=self._namespace,
+                    plural="seldondeployments",
+                    body=body_deploy,
+                    _request_timeout=poll_timeout or None,
+                )
             )
             logger.debug("Seldon Core API response: %s", response)
         except k8s_client.rest.ApiException as e:
@@ -607,14 +697,16 @@ class SeldonClient:
             # a SeldonDeploymentNotFoundError otherwise
             self.get_deployment(name=name)
 
-            response = self._custom_objects_api.delete_namespaced_custom_object(
-                group="machinelearning.seldon.io",
-                version="v1",
-                namespace=self._namespace,
-                plural="seldondeployments",
-                name=name,
-                _request_timeout=poll_timeout or None,
-                grace_period_seconds=0 if force else None,
+            response = (
+                self._custom_objects_api.delete_namespaced_custom_object(
+                    group="machinelearning.seldon.io",
+                    version="v1",
+                    namespace=self._namespace,
+                    plural="seldondeployments",
+                    name=name,
+                    _request_timeout=poll_timeout or None,
+                    grace_period_seconds=0 if force else None,
+                )
             )
             logger.debug("Seldon Core API response: %s", response)
         except k8s_client.rest.ApiException as e:
@@ -1024,3 +1116,90 @@ class SeldonClient:
             raise SeldonClientError(
                 f"Exception when deleting Secret resource {name}"
             ) from e
+
+
+def create_seldon_core_custom_spec(
+    model_uri: Optional[str],
+    custom_docker_image: Optional[str],
+    secret_name: Optional[str],
+    command: Optional[List[str]],
+    container_registry_secret_name: Optional[str] = None,
+) -> k8s_client.V1PodSpec:
+    """Create a custom pod spec for the seldon core container.
+
+    Args:
+        model_uri: The URI of the model to load.
+        custom_docker_image: The docker image to use.
+        secret_name: The name of the secret to use.
+        command: The command to run in the container.
+        container_registry_secret_name: The name of the secret to use for docker image pull.
+
+    Returns:
+        A pod spec for the seldon core container.
+    """
+    volume = k8s_client.V1Volume(
+        name="classifier-provision-location",
+        empty_dir={},
+    )
+    init_container = k8s_client.V1Container(
+        name="classifier-model-initializer",
+        image="seldonio/rclone-storage-initializer:1.14.0-dev",
+        image_pull_policy="IfNotPresent",
+        args=[model_uri, "/mnt/models"],
+        volume_mounts=[
+            k8s_client.V1VolumeMount(
+                name="classifier-provision-location", mount_path="/mnt/models"
+            )
+        ],
+        env_from=[
+            k8s_client.V1EnvFromSource(
+                secret_ref=k8s_client.V1SecretEnvSource(
+                    name=secret_name, optional=False
+                )
+            )
+        ],
+    )
+    image_pull_secret = k8s_client.V1LocalObjectReference(
+        name=container_registry_secret_name
+    )
+    container = k8s_client.V1Container(
+        name="classifier",
+        image=custom_docker_image,
+        image_pull_policy="IfNotPresent",
+        command=command,
+        volume_mounts=[
+            k8s_client.V1VolumeMount(
+                name="classifier-provision-location",
+                mount_path="/mnt/models",
+                read_only=True,
+            )
+        ],
+        ports=[
+            k8s_client.V1ContainerPort(container_port=5000),
+            k8s_client.V1ContainerPort(container_port=9000),
+        ],
+    )
+
+    if image_pull_secret:
+        spec = k8s_client.V1PodSpec(
+            volumes=[
+                volume,
+            ],
+            init_containers=[
+                init_container,
+            ],
+            image_pull_secrets=[image_pull_secret],
+            containers=[container],
+        )
+    else:
+        spec = k8s_client.V1PodSpec(
+            volumes=[
+                volume,
+            ],
+            init_containers=[
+                init_container,
+            ],
+            containers=[container],
+        )
+
+    return api.sanitize_for_serialization(spec)
