@@ -14,6 +14,8 @@
 """Initialization for Seldon steps."""
 
 from zenml.integrations.seldon.steps.seldon_deployer import (
-    SeldonDeployerStepConfig,
+    CustomDeployParameters,
+    SeldonDeployerStepParameters,
+    seldon_custom_model_deployer_step,
     seldon_model_deployer_step,
 )
