@@ -20,14 +20,11 @@ from slack_sdk import WebClient
 from slack_sdk.errors import SlackApiError
 from slack_sdk.rtm import RTMClient
 
-from zenml.alerter.base_alerter import BaseAlerter
+from zenml.alerter.base_alerter import BaseAlerter, BaseAlerterStepParameters
 from zenml.integrations.slack.flavors.slack_alerter_flavor import (
     SlackAlerterConfig,
 )
 from zenml.logger import get_logger
-from zenml.steps.step_interfaces.base_alerter_step import (
-    BaseAlerterStepParameters,
-)
 
 logger = get_logger(__name__)
 
