@@ -13,6 +13,8 @@
 #  permissions and limitations under the License.
 """Initialization for TensorFlow integration."""
 
+import platform
+from typing import List, Optional
 from zenml.integrations.constants import TENSORFLOW
 from zenml.integrations.integration import Integration
 
@@ -21,16 +23,43 @@ class TensorflowIntegration(Integration):
     """Definition of Tensorflow integration for ZenML."""
 
     NAME = TENSORFLOW
-    REQUIREMENTS = ["tensorflow==2.8.0", "tensorflow_io==0.24.0"]
+    REQUIREMENTS = []
 
     @classmethod
     def activate(cls) -> None:
         """Activates the integration."""
         # need to import this explicitly to load the Tensorflow file IO support
         # for S3 and other file systems
-        import tensorflow_io  # type: ignore [import]
+        if (
+            not platform.system() == "Darwin"
+            or not platform.machine() == "arm64"
+        ):
+            import tensorflow_io  # type: ignore [import]
 
         from zenml.integrations.tensorflow import materializers  # noqa
 
+    @classmethod
+    def get_requirements(cls, target_os: Optional[str] = None) -> List[str]:
+        """Defines platform specific requirements for the integration.
+
+        Args:
+            target_os: The target operating system.
+
+        Returns:
+            A list of requirements.
+        """
+        target_os = target_os or platform.system()
+        if target_os == "Darwin" and platform.machine() == "arm64":
+            requirements = [
+                "tensorflow-macos>=2.8.0",
+            ]
+        else:
+            requirements = [
+                "tensorflow==2.8.0",
+                "tensorflow_io==0.24.0",
+                "protobuf>=3.6.0,<4.0.0",
+            ]
+        return requirements
+
 
 TensorflowIntegration.check_installation()
