@@ -15,15 +15,18 @@
 
 import os
 import tempfile
-from typing import Any, Type
+from typing import TYPE_CHECKING, Any, Dict, Type
 
 import tensorflow as tf
 
-from zenml.artifacts import DataArtifact
+from zenml.enums import ArtifactType
 from zenml.io import fileio
 from zenml.materializers.base_materializer import BaseMaterializer
 from zenml.utils import io_utils
 
+if TYPE_CHECKING:
+    from zenml.metadata.metadata_types import MetadataType
+
 DEFAULT_FILENAME = "saved_data"
 
 
@@ -31,9 +34,9 @@ class TensorflowDatasetMaterializer(BaseMaterializer):
     """Materializer to read data to and from tf.data.Dataset."""
 
     ASSOCIATED_TYPES = (tf.data.Dataset,)
-    ASSOCIATED_ARTIFACT_TYPES = (DataArtifact,)
+    ASSOCIATED_ARTIFACT_TYPE = ArtifactType.DATA
 
-    def handle_input(self, data_type: Type[Any]) -> Any:
+    def load(self, data_type: Type[Any]) -> Any:
         """Reads data into tf.data.Dataset.
 
         Args:
@@ -42,28 +45,44 @@ class TensorflowDatasetMaterializer(BaseMaterializer):
         Returns:
             A tf.data.Dataset object.
         """
-        super().handle_input(data_type)
+        super().load(data_type)
         temp_dir = tempfile.mkdtemp()
-        io_utils.copy_dir(self.artifact.uri, temp_dir)
+        io_utils.copy_dir(self.uri, temp_dir)
         path = os.path.join(temp_dir, DEFAULT_FILENAME)
         dataset = tf.data.experimental.load(path)
         # Don't delete the temporary directory here as the dataset is lazily
         # loaded and needs to read it when the object gets used
         return dataset
 
-    def handle_return(self, dataset: tf.data.Dataset) -> None:
+    def save(self, dataset: tf.data.Dataset) -> None:
         """Persists a tf.data.Dataset object.
 
         Args:
             dataset: The dataset to persist.
         """
-        super().handle_return(dataset)
+        super().save(dataset)
         temp_dir = tempfile.TemporaryDirectory()
         path = os.path.join(temp_dir.name, DEFAULT_FILENAME)
         try:
             tf.data.experimental.save(
                 dataset, path, compression=None, shard_func=None
             )
-            io_utils.copy_dir(temp_dir.name, self.artifact.uri)
+            io_utils.copy_dir(temp_dir.name, self.uri)
         finally:
             fileio.rmtree(temp_dir.name)
+
+    def extract_metadata(
+        self, dataset: tf.data.Dataset
+    ) -> Dict[str, "MetadataType"]:
+        """Extract metadata from the given `Dataset` object.
+
+        Args:
+            dataset: The `Dataset` object to extract metadata from.
+
+        Returns:
+            The extracted metadata as a dictionary.
+        """
+        super().extract_metadata(dataset)
+        return {
+            "length": len(dataset),
+        }
