@@ -26,7 +26,9 @@ from zenml.materializers.built_in_materializer import (
 )
 from zenml.materializers.numpy_materializer import NumpyMaterializer
 from zenml.materializers.pandas_materializer import PandasMaterializer
+from zenml.materializers.pydantic_materializer import PydanticMaterializer
 from zenml.materializers.service_materializer import ServiceMaterializer
+from zenml.materializers.unmaterialized_artifact import UnmaterializedArtifact
 
 __all__ = [
     "BuiltInContainerMaterializer",
@@ -34,5 +36,7 @@ __all__ = [
     "BytesMaterializer",
     "NumpyMaterializer",
     "PandasMaterializer",
+    "PydanticMaterializer",
     "ServiceMaterializer",
+    "UnmaterializedArtifact",
 ]
