@@ -14,10 +14,9 @@
 """Implementation of ZenML's builtin materializer."""
 
 import os
-from typing import Any, Iterable, Type
+from typing import TYPE_CHECKING, Any, Dict, Iterable, Type, Union
 
-from zenml.artifacts import DataAnalysisArtifact, DataArtifact
-from zenml.artifacts.base_artifact import BaseArtifact
+from zenml.enums import ArtifactType
 from zenml.io import fileio
 from zenml.logger import get_logger
 from zenml.materializers.base_materializer import BaseMaterializer
@@ -26,32 +25,39 @@ from zenml.materializers.default_materializer_registry import (
 )
 from zenml.utils import yaml_utils
 
+if TYPE_CHECKING:
+    from zenml.metadata.metadata_types import MetadataType
+
 logger = get_logger(__name__)
 DEFAULT_FILENAME = "data.json"
 DEFAULT_BYTES_FILENAME = "data.txt"
 DEFAULT_METADATA_FILENAME = "metadata.json"
-BASIC_TYPES = (bool, float, int, str)  # complex/bytes are not JSON serializable
+BASIC_TYPES = (
+    bool,
+    float,
+    int,
+    str,
+)  # complex/bytes are not JSON serializable
 
 
 class BuiltInMaterializer(BaseMaterializer):
     """Handle JSON-serializable basic types (`bool`, `float`, `int`, `str`)."""
 
-    ASSOCIATED_ARTIFACT_TYPES = (
-        DataArtifact,
-        DataAnalysisArtifact,
-    )
+    ASSOCIATED_ARTIFACT_TYPE = ArtifactType.DATA
     ASSOCIATED_TYPES = BASIC_TYPES
 
-    def __init__(self, artifact: "BaseArtifact"):
+    def __init__(self, uri: str):
         """Define `self.data_path`.
 
         Args:
-            artifact: Artifact required by `BaseMaterializer.__init__()`.
+            uri: The URI where the artifact data is stored.
         """
-        super().__init__(artifact)
-        self.data_path = os.path.join(self.artifact.uri, DEFAULT_FILENAME)
+        super().__init__(uri)
+        self.data_path = os.path.join(self.uri, DEFAULT_FILENAME)
 
-    def handle_input(self, data_type: Type[Any]) -> Any:
+    def load(
+        self, data_type: Union[Type[bool], Type[float], Type[int], Type[str]]
+    ) -> Any:
         """Reads basic primitive types from JSON.
 
         Args:
@@ -60,7 +66,7 @@ class BuiltInMaterializer(BaseMaterializer):
         Returns:
             The data read.
         """
-        super().handle_input(data_type)
+        super().load(data_type)
         contents = yaml_utils.read_json(self.data_path)
         if type(contents) != data_type:
             # TODO [ENG-142]: Raise error or try to coerce
@@ -70,32 +76,53 @@ class BuiltInMaterializer(BaseMaterializer):
             )
         return contents
 
-    def handle_return(self, data: Any) -> None:
+    def save(self, data: Union[bool, float, int, str]) -> None:
         """Serialize a basic type to JSON.
 
         Args:
             data: The data to store.
         """
-        super().handle_return(data)
+        super().save(data)
         yaml_utils.write_json(self.data_path, data)
 
+    def extract_metadata(
+        self, data: Union[bool, float, int, str]
+    ) -> Dict[str, "MetadataType"]:
+        """Extract metadata from the given built-in container object.
+
+        Args:
+            data: The built-in container object to extract metadata from.
+
+        Returns:
+            The extracted metadata as a dictionary.
+        """
+        base_metadata = super().extract_metadata(data)
+        builtin_metadata: Dict[str, "MetadataType"] = {}
+
+        # For boolean and numbers, add the string representation as metadata.
+        # We don't to this for strings because they can be arbitrarily long.
+        if isinstance(data, (bool, float, int)):
+            builtin_metadata["string_representation"] = str(data)
+
+        return {**base_metadata, **builtin_metadata}
+
 
 class BytesMaterializer(BaseMaterializer):
     """Handle `bytes` data type, which is not JSON serializable."""
 
-    ASSOCIATED_ARTIFACT_TYPES = (DataArtifact, DataAnalysisArtifact)
+    ASSOCIATED_ARTIFACT_TYPE = ArtifactType.DATA
     ASSOCIATED_TYPES = (bytes,)
 
-    def __init__(self, artifact: "BaseArtifact"):
+    def __init__(self, uri: str):
         """Define `self.data_path`.
 
         Args:
-            artifact: Artifact required by `BaseMaterializer.__init__()`.
+            uri: The URI where the artifact data is stored.
         """
-        super().__init__(artifact)
-        self.data_path = os.path.join(self.artifact.uri, DEFAULT_BYTES_FILENAME)
+        super().__init__(uri)
+        self.data_path = os.path.join(self.uri, DEFAULT_BYTES_FILENAME)
 
-    def handle_input(self, data_type: Type[Any]) -> Any:
+    def load(self, data_type: Type[Any]) -> Any:
         """Reads a bytes object from file.
 
         Args:
@@ -104,17 +131,17 @@ class BytesMaterializer(BaseMaterializer):
         Returns:
             The data read.
         """
-        super().handle_input(data_type)
+        super().load(data_type)
         with fileio.open(self.data_path, "rb") as file_:
             return file_.read()
 
-    def handle_return(self, data: Any) -> None:
+    def save(self, data: Any) -> None:
         """Save a bytes object to file.
 
         Args:
             data: The data to store.
         """
-        super().handle_return(data)
+        super().save(data)
         with fileio.open(self.data_path, "wb") as file_:
             file_.write(data)
 
@@ -147,7 +174,9 @@ def _is_serializable(obj: Any) -> bool:
     if isinstance(obj, (list, tuple, set)):
         return _all_serializable(obj)
     if isinstance(obj, dict):
-        return _all_serializable(obj.keys()) and _all_serializable(obj.values())
+        return _all_serializable(obj.keys()) and _all_serializable(
+            obj.values()
+        )
     return False
 
 
@@ -216,19 +245,17 @@ class BuiltInContainerMaterializer(BaseMaterializer):
 
     ASSOCIATED_TYPES = (dict, list, set, tuple)
 
-    def __init__(self, artifact: "BaseArtifact"):
+    def __init__(self, uri: str):
         """Define `self.data_path` and `self.metadata_path`.
 
         Args:
-            artifact: Artifact required by `BaseMaterializer.__init__()`.
+            uri: The URI where the artifact data is stored.
         """
-        super().__init__(artifact)
-        self.data_path = os.path.join(self.artifact.uri, DEFAULT_FILENAME)
-        self.metadata_path = os.path.join(
-            self.artifact.uri, DEFAULT_METADATA_FILENAME
-        )
+        super().__init__(uri)
+        self.data_path = os.path.join(self.uri, DEFAULT_FILENAME)
+        self.metadata_path = os.path.join(self.uri, DEFAULT_METADATA_FILENAME)
 
-    def handle_input(self, data_type: Type[Any]) -> Any:
+    def load(self, data_type: Type[Any]) -> Any:
         """Reads a materialized built-in container object.
 
         If the data was serialized to JSON, deserialize it.
@@ -236,9 +263,8 @@ class BuiltInContainerMaterializer(BaseMaterializer):
         Otherwise, reconstruct all elements according to the metadata file:
             1. Resolve the data type using `find_type_by_str()`,
             2. Get the materializer via the `default_materializer_registry`,
-            3. Initialize the materializer with a mock `DataArtifact`, whose
-                `uri` attribute is overwritten to point to the desired path,
-            4. Use `handle_input()` of that materializer to load the element.
+            3. Initialize the materializer with the desired path,
+            4. Use `load()` of that materializer to load the element.
 
         Args:
             data_type: The type of the data to read.
@@ -249,7 +275,7 @@ class BuiltInContainerMaterializer(BaseMaterializer):
         Raises:
             RuntimeError: If the data was not found.
         """
-        super().handle_input(data_type)
+        super().load(data_type)
 
         # If the data was not serialized, there must be metadata present.
         if not fileio.exists(self.data_path) and not fileio.exists(
@@ -271,9 +297,8 @@ class BuiltInContainerMaterializer(BaseMaterializer):
             for path_, type_str in zip(metadata["paths"], metadata["types"]):
                 type_ = find_type_by_str(type_str)
                 materializer_class = default_materializer_registry[type_]
-                mock_artifact = DataArtifact(uri=path_)
-                materializer = materializer_class(mock_artifact)
-                element = materializer.handle_input(type_)
+                materializer = materializer_class(uri=path_)
+                element = materializer.load(type_)
                 outputs.append(element)
 
         # Cast the data to the correct type.
@@ -286,7 +311,7 @@ class BuiltInContainerMaterializer(BaseMaterializer):
             return set(outputs)
         return outputs
 
-    def handle_return(self, data: Any) -> None:
+    def save(self, data: Any) -> None:
         """Materialize a built-in container object.
 
         If the object can be serialized to JSON, serialize it.
@@ -305,7 +330,7 @@ class BuiltInContainerMaterializer(BaseMaterializer):
         Raises:
             Exception: If any exception occurs, it is raised after cleanup.
         """
-        super().handle_return(data)
+        super().save(data)
 
         # tuple and set: handle as list.
         if isinstance(data, tuple) or isinstance(data, set):
@@ -324,15 +349,13 @@ class BuiltInContainerMaterializer(BaseMaterializer):
         # Get path, type, and corresponding materializer for each element.
         paths, types, materializers = [], [], []
         for i, element in enumerate(data):
-            element_path = os.path.join(self.artifact.uri, str(i))
+            element_path = os.path.join(self.uri, str(i))
             fileio.mkdir(element_path)
             type_ = find_materializer_registry_type(type(element))
             paths.append(element_path)
             types.append(str(type_))
             materializer_class = default_materializer_registry[type_]
-            mock_artifact = DataArtifact(uri=element_path)
-            mock_artifact.uri = element_path
-            materializer = materializer_class(mock_artifact)
+            materializer = materializer_class(uri=element_path)
             materializers.append(materializer)
         try:
             # Write metadata as JSON.
@@ -340,7 +363,7 @@ class BuiltInContainerMaterializer(BaseMaterializer):
             yaml_utils.write_json(self.metadata_path, metadata)
             # Materialize each element.
             for element, materializer in zip(data, materializers):
-                materializer.handle_return(element)
+                materializer.save(element)
         # If an error occurs, delete all created files.
         except Exception as e:
             # Delete metadata
@@ -350,3 +373,20 @@ class BuiltInContainerMaterializer(BaseMaterializer):
             for element_path in paths:
                 fileio.rmtree(element_path)
             raise e
+
+    def extract_metadata(self, data: Any) -> Dict[str, "MetadataType"]:
+        """Extract metadata from the given built-in container object.
+
+        Args:
+            data: The built-in container object to extract metadata from.
+
+        Returns:
+            The extracted metadata as a dictionary.
+        """
+        base_metadata = super().extract_metadata(data)
+        container_metadata = {}
+        if hasattr(data, "__len__"):
+            container_metadata = {
+                "length": len(data),
+            }
+        return {**base_metadata, **container_metadata}
