@@ -14,14 +14,15 @@
 """Implementation of the ZenML NumPy materializer."""
 
 import os
-from typing import TYPE_CHECKING, Any, Type, cast
+from typing import TYPE_CHECKING, Any, Dict, Type, cast
 
 import numpy as np
 
-from zenml.artifacts import DataArtifact
+from zenml.enums import ArtifactType
 from zenml.io import fileio
 from zenml.logger import get_logger
 from zenml.materializers.base_materializer import BaseMaterializer
+from zenml.metadata.metadata_types import DType, MetadataType
 
 if TYPE_CHECKING:
     from numpy.typing import NDArray
@@ -40,9 +41,9 @@ class NumpyMaterializer(BaseMaterializer):
     """Materializer to read data to and from pandas."""
 
     ASSOCIATED_TYPES = (np.ndarray,)
-    ASSOCIATED_ARTIFACT_TYPES = (DataArtifact,)
+    ASSOCIATED_ARTIFACT_TYPE = ArtifactType.DATA
 
-    def handle_input(self, data_type: Type[Any]) -> "Any":
+    def load(self, data_type: Type[Any]) -> "Any":
         """Reads a numpy array from a `.npy` file.
 
         Args:
@@ -55,9 +56,9 @@ class NumpyMaterializer(BaseMaterializer):
         Returns:
             The numpy array.
         """
-        super().handle_input(data_type)
+        super().load(data_type)
 
-        numpy_file = os.path.join(self.artifact.uri, NUMPY_FILENAME)
+        numpy_file = os.path.join(self.uri, NUMPY_FILENAME)
 
         if fileio.exists(numpy_file):
             with fileio.open(numpy_file, "rb") as f:
@@ -67,7 +68,7 @@ class NumpyMaterializer(BaseMaterializer):
                 # about either an untyped function call or an unused ignore
                 # statement
                 return cast(Any, np.load)(f, allow_pickle=True)
-        elif fileio.exists(os.path.join(self.artifact.uri, DATA_FILENAME)):
+        elif fileio.exists(os.path.join(self.uri, DATA_FILENAME)):
             logger.warning(
                 "A legacy artifact was found. "
                 "This artifact was created with an older version of "
@@ -83,11 +84,11 @@ class NumpyMaterializer(BaseMaterializer):
 
                 # Read numpy array from parquet file
                 shape_dict = yaml_utils.read_json(
-                    os.path.join(self.artifact.uri, SHAPE_FILENAME)
+                    os.path.join(self.uri, SHAPE_FILENAME)
                 )
                 shape_tuple = tuple(shape_dict.values())
                 with fileio.open(
-                    os.path.join(self.artifact.uri, DATA_FILENAME), "rb"
+                    os.path.join(self.uri, DATA_FILENAME), "rb"
                 ) as f:
                     input_stream = pa.input_stream(f)
                     data = pq.read_table(input_stream)
@@ -101,19 +102,47 @@ class NumpyMaterializer(BaseMaterializer):
                     "You can install `pyarrow` by running `pip install pyarrow`.",
                 )
 
-    def handle_return(self, arr: "NDArray[Any]") -> None:
+    def save(self, arr: "NDArray[Any]") -> None:
         """Writes a np.ndarray to the artifact store as a `.npy` file.
 
         Args:
             arr: The numpy array to write.
         """
-        super().handle_return(arr)
-        with fileio.open(
-            os.path.join(self.artifact.uri, NUMPY_FILENAME), "wb"
-        ) as f:
+        super().save(arr)
+        with fileio.open(os.path.join(self.uri, NUMPY_FILENAME), "wb") as f:
             # This function is untyped for numpy versions supporting python
             # 3.7, but typed for numpy versions installed on python 3.8+.
             # We need to cast it to any here so that numpy doesn't complain
             # about either an untyped function call or an unused ignore
             # statement
             cast(Any, np.save)(f, arr)
+
+    def extract_metadata(
+        self, arr: "NDArray[Any]"
+    ) -> Dict[str, "MetadataType"]:
+        """Extract metadata from the given numpy array.
+
+        Args:
+            arr: The numpy array to extract metadata from.
+
+        Returns:
+            The extracted metadata as a dictionary.
+        """
+        base_metadata = super().extract_metadata(arr)
+
+        # These functions are untyped for numpy versions supporting python
+        # 3.7, but typed for numpy versions installed on python 3.8+.
+        # We need to cast them to Any here so that numpy doesn't complain
+        # about either an untyped function call or an unused ignore statement.
+        min_val = cast(Any, np.min)(arr).item()
+        max_val = cast(Any, np.max)(arr).item()
+
+        numpy_metadata: Dict[str, "MetadataType"] = {
+            "shape": tuple(arr.shape),
+            "dtype": DType(arr.dtype.type),
+            "mean": np.mean(arr).item(),
+            "std": np.std(arr).item(),
+            "min": min_val,
+            "max": max_val,
+        }
+        return {**base_metadata, **numpy_metadata}
