@@ -15,13 +15,13 @@
 
 import time
 from datetime import datetime
-from typing import TYPE_CHECKING, Dict, Tuple
+from typing import TYPE_CHECKING, Dict, Optional, Tuple
 
-from zenml.artifacts.base_artifact import BaseArtifact
 from zenml.client import Client
 from zenml.config.step_configurations import Step
 from zenml.config.step_run_info import StepRunInfo
 from zenml.enums import ExecutionStatus
+from zenml.environment import get_run_environment_dict
 from zenml.logger import get_logger
 from zenml.models.pipeline_run_models import (
     PipelineRunRequestModel,
@@ -39,18 +39,22 @@ from zenml.orchestrators import (
 )
 from zenml.orchestrators import utils as orchestrator_utils
 from zenml.orchestrators.step_runner import StepRunner
+from zenml.orchestrators.utils import is_setting_enabled
 from zenml.stack import Stack
 from zenml.utils import string_utils
 
 if TYPE_CHECKING:
-    from zenml.config.pipeline_deployment import PipelineDeployment
+    from zenml.models.artifact_models import ArtifactResponseModel
+    from zenml.models.pipeline_deployment_models import (
+        PipelineDeploymentResponseModel,
+    )
     from zenml.step_operators import BaseStepOperator
 
 logger = get_logger(__name__)
 
 
 def _get_step_name_in_pipeline(
-    step: "Step", deployment: "PipelineDeployment"
+    step: "Step", deployment: "PipelineDeploymentResponseModel"
 ) -> str:
     """Gets the step name of a step inside a pipeline.
 
@@ -62,7 +66,8 @@ def _get_step_name_in_pipeline(
         The name of the step inside the pipeline.
     """
     step_name_mapping = {
-        step_.config.name: key for key, step_ in deployment.steps.items()
+        step_.config.name: key
+        for key, step_ in deployment.step_configurations.items()
     }
     return step_name_mapping[step.config.name]
 
@@ -101,7 +106,7 @@ def _get_step_operator(
 
 
 class StepLauncher:
-    """This class is responsible for launching a step of a ZenML pipeline.
+    """A class responsible for launching a step of a ZenML pipeline.
 
     This class follows these steps to launch and publish a ZenML step:
     1. Publish or reuse a `PipelineRun`
@@ -119,7 +124,7 @@ class StepLauncher:
 
     def __init__(
         self,
-        deployment: "PipelineDeployment",
+        deployment: "PipelineDeploymentResponseModel",
         step: Step,
         orchestrator_run_id: str,
     ):
@@ -129,12 +134,21 @@ class StepLauncher:
             deployment: The pipeline deployment.
             step: The step to launch.
             orchestrator_run_id: The orchestrator pipeline run id.
+
+        Raises:
+            RuntimeError: If the deployment has no associated stack.
         """
         self._deployment = deployment
         self._step = step
         self._orchestrator_run_id = orchestrator_run_id
-        stack_model = Client().get_stack(deployment.stack_id)
-        self._stack = Stack.from_model(stack_model)
+
+        if not deployment.stack:
+            raise RuntimeError(
+                f"Missing stack for deployment {deployment.id}. This is "
+                "probably because the stack was manually deleted."
+            )
+
+        self._stack = Stack.from_model(deployment.stack)
         self._step_name = _get_step_name_in_pipeline(
             step=step, deployment=deployment
         )
@@ -143,17 +157,28 @@ class StepLauncher:
         """Launches the step."""
         logger.info(f"Step `{self._step_name}` has started.")
 
-        pipeline_run = self._create_or_reuse_run()
+        pipeline_run, run_was_created = self._create_or_reuse_run()
         try:
+            if run_was_created:
+                pipeline_run_metadata = self._stack.get_pipeline_run_metadata(
+                    run_id=pipeline_run.id
+                )
+                publish_utils.publish_pipeline_run_metadata(
+                    pipeline_run_id=pipeline_run.id,
+                    pipeline_run_metadata=pipeline_run_metadata,
+                )
             client = Client()
+            docstring, source_code = self._get_step_docstring_and_source_code()
             step_run = StepRunRequestModel(
                 name=self._step_name,
                 pipeline_run_id=pipeline_run.id,
                 step=self._step,
                 status=ExecutionStatus.RUNNING,
-                start_time=datetime.now(),
+                docstring=docstring,
+                source_code=source_code,
+                start_time=datetime.utcnow(),
                 user=client.active_user.id,
-                project=client.active_project.id,
+                workspace=client.active_workspace.id,
             )
             try:
                 execution_needed, step_run_response = self._prepare(
@@ -164,7 +189,7 @@ class StepLauncher:
                     f"Failed during preparation to run step `{self._step_name}`."
                 )
                 step_run.status = ExecutionStatus.FAILED
-                step_run.end_time = datetime.now()
+                step_run.end_time = datetime.utcnow()
                 Client().zen_store.create_run_step(step_run)
                 raise
 
@@ -185,20 +210,45 @@ class StepLauncher:
             publish_utils.publish_failed_pipeline_run(pipeline_run.id)
             raise
 
-    def _create_or_reuse_run(self) -> PipelineRunResponseModel:
-        """Creates a run or reuses an existing one.
+    def _get_step_docstring_and_source_code(self) -> Tuple[Optional[str], str]:
+        """Gets the docstring and source code of the step.
+
+        If any of the two is longer than 1000 characters, it will be truncated.
 
         Returns:
-            The created or existing run.
+            The docstring and source code of the step.
+        """
+        from zenml.steps.base_step import BaseStep
+
+        step_instance = BaseStep.load_from_source(self._step.spec.source)
+
+        docstring = step_instance.docstring
+        if docstring and len(docstring) > 1000:
+            docstring = docstring[:1000] + "..."
+
+        source_code = step_instance.source_code
+        if source_code and len(source_code) > 1000:
+            source_code = source_code[:1000] + "..."
+
+        return docstring, source_code
+
+    def _create_or_reuse_run(self) -> Tuple[PipelineRunResponseModel, bool]:
+        """Creates a pipeline run or reuses an existing one.
+
+        Returns:
+            The created or existing pipeline run,
+            and a boolean indicating whether the run was created or reused.
         """
         run_id = orchestrator_utils.get_run_id_for_orchestrator_run_id(
             orchestrator=self._stack.orchestrator,
             orchestrator_run_id=self._orchestrator_run_id,
         )
 
-        date = datetime.now().strftime("%Y_%m_%d")
-        time = datetime.now().strftime("%H_%M_%S_%f")
-        run_name = self._deployment.run_name.format(date=date, time=time)
+        date = datetime.utcnow().strftime("%Y_%m_%d")
+        time = datetime.utcnow().strftime("%H_%M_%S_%f")
+        run_name = self._deployment.run_name_template.format(
+            date=date, time=time
+        )
 
         logger.debug(
             "Creating pipeline run with ID: %s, name: %s", run_id, run_name
@@ -210,15 +260,30 @@ class StepLauncher:
             name=run_name,
             orchestrator_run_id=self._orchestrator_run_id,
             user=client.active_user.id,
-            project=client.active_project.id,
-            stack=self._deployment.stack_id,
-            pipeline=self._deployment.pipeline_id,
-            enable_cache=self._deployment.pipeline.enable_cache,
+            workspace=client.active_workspace.id,
+            stack=self._deployment.stack.id
+            if self._deployment.stack
+            else None,
+            pipeline=self._deployment.pipeline.id
+            if self._deployment.pipeline
+            else None,
+            build=self._deployment.build.id
+            if self._deployment.build
+            else None,
+            deployment=self._deployment.id,
+            schedule_id=self._deployment.schedule.id
+            if self._deployment.schedule
+            else None,
+            enable_cache=self._deployment.pipeline_configuration.enable_cache,
+            enable_artifact_metadata=self._deployment.pipeline_configuration.enable_artifact_metadata,
             status=ExecutionStatus.RUNNING,
-            pipeline_configuration=self._deployment.pipeline.dict(),
-            num_steps=len(self._deployment.steps),
+            pipeline_configuration=self._deployment.pipeline_configuration.dict(),
+            num_steps=len(self._deployment.step_configurations),
+            client_environment=self._deployment.client_environment,
+            orchestrator_environment=get_run_environment_dict(),
+            server_version=client.zen_store.get_store_info().version,
+            start_time=datetime.utcnow(),
         )
-
         return client.zen_store.get_or_create_run(pipeline_run)
 
     def _prepare(
@@ -245,16 +310,16 @@ class StepLauncher:
             step=self._step,
             input_artifact_ids=input_artifact_ids,
             artifact_store=self._stack.artifact_store,
-            project_id=Client().active_project.id,
+            workspace_id=Client().active_workspace.id,
         )
 
         step_run.input_artifacts = input_artifact_ids
         step_run.parent_step_ids = parent_step_ids
         step_run.cache_key = cache_key
 
-        cache_enabled = (
-            self._deployment.pipeline.enable_cache
-            and self._step.config.enable_cache
+        cache_enabled = is_setting_enabled(
+            is_enabled_on_step=self._step.config.enable_cache,
+            is_enabled_on_pipeline=self._deployment.pipeline_configuration.enable_cache,
         )
 
         execution_needed = True
@@ -292,15 +357,14 @@ class StepLauncher:
         # Prepare step run information.
         step_run_info = StepRunInfo(
             config=self._step.config,
-            pipeline=self._deployment.pipeline,
+            pipeline=self._deployment.pipeline_configuration,
             run_name=pipeline_run.name,
+            pipeline_step_name=self._step_name,
             run_id=pipeline_run.id,
             step_run_id=step_run.id,
         )
-        input_artifacts = input_utils.prepare_input_artifacts(
-            input_artifact_models=step_run.input_artifacts,
-        )
-        output_artifacts = output_utils.prepare_output_artifacts(
+
+        output_artifact_uris = output_utils.prepare_output_artifact_uris(
             step_run=step_run, stack=self._stack, step=self._step
         )
 
@@ -315,12 +379,12 @@ class StepLauncher:
             else:
                 self._run_step_without_step_operator(
                     step_run_info=step_run_info,
-                    input_artifacts=input_artifacts,
-                    output_artifacts=output_artifacts,
+                    input_artifacts=step_run.input_artifacts,
+                    output_artifact_uris=output_artifact_uris,
                 )
         except:  # noqa: E722
             output_utils.remove_artifact_dirs(
-                artifacts=list(output_artifacts.values())
+                artifact_uris=list(output_artifact_uris.values())
             )
             raise
 
@@ -353,6 +417,7 @@ class StepLauncher:
             StepOperatorEntrypointConfiguration.get_entrypoint_command()
             + StepOperatorEntrypointConfiguration.get_entrypoint_arguments(
                 step_name=self._step_name,
+                deployment_id=self._deployment.id,
                 step_run_id=str(step_run_info.step_run_id),
             )
         )
@@ -369,19 +434,19 @@ class StepLauncher:
     def _run_step_without_step_operator(
         self,
         step_run_info: StepRunInfo,
-        input_artifacts: Dict[str, BaseArtifact],
-        output_artifacts: Dict[str, BaseArtifact],
+        input_artifacts: Dict[str, "ArtifactResponseModel"],
+        output_artifact_uris: Dict[str, str],
     ) -> None:
         """Runs the current step without a step operator.
 
         Args:
             step_run_info: Additional information needed to run the step.
             input_artifacts: The input artifacts of the current step.
-            output_artifacts: The output artifacts of the current step.
+            output_artifact_uris: The output artifact URIs of the current step.
         """
         runner = StepRunner(step=self._step, stack=self._stack)
         runner.run(
             input_artifacts=input_artifacts,
-            output_artifacts=output_artifacts,
+            output_artifact_uris=output_artifact_uris,
             step_run_info=step_run_info,
         )
