@@ -14,7 +14,7 @@
 """Class for all lineage artifact nodes."""
 
 
-from typing import Optional
+from typing import List, Optional, Tuple
 
 from zenml.post_execution.lineage.node.base_node import (
     BaseNode,
@@ -31,6 +31,7 @@ class ArtifactNodeDetails(BaseNodeDetails):
     parent_step_id: str
     producer_step_id: Optional[str]
     uri: str
+    metadata: List[Tuple[str, str, str]]  # (key, value, type)
 
 
 class ArtifactNode(BaseNode):
