@@ -1,4 +1,4 @@
-#  Copyright (c) ZenML GmbH 2021. All Rights Reserved.
+#  Copyright (c) ZenML GmbH 2023. All Rights Reserved.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,17 +13,16 @@
 #  permissions and limitations under the License.
 """Implementation of the post-execution pipeline."""
 
-from typing import TYPE_CHECKING, Any, List, Optional, Type, Union
-from uuid import UUID
+from typing import TYPE_CHECKING, Any, List, Optional, Type, Union, cast
 
 from zenml.client import Client
 from zenml.logger import get_apidocs_link, get_logger
-from zenml.models import PipelineResponseModel
+from zenml.models import PipelineResponseModel, PipelineRunFilterModel
+from zenml.post_execution.base_view import BaseView
 from zenml.post_execution.pipeline_run import PipelineRunView
 from zenml.utils.analytics_utils import AnalyticsEvent, track
 
 if TYPE_CHECKING:
-    from zenml.config.pipeline_configurations import PipelineSpec
     from zenml.pipelines.base_pipeline import BasePipeline
 
 logger = get_logger(__name__)
@@ -31,22 +30,26 @@ logger = get_logger(__name__)
 
 @track(event=AnalyticsEvent.GET_PIPELINES)
 def get_pipelines() -> List["PipelineView"]:
-    """Fetches all post-execution pipeline views in the active project.
+    """Fetches all post-execution pipeline views in the active workspace.
 
     Returns:
         A list of post-execution pipeline views.
     """
     # TODO: [server] handle the active stack correctly
     client = Client()
-    pipelines = client.zen_store.list_pipelines(
-        project_name_or_id=client.active_project.id
+    pipelines = client.list_pipelines(
+        workspace_id=client.active_workspace.id,
+        sort_by="desc:created",
     )
-    return [PipelineView(model) for model in pipelines]
+    return [PipelineView(model) for model in pipelines.items]
 
 
 @track(event=AnalyticsEvent.GET_PIPELINE)
 def get_pipeline(
-    pipeline: Optional[Union["BasePipeline", Type["BasePipeline"], str]] = None,
+    pipeline: Optional[
+        Union["BasePipeline", Type["BasePipeline"], str]
+    ] = None,
+    version: Optional[str] = None,
     **kwargs: Any,
 ) -> Optional["PipelineView"]:
     """Fetches a post-execution pipeline view.
@@ -69,7 +72,9 @@ def get_pipeline(
     `None` will be returned.
 
     Args:
-        pipeline: Class or class instance of the pipeline
+        pipeline: Name, class or instance of the pipeline.
+        version: Optional version of the pipeline. If not given, the latest
+            version will be returned.
         **kwargs: The deprecated `pipeline_name` is caught as a kwarg to
             specify the pipeline instead of using the `pipeline` argument.
 
@@ -85,7 +90,11 @@ def get_pipeline(
     if isinstance(pipeline, str):
         pipeline_name = pipeline
     elif isinstance(pipeline, BasePipeline):
-        pipeline_name = pipeline.name
+        pipeline_model = pipeline._get_registered_model()
+        if pipeline_model:
+            return PipelineView(model=pipeline_model)
+        else:
+            return None
     elif isinstance(pipeline, type) and issubclass(pipeline, BasePipeline):
         pipeline_name = pipeline.__name__
     elif "pipeline_name" in kwargs and isinstance(
@@ -115,97 +124,70 @@ def get_pipeline(
         )
 
     client = Client()
-    active_project_id = client.active_project.id
-
-    pipeline_models = client.list_pipelines(
-        name=pipeline_name,
-        project_name_or_id=active_project_id,
-    )
-    if len(pipeline_models) == 1:
-        return PipelineView(pipeline_models[0])
-    elif len(pipeline_models) > 1:
-        raise RuntimeError(
-            f"Pipeline_name `{pipeline_name}` not unique within Project "
-            f"`{active_project_id}`."
+    try:
+        pipeline_model = client.get_pipeline(
+            name_id_or_prefix=pipeline_name, version=version
         )
-    else:
+        return PipelineView(model=pipeline_model)
+    except KeyError:
         return None
 
 
-class PipelineView:
+class PipelineView(BaseView):
     """Post-execution pipeline class."""
 
-    def __init__(self, model: PipelineResponseModel):
-        """Initializes a post-execution pipeline object.
-
-        In most cases `PipelineView` objects should not be created manually
-        but retrieved using the `get_pipelines()` utility from
-        `zenml.post_execution` instead.
-
-        Args:
-            model: The model to initialize this pipeline view from.
-        """
-        self._model = model
+    MODEL_CLASS = PipelineResponseModel
+    REPR_KEYS = ["id", "name"]
 
     @property
-    def id(self) -> UUID:
-        """Returns the ID of this pipeline.
+    def model(self) -> PipelineResponseModel:
+        """Returns the underlying `PipelineResponseModel`.
 
         Returns:
-            The ID of this pipeline.
+            The underlying `PipelineResponseModel`.
         """
-        assert self._model.id is not None
-        return self._model.id
+        return cast(PipelineResponseModel, self._model)
 
     @property
-    def name(self) -> str:
-        """Returns the name of the pipeline.
+    def num_runs(self) -> int:
+        """Returns the number of runs of this pipeline.
 
         Returns:
-            The name of the pipeline.
+            The number of runs of this pipeline.
         """
-        return self._model.name
-
-    @property
-    def docstring(self) -> Optional[str]:
-        """Returns the docstring of the pipeline.
-
-        Returns:
-            The docstring of the pipeline.
-        """
-        return self._model.docstring
-
-    @property
-    def spec(self) -> "PipelineSpec":
-        """Returns the spec of the pipeline.
-
-        The pipeline spec contains the source paths of all steps, as well as
-        each of their upstream step names. This is primarily used to compare
-        whether two pipelines are the same.
-
-        Returns:
-            The spec of the pipeline.
-        """
-        return self._model.spec
+        active_workspace_id = Client().active_workspace.id
+        return (
+            Client()
+            .zen_store.list_runs(
+                PipelineRunFilterModel(
+                    workspace_id=active_workspace_id,
+                    pipeline_id=self._model.id,
+                )
+            )
+            .total
+        )
 
     @property
     def runs(self) -> List["PipelineRunView"]:
-        """Returns all stored runs of this pipeline.
+        """Returns the last 50 stored runs of this pipeline.
 
-        The runs are returned in chronological order, so the latest
-        run will be the last element in this list.
+        The runs are returned in reverse chronological order, so the latest
+        run will be the first element in this list.
 
         Returns:
             A list of all stored runs of this pipeline.
         """
         # Do not cache runs as new runs might appear during this objects
         # lifecycle
-        active_project_id = Client().active_project.id
-        runs = Client().zen_store.list_runs(
-            project_name_or_id=active_project_id,
-            pipeline_id=self._model.id,
+        active_workspace_id = Client().active_workspace.id
+        runs = Client().list_runs(
+            workspace_id=active_workspace_id,
+            pipeline_id=self.model.id,
+            size=50,
+            sort_by="desc:created",
         )
-        return [PipelineRunView(run) for run in runs]
+
+        return [PipelineRunView(run) for run in runs.items]
 
     def get_run_for_completed_step(self, step_name: str) -> "PipelineRunView":
         """Ascertains which pipeline run produced the cached artifact of a given step.
@@ -237,28 +219,3 @@ class PipelineView:
             )
 
         return orig_pipeline_run
-
-    def __repr__(self) -> str:
-        """Returns a string representation of this pipeline.
-
-        Returns:
-            A string representation of this pipeline.
-        """
-        return (
-            f"{self.__class__.__qualname__}(id={self.id}, "
-            f"name='{self.name}')"
-        )
-
-    def __eq__(self, other: Any) -> bool:
-        """Returns whether the other object is referring to the same pipeline.
-
-        Args:
-            other: The other object to compare to.
-
-        Returns:
-            True if the other object is referring to the same pipeline,
-            False otherwise.
-        """
-        if isinstance(other, PipelineView):
-            return self.id == other.id
-        return NotImplemented
