@@ -1,4 +1,4 @@
-#  Copyright (c) ZenML GmbH 2021. All Rights Reserved.
+#  Copyright (c) ZenML GmbH 2023. All Rights Reserved.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,89 +13,58 @@
 #  permissions and limitations under the License.
 """Implementation of a post-execution step class."""
 
-from typing import TYPE_CHECKING, Any, Dict, List, Optional
+from typing import TYPE_CHECKING, Any, Dict, Optional, cast
 
+from zenml.client import Client
 from zenml.enums import ExecutionStatus
+from zenml.models import StepRunResponseModel
 from zenml.post_execution.artifact import ArtifactView
-from zenml.zen_stores.models.pipeline_models import StepWrapper
+from zenml.post_execution.base_view import BaseView
 
 if TYPE_CHECKING:
-    from zenml.metadata_stores import BaseMetadataStore
+    from zenml.config.base_settings import BaseSettings
+    from zenml.config.step_configurations import StepConfiguration, StepSpec
 
 
-class StepView:
+class StepView(BaseView):
     """Post-execution step class.
 
     This can be used to query artifact information associated with a pipeline step.
     """
 
-    def __init__(
-        self,
-        id_: int,
-        parents_step_ids: List[int],
-        entrypoint_name: str,
-        name: str,
-        parameters: Dict[str, Any],
-        metadata_store: "BaseMetadataStore",
-    ):
+    MODEL_CLASS = StepRunResponseModel
+    REPR_KEYS = ["id", "name", "entrypoint_name"]
+
+    def __init__(self, model: StepRunResponseModel):
         """Initializes a post-execution step object.
 
         In most cases `StepView` objects should not be created manually
         but retrieved from a `PipelineRunView` object instead.
 
         Args:
-            id_: The execution id of this step.
-            parents_step_ids: The execution ids of the parents of this step.
-            entrypoint_name: The name of this step.
-            name: The name of this step within the pipeline
-            parameters: Parameters that were used to run this step.
-            metadata_store: The metadata store which should be used to fetch
-                additional information related to this step.
+            model: The model to initialize this object from.
         """
-        self._id = id_
-        self._parents_step_ids = parents_step_ids
-        self._entrypoint_name = entrypoint_name
-        self._name = name
-        self._parameters = parameters
-        self._metadata_store = metadata_store
-
+        super().__init__(model)
         self._inputs: Dict[str, ArtifactView] = {}
         self._outputs: Dict[str, ArtifactView] = {}
 
-        # This might be set from the parent pipeline run view in case the run
-        # is also tracked in the ZenStore
-        self._step_wrapper: Optional[StepWrapper] = None
-
     @property
-    def id(self) -> int:
-        """Returns the step id.
+    def model(self) -> StepRunResponseModel:
+        """Returns the underlying `StepRunResponseModel`.
 
         Returns:
-            The step id.
+            The underlying `StepRunResponseModel`.
         """
-        return self._id
+        return cast(StepRunResponseModel, self._model)
 
     @property
-    def parents_step_ids(self) -> List[int]:
-        """Returns a list of IDs of all parents of this step.
+    def step_configuration(self) -> "StepConfiguration":
+        """Returns the step configuration.
 
         Returns:
-            A list of IDs of all parents of this step.
+            The step configuration.
         """
-        return self._parents_step_ids
-
-    @property
-    def parent_steps(self) -> List["StepView"]:
-        """Returns a list of all parent steps of this step.
-
-        Returns:
-            A list of all parent steps of this step.
-        """
-        steps = [
-            self._metadata_store.get_step_by_id(s)
-            for s in self.parents_step_ids
-        ]
-        return steps
+        return self.model.step.config
 
     @property
     def entrypoint_name(self) -> str:
@@ -106,7 +75,7 @@ class StepView:
 
         Examples:
             # the step entrypoint_name will be "my_step"
-            @step(name="my_step")
+            @step(step="my_step")
             def my_step_function(...)
 
             # the step entrypoint_name will be "my_step_function"
@@ -116,52 +85,88 @@ class StepView:
         Returns:
             The step entrypoint_name.
         """
-        return self._entrypoint_name
+        return self.step_configuration.name
 
     @property
-    def name(self) -> str:
-        """Returns the name as it is defined in the pipeline.
-
-        This name is equal to the name given to the step within the pipeline
-        context
-
-        Examples:
-            @step()
-            def my_step_function(...)
-
-            @pipeline
-            def my_pipeline_function(step_a)
-
-            p = my_pipeline_function(
-                    step_a = my_step_function()
-                )
-
-            The name will be `step_a`
-
-        Returns:
-            The name of this step.
-        """
-        return self._name
-
-    @property
-    def docstring(self) -> Optional[str]:
-        """Docstring of the step function or class.
-
-        Returns:
-            The docstring of the step function or class.
-        """
-        if self._step_wrapper:
-            return self._step_wrapper.docstring
-        return None
-
-    @property
-    def parameters(self) -> Dict[str, Any]:
+    def parameters(self) -> Dict[str, str]:
         """The parameters used to run this step.
 
         Returns:
             The parameters used to run this step.
         """
-        return self._parameters
+        return self.step_configuration.parameters
+
+    @property
+    def settings(self) -> Dict[str, "BaseSettings"]:
+        """Returns the step settings.
+
+        These are runtime settings passed down to stack components, which
+        can be set at step level.
+
+        Returns:
+            The step settings.
+        """
+        return self.step_configuration.settings
+
+    @property
+    def extra(self) -> Dict[str, Any]:
+        """Returns the extra dictionary.
+
+        This dict is meant to be used to pass any configuration down to the
+        step that the user has use of.
+
+        Returns:
+            The extra dictionary.
+        """
+        return self.step_configuration.extra
+
+    @property
+    def enable_cache(self) -> Optional[bool]:
+        """Returns whether caching is enabled for this step.
+
+        Returns:
+            Whether caching is enabled for this step.
+        """
+        return self.step_configuration.enable_cache
+
+    @property
+    def enable_artifact_metadata(self) -> Optional[bool]:
+        """Returns whether artifact metadata is enabled for this step.
+
+        Returns:
+            Whether artifact metadata is enabled for this step.
+        """
+        return self.step_configuration.enable_artifact_metadata
+
+    @property
+    def step_operator(self) -> Optional[str]:
+        """Returns the name of the step operator of the step.
+
+        Returns:
+            The name of the step operator of the step.
+        """
+        return self.step_configuration.step_operator
+
+    @property
+    def experiment_tracker(self) -> Optional[str]:
+        """Returns the name of the experiment tracker of the step.
+
+        Returns:
+            The name of the experiment tracker of the step.
+        """
+        return self.step_configuration.experiment_tracker
+
+    @property
+    def spec(self) -> "StepSpec":
+        """Returns the step spec.
+
+        The step spec defines the source path and upstream steps of a step and
+        is used primarily to compare whether two steps are the same.
+
+        Returns:
+            The step spec.
+        """
+        return self.model.step.spec
 
     @property
     def status(self) -> ExecutionStatus:
@@ -170,7 +175,9 @@ class StepView:
         Returns:
             The current status of the step.
         """
-        return self._metadata_store.get_step_status(self)
+        # Query the step again since the status might have changed since this
+        # object was created.
+        return Client().zen_store.get_run_step(self.model.id).status
 
     @property
     def is_cached(self) -> bool:
@@ -197,7 +204,7 @@ class StepView:
         Returns:
             A dictionary of artifact names to artifact views.
         """
-        self._ensure_inputs_outputs_fetched()
+        self._ensure_inputs_fetched()
         return self._inputs
 
     @property
@@ -224,7 +231,7 @@ class StepView:
         Returns:
             A dictionary of artifact names to artifact views.
         """
-        self._ensure_inputs_outputs_fetched()
+        self._ensure_outputs_fetched()
         return self._outputs
 
     @property
@@ -244,41 +251,24 @@ class StepView:
             )
         return next(iter(self.outputs.values()))
 
-    def _ensure_inputs_outputs_fetched(self) -> None:
-        """Fetches all step inputs and outputs from the metadata store."""
-        if self._inputs or self._outputs:
-            # we already fetched inputs/outputs, no need to do anything
+    def _ensure_inputs_fetched(self) -> None:
+        """Fetches all step inputs from the ZenStore."""
+        if self._inputs:
+            # we already fetched inputs, no need to do anything
             return
 
-        self._inputs, self._outputs = self._metadata_store.get_step_artifacts(
-            self
-        )
+        self._inputs = {
+            name: ArtifactView(artifact_model)
+            for name, artifact_model in self.model.input_artifacts.items()
+        }
 
-    def __repr__(self) -> str:
-        """Returns a string representation of this step.
+    def _ensure_outputs_fetched(self) -> None:
+        """Fetches all step outputs from the ZenStore."""
+        if self._outputs:
+            # we already fetched outputs, no need to do anything
+            return
 
-        Returns:
-            A string representation of this step.
-        """
-        return (
-            f"{self.__class__.__qualname__}(id={self._id}, "
-            f"name='{self.name}', entrypoint_name='{self.entrypoint_name}'"
-            f"parameters={self._parameters})"
-        )
-
-    def __eq__(self, other: Any) -> bool:
-        """Returns whether the other object is referring to the same step.
-
-        Args:
-            other: The other object to compare to.
-
-        Returns:
-            True if the other object is referring to the same step, False
-            otherwise.
-        """
-        if isinstance(other, StepView):
-            return (
-                self._id == other._id
-                and self._metadata_store.uuid == other._metadata_store.uuid
-            )
-        return NotImplemented
+        self._outputs = {
+            name: ArtifactView(artifact_model)
+            for name, artifact_model in self.model.output_artifacts.items()
+        }
