@@ -13,12 +13,22 @@
 #  permissions and limitations under the License.
 """Initialization for the ZenML secrets manager module."""
 
-from zenml.secrets_managers.base_secrets_manager import BaseSecretsManager
+from zenml.secrets_managers.base_secrets_manager import (
+    BaseSecretsManager,
+    BaseSecretsManagerConfig,
+    BaseSecretsManagerFlavor,
+)
 from zenml.secrets_managers.local.local_secrets_manager import (
     LocalSecretsManager,
+    LocalSecretsManagerConfig,
+    LocalSecretsManagerFlavor,
 )
 
 __all__ = [
     "BaseSecretsManager",
+    "BaseSecretsManagerConfig",
+    "BaseSecretsManagerFlavor",
     "LocalSecretsManager",
+    "LocalSecretsManagerFlavor",
+    "LocalSecretsManagerConfig",
 ]
