@@ -115,7 +115,7 @@ class ContainerService(BaseService):
     `run` method. Upon `start`, the service will spawn a container that
     ends up calling the `run` method.
 
-    Example:
+    For example,
 
     ```python
 
@@ -496,7 +496,9 @@ class ContainerService(BaseService):
         Yields:
             A generator that can be accessed to get the service logs.
         """
-        if not self.status.log_file or not os.path.exists(self.status.log_file):
+        if not self.status.log_file or not os.path.exists(
+            self.status.log_file
+        ):
             return
 
         with open(self.status.log_file, "r") as f:
