@@ -29,7 +29,10 @@ from zenml.services.service_monitor import (
     HTTPEndpointHealthMonitor,
     TCPEndpointHealthMonitor,
 )
-from zenml.utils.networking_utils import port_available, scan_for_available_port
+from zenml.utils.networking_utils import (
+    port_available,
+    scan_for_available_port,
+)
 
 logger = get_logger(__name__)
 
@@ -104,7 +107,7 @@ class LocalDaemonServiceEndpoint(BaseServiceEndpoint):
         """
         # If a port value is explicitly configured, attempt to use it first
         if self.config.port:
-            if port_available(self.config.port):
+            if port_available(self.config.port, self.config.ip_address):
                 return self.config.port
             if not self.config.allocate_port:
                 raise IOError(f"TCP port {self.config.port} is not available.")
