@@ -13,18 +13,20 @@
 #  permissions and limitations under the License.
 """Stack component mixin for authentication."""
 
-from typing import Optional, Type, TypeVar
+from typing import Optional, Type, TypeVar, cast
 
-from pydantic import BaseModel
-
-from zenml.repository import Repository
+from zenml.client import Client
 from zenml.secret import BaseSecretSchema
+from zenml.stack.stack_component import StackComponent, StackComponentConfig
 
 T = TypeVar("T", bound=BaseSecretSchema)
 
 
-class AuthenticationMixin(BaseModel):
-    """Stack component mixin for authentication.
+class AuthenticationConfigMixin(StackComponentConfig):
+    """Base config for authentication mixins.
+
+    Any stack component that implements `AuthenticationMixin` should have a
+    config that inherits from this class.
 
     Attributes:
         authentication_secret: Name of the secret that stores the
@@ -33,6 +35,23 @@ class AuthenticationMixin(BaseModel):
 
     authentication_secret: Optional[str] = None
 
+
+class AuthenticationMixin(StackComponent):
+    """Stack component mixin for authentication.
+
+    Any stack component that implements this mixin should have a config that
+    inherits from `AuthenticationConfigMixin`.
+    """
+
+    @property
+    def config(self) -> AuthenticationConfigMixin:
+        """Returns the `AuthenticationConfigMixin` config.
+
+        Returns:
+            The configuration.
+        """
+        return cast(AuthenticationConfigMixin, self._config)
+
     def get_authentication_secret(
         self, expected_schema_type: Type[T]
     ) -> Optional[T]:
@@ -49,26 +68,40 @@ class AuthenticationMixin(BaseModel):
             RuntimeError: If no secrets manager exists in the active stack.
             TypeError: If the secret is not of the expected schema type.
         """
-        if not self.authentication_secret:
+        if not self.config.authentication_secret:
             return None
 
-        secrets_manager = Repository().active_stack.secrets_manager
+        # Try to resolve the secret using the secret store first
+        try:
+            store_secret = Client().get_secret_by_name_and_scope(
+                name=self.config.authentication_secret,
+            )
+        except (KeyError, NotImplementedError):
+            pass
+        else:
+            return expected_schema_type(
+                name=self.config.authentication_secret,
+                **store_secret.secret_values,
+            )
+
+        active_stack = Client().active_stack
+        secrets_manager = active_stack.secrets_manager
         if not secrets_manager:
             raise RuntimeError(
-                f"Unable to retrieve secret '{self.authentication_secret}' "
+                f"Unable to retrieve secret '{self.config.authentication_secret}' "
                 "because the active stack does not have a secrets manager."
             )
 
-        secret = secrets_manager.get_secret(self.authentication_secret)
+        secret = secrets_manager.get_secret(self.config.authentication_secret)
 
         if not isinstance(secret, expected_schema_type):
             raise TypeError(
                 f"Authentication secret has type {secret.TYPE} but a secret of "
                 f"type {expected_schema_type.TYPE} was expected. To solve this "
                 f"issue, register a secret with name "
-                f"{self.authentication_secret} of type "
+                f"{self.config.authentication_secret} of type "
                 f"{expected_schema_type.TYPE} using the following command: \n "
-                f"`zenml secret register {self.authentication_secret} "
+                f"`zenml secrets-manager secret register {self.config.authentication_secret} "
                 f"--schema={expected_schema_type.TYPE} ...`"
             )
 
