@@ -14,12 +14,12 @@
 """Implementation of the ZenML Stack Component class."""
 from abc import ABC
 from datetime import datetime
-from typing import TYPE_CHECKING, Any, List, Optional, Set, Type, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Type, Union
 from uuid import UUID
 
 from pydantic import BaseModel, Extra
 
-from zenml.config.pipeline_deployment import PipelineDeployment
+from zenml.config.build_configuration import BuildConfiguration
 from zenml.config.step_configurations import Step
 from zenml.config.step_run_info import StepRunInfo
 from zenml.enums import StackComponentType
@@ -29,9 +29,13 @@ from zenml.utils import secret_utils, settings_utils
 
 if TYPE_CHECKING:
     from zenml.config.base_settings import BaseSettings
+    from zenml.metadata.metadata_types import MetadataType
+    from zenml.models.pipeline_deployment_models import (
+        PipelineDeploymentBaseModel,
+        PipelineDeploymentResponseModel,
+    )
     from zenml.stack import Stack, StackValidator
 
-
 logger = get_logger(__name__)
 
 
@@ -169,11 +173,34 @@ class StackComponentConfig(BaseModel, ABC):
         Returns:
             The (potentially resolved) attribute value.
         """
+        from zenml.client import Client
+
         value = super().__getattribute__(key)
 
         if not secret_utils.is_secret_reference(value):
             return value
 
+        secret_ref = secret_utils.parse_secret_reference(value)
+
+        # Try to resolve the secret using the secret store first
+        try:
+            store_secret = Client().get_secret_by_name_and_scope(
+                name=secret_ref.name,
+            )
+        except (KeyError, NotImplementedError):
+            pass
+        else:
+            if secret_ref.key in store_secret.values:
+                return store_secret.secret_values[secret_ref.key]
+            else:
+                raise KeyError(
+                    f"Failed to resolve secret reference for attribute {key} "
+                    f"of stack component `{self}`. "
+                    f"The secret {secret_ref.name} does not contain a value "
+                    f"for key {secret_ref.key}. Available keys: "
+                    f"{set(store_secret.values)}."
+                )
+
         # A stack component can be part of many stacks, and currently a
         # secrets manager is associated with a stack. This means we're
         # not able to identify the 'correct' secrets manager that the user
@@ -190,8 +217,6 @@ class StackComponentConfig(BaseModel, ABC):
                 "your active stack: `zenml stack set <STACK_NAME>`."
             )
 
-        from zenml.client import Client
-
         secrets_manager = Client().active_stack.secrets_manager
         if not secrets_manager:
             raise RuntimeError(
@@ -200,7 +225,6 @@ class StackComponentConfig(BaseModel, ABC):
                 "have a secrets manager."
             )
 
-        secret_ref = secret_utils.parse_secret_reference(value)
         try:
             secret = secrets_manager.get_secret(secret_ref.name)
         except KeyError:
@@ -265,7 +289,7 @@ class StackComponent:
         flavor: str,
         type: StackComponentType,
         user: Optional[UUID],
-        project: UUID,
+        workspace: UUID,
         created: datetime,
         updated: datetime,
         *args: Any,
@@ -280,7 +304,7 @@ class StackComponent:
             flavor: The flavor of the component.
             type: The type of the component.
             user: The ID of the user who created the component.
-            project: The ID of the project the component belongs to.
+            workspace: The ID of the workspace the component belongs to.
             created: The creation time of the component.
             updated: The last update time of the component.
             *args: Additional positional arguments.
@@ -301,7 +325,7 @@ class StackComponent:
         self.flavor = flavor
         self.type = type
         self.user = user
-        self.project = project
+        self.workspace = workspace
         self.created = created
         self.updated = updated
 
@@ -345,7 +369,7 @@ class StackComponent:
 
         return flavor.implementation_class(
             user=user_id,
-            project=component_model.project.id,
+            workspace=component_model.workspace.id,
             name=component_model.name,
             id=component_model.id,
             config=configuration,
@@ -377,7 +401,8 @@ class StackComponent:
         return None
 
     def get_settings(
-        self, container: Union["Step", "StepRunInfo", "PipelineDeployment"]
+        self,
+        container: Union["Step", "StepRunInfo", "PipelineDeploymentBaseModel"],
     ) -> "BaseSettings":
         """Gets settings for this stack component.
 
@@ -409,7 +434,7 @@ class StackComponent:
         all_settings = (
             container.config.settings
             if isinstance(container, (Step, StepRunInfo))
-            else container.pipeline.settings
+            else container.pipeline_configuration.settings
         )
 
         if key in all_settings:
@@ -486,9 +511,22 @@ class StackComponent:
         """
         return None
 
+    def get_docker_builds(
+        self, deployment: "PipelineDeploymentBaseModel"
+    ) -> List["BuildConfiguration"]:
+        """Gets the Docker builds required for the component.
+
+        Args:
+            deployment: The pipeline deployment for which to get the builds.
+
+        Returns:
+            The required Docker builds.
+        """
+        return []
+
     def prepare_pipeline_deployment(
         self,
-        deployment: "PipelineDeployment",
+        deployment: "PipelineDeploymentResponseModel",
         stack: "Stack",
     ) -> None:
         """Prepares deploying the pipeline.
@@ -502,6 +540,19 @@ class StackComponent:
             stack: The stack on which the pipeline will be deployed.
         """
 
+    def get_pipeline_run_metadata(
+        self, run_id: UUID
+    ) -> Dict[str, "MetadataType"]:
+        """Get general component-specific metadata for a pipeline run.
+
+        Args:
+            run_id: The ID of the pipeline run.
+
+        Returns:
+            A dictionary of metadata.
+        """
+        return {}
+
     def prepare_step_run(self, info: "StepRunInfo") -> None:
         """Prepares running a step.
 
@@ -509,6 +560,19 @@ class StackComponent:
             info: Info about the step that will be executed.
         """
 
+    def get_step_run_metadata(
+        self, info: "StepRunInfo"
+    ) -> Dict[str, "MetadataType"]:
+        """Get component- and step-specific metadata after a step ran.
+
+        Args:
+            info: Info about the step that was executed.
+
+        Returns:
+            A dictionary of metadata.
+        """
+        return {}
+
     def cleanup_step_run(self, info: "StepRunInfo", step_failed: bool) -> None:
         """Cleans up resources after the step run is finished.
 
