@@ -18,8 +18,6 @@ being one of the nodes of a Directed Acyclic Graph (or DAG). Steps are
 responsible for one aspect of processing or interacting with the data /
 artifacts in the pipeline.
 
-ZenML currently implements a basic step interface, but there will be other more
-customized interfaces (layered in a hierarchy) for specialized implementations.
 Conceptually, a Step is a discrete and independent part of a pipeline that is
 responsible for one particular aspect of data manipulation inside a ZenML
 pipeline.
@@ -28,19 +26,21 @@ Steps can be subclassed from the `BaseStep` class, or used via our `@step`
 decorator.
 """
 
+from zenml.config import ResourceSettings
+from zenml.steps.base_parameters import BaseParameters
 from zenml.steps.base_step import BaseStep
-from zenml.steps.base_step_config import BaseStepConfig
 from zenml.steps.step_context import StepContext
 from zenml.steps.step_decorator import step
 from zenml.steps.step_environment import STEP_ENVIRONMENT_NAME, StepEnvironment
 from zenml.steps.step_output import Output
 
 __all__ = [
-    "STEP_ENVIRONMENT_NAME",
-    "BaseStep",
-    "BaseStepConfig",
-    "StepContext",
     "step",
+    "BaseStep",
+    "BaseParameters",
     "Output",
+    "ResourceSettings",
+    "StepContext",
     "StepEnvironment",
+    "STEP_ENVIRONMENT_NAME",
 ]
