@@ -13,30 +13,28 @@
 #  permissions and limitations under the License.
 """Step context class."""
 
-from typing import TYPE_CHECKING, Dict, NamedTuple, Optional, Type, cast
+from typing import TYPE_CHECKING, Dict, NamedTuple, Optional, Type
 
+from zenml.client import Client
 from zenml.exceptions import StepContextError
-from zenml.repository import Repository
 
 if TYPE_CHECKING:
-    from zenml.artifacts.base_artifact import BaseArtifact
     from zenml.materializers.base_materializer import BaseMaterializer
-    from zenml.metadata_stores.base_metadata_store import BaseMetadataStore
     from zenml.stack import Stack
 
 
 class StepContextOutput(NamedTuple):
-    """Tuple containing materializer class and artifact for a step output."""
+    """Tuple containing materializer class and URI for a step output."""
 
     materializer_class: Type["BaseMaterializer"]
-    artifact: "BaseArtifact"
+    artifact_uri: str
 
 
 class StepContext:
     """Provides additional context inside a step function.
 
-    This class is used to access the metadata store, materializers and
-    artifacts inside a step function. To use it, add a `StepContext` object
+    This class is used to access pipelines, materializers, and artifacts
+    inside a step function. To use it, add a `StepContext` object
     to the signature of your step function like this:
 
     ```python
@@ -61,38 +59,37 @@ class StepContext:
         self,
         step_name: str,
         output_materializers: Dict[str, Type["BaseMaterializer"]],
-        output_artifacts: Dict[str, "BaseArtifact"],
+        output_artifact_uris: Dict[str, str],
     ):
         """Initializes a StepContext instance.
 
         Args:
             step_name: The name of the step that this context is used in.
             output_materializers: The output materializers of the step that
-                                  this context is used in.
-            output_artifacts: The output artifacts of the step that this
-                              context is used in.
+                this context is used in.
+            output_artifact_uris: The output artifacts of the step that this
+                context is used in.
 
         Raises:
-             StepContextError: If the keys of the output materializers and
-                               output artifacts do not match.
+            StepContextError: If the keys of the output materializers and
+                output artifacts do not match.
         """
-        if output_materializers.keys() != output_artifacts.keys():
+        if output_materializers.keys() != output_artifact_uris.keys():
             raise StepContextError(
                 f"Mismatched keys in output materializers and output "
-                f"artifacts for step '{step_name}'. Output materializer "
-                f"keys: {set(output_materializers)}, output artifact "
-                f"keys: {set(output_artifacts)}"
+                f"artifacts URIs for step '{step_name}'. Output materializer "
+                f"keys: {set(output_materializers)}, output artifact URI "
+                f"keys: {set(output_artifact_uris)}"
             )
 
         self.step_name = step_name
         self._outputs = {
             key: StepContextOutput(
-                output_materializers[key], output_artifacts[key]
+                output_materializers[key], output_artifact_uris[key]
             )
             for key in output_materializers.keys()
         }
-        self._metadata_store = Repository().active_stack.metadata_store
-        self._stack = Repository().active_stack
+        self._stack = Client().active_stack
 
     def _get_output(
         self, output_name: Optional[str] = None
@@ -105,12 +102,12 @@ class StepContext:
 
         Returns:
             Tuple containing the materializer and artifact URI for the
-            given output.
+                given output.
 
         Raises:
             StepContextError: If the step has no outputs, no output for
-                              the given `output_name` or if no `output_name`
-                              was given but the step has multiple outputs.
+                the given `output_name` or if no `output_name` was given but
+                the step has multiple outputs.
         """
         output_count = len(self._outputs)
         if output_count == 0:
@@ -138,19 +135,6 @@ class StepContext:
         else:
             return next(iter(self._outputs.values()))
 
-    @property
-    def metadata_store(self) -> "BaseMetadataStore":
-        """Returns the metadata store.
-
-        Returns an instance of the metadata store that is used to store
-        metadata about the step (and the corresponding pipeline) which is
-        being executed.
-
-        Returns:
-            The metadata store.
-        """
-        return self._metadata_store
-
     @property
     def stack(self) -> Optional["Stack"]:
         """Returns the current active stack.
@@ -181,13 +165,15 @@ class StepContext:
             A materializer initialized with the output artifact for
             the given output.
         """
-        materializer_class, artifact = self._get_output(output_name)
+        materializer_class, artifact_uri = self._get_output(output_name)
         # use custom materializer class if provided or fallback to default
         # materializer for output
         materializer_class = custom_materializer_class or materializer_class
-        return materializer_class(artifact)
+        return materializer_class(artifact_uri)
 
-    def get_output_artifact_uri(self, output_name: Optional[str] = None) -> str:
+    def get_output_artifact_uri(
+        self, output_name: Optional[str] = None
+    ) -> str:
         """Returns the artifact URI for a given step output.
 
         Args:
@@ -199,4 +185,4 @@ class StepContext:
         Returns:
             Artifact URI for the given output.
         """
-        return cast(str, self._get_output(output_name).artifact.uri)
+        return self._get_output(output_name).artifact_uri
