@@ -13,7 +13,15 @@
 #  permissions and limitations under the License.
 """Step environment class."""
 
+from typing import TYPE_CHECKING
+
 from zenml.environment import BaseEnvironmentComponent
+from zenml.logger import get_logger
+
+if TYPE_CHECKING:
+    from zenml.config.step_run_info import StepRunInfo
+
+logger = get_logger(__name__)
 
 STEP_ENVIRONMENT_NAME = "step_environment"
 
@@ -41,21 +49,18 @@ class StepEnvironment(BaseEnvironmentComponent):
 
     def __init__(
         self,
-        pipeline_name: str,
-        pipeline_run_id: str,
-        step_name: str,
+        step_run_info: "StepRunInfo",
+        cache_enabled: bool,
     ):
         """Initialize the environment of the currently running step.
 
         Args:
-            pipeline_name: the name of the currently running pipeline
-            pipeline_run_id: the ID of the currently running pipeline
-            step_name: the name of the currently running step
+            step_run_info: Info about the currently running step.
+            cache_enabled: Whether caching is enabled for the current step run.
         """
         super().__init__()
-        self._pipeline_name = pipeline_name
-        self._pipeline_run_id = pipeline_run_id
-        self._step_name = step_name
+        self._step_run_info = step_run_info
+        self._cache_enabled = cache_enabled
 
     @property
     def pipeline_name(self) -> str:
@@ -64,7 +69,16 @@ class StepEnvironment(BaseEnvironmentComponent):
         Returns:
             The name of the currently running pipeline.
         """
-        return self._pipeline_name
+        return self._step_run_info.pipeline.name
+
+    @property
+    def run_name(self) -> str:
+        """The name of the current pipeline run.
+
+        Returns:
+            The name of the current pipeline run.
+        """
+        return self._step_run_info.run_name
 
     @property
     def pipeline_run_id(self) -> str:
@@ -73,7 +87,11 @@ class StepEnvironment(BaseEnvironmentComponent):
         Returns:
             The ID of the current pipeline run.
         """
-        return self._pipeline_run_id
+        logger.warning(
+            "`StepContext.pipeline_run_id` is deprecated. Use "
+            "`StepContext.run_name` instead."
+        )
+        return self.run_name
 
     @property
     def step_name(self) -> str:
@@ -82,4 +100,22 @@ class StepEnvironment(BaseEnvironmentComponent):
         Returns:
             The name of the currently running step.
         """
-        return self._step_name
+        return self._step_run_info.pipeline_step_name
+
+    @property
+    def step_run_info(self) -> "StepRunInfo":
+        """Info about the currently running step.
+
+        Returns:
+            Info about the currently running step.
+        """
+        return self._step_run_info
+
+    @property
+    def cache_enabled(self) -> bool:
+        """Returns whether cache is enabled for the step.
+
+        Returns:
+            True if cache is enabled for the step, otherwise False.
+        """
+        return self._cache_enabled
