@@ -47,6 +47,9 @@ class AnalyticsEvent(str, Enum):
     UPDATE_REPOSITORY = "Repository updated"
     DELETE_REPOSITORY = "Repository deleted"
 
+    # Template
+    GENERATE_TEMPLATE = "Template generated"
+
     # Zen store
     INITIALIZED_STORE = "Store initialized"
 
@@ -93,12 +96,12 @@ class AnalyticsEvent(str, Enum):
     UPDATED_TEAM = "Team updated"
     DELETED_TEAM = "Team deleted"
 
-    # Projects
-    CREATED_PROJECT = "Project created"
-    CREATED_DEFAULT_PROJECT = "Default project created"
-    UPDATED_PROJECT = "Project updated"
-    DELETED_PROJECT = "Project deleted"
-    SET_PROJECT = "Project set"
+    # Workspaces
+    CREATED_WORKSPACE = "Workspace created"
+    CREATED_DEFAULT_WORKSPACE = "Default workspace created"
+    UPDATED_WORKSPACE = "Workspace updated"
+    DELETED_WORKSPACE = "Workspace deleted"
+    SET_WORKSPACE = "Workspace set"
 
     # Role
     CREATED_ROLE = "Role created"
@@ -111,6 +114,11 @@ class AnalyticsEvent(str, Enum):
     UPDATED_FLAVOR = "Flavor updated"
     DELETED_FLAVOR = "Flavor deleted"
 
+    # Secret
+    CREATED_SECRET = "Secret created"
+    UPDATED_SECRET = "Secret updated"
+    DELETED_SECRET = "Secret deleted"
+
     # Test event
     EVENT_TEST = "Test event"
 
@@ -333,11 +341,17 @@ class AnalyticsContext:
         # infinite loop
         if gc._zen_store is not None:
             zen_store = gc.zen_store
+            user = zen_store.get_user()
+
+            if "client_id" not in properties:
+                properties["client_id"] = self.user_id
+            if "user_id" not in properties:
+                properties["user_id"] = str(user.id)
+
             if (
                 zen_store.type == StoreType.REST
                 and "server_id" not in properties
             ):
-                user = zen_store.active_user
                 server_info = zen_store.get_store_info()
                 properties.update(
                     {
@@ -345,6 +359,9 @@ class AnalyticsContext:
                         "server_id": str(server_info.id),
                         "server_deployment": str(server_info.deployment_type),
                         "database_type": str(server_info.database_type),
+                        "secrets_store_type": str(
+                            server_info.secrets_store_type
+                        ),
                     }
                 )
 
@@ -428,7 +445,7 @@ def track_event(
 def parametrized(
     dec: Callable[..., Callable[..., Any]]
 ) -> Callable[..., Callable[[Callable[..., Any]], Callable[..., Any]]]:
-    """This is a meta-decorator, that is, a decorator for decorators.
+    """A meta-decorator, that is, a decorator for decorators.
 
     As a decorator is a function, it actually works as a regular decorator
     with arguments.
@@ -502,7 +519,7 @@ class AnalyticsTrackedModelMixin(BaseModel):
     tracking metadata.
     """
 
-    ANALYTICS_FIELDS: ClassVar[List[str]]
+    ANALYTICS_FIELDS: ClassVar[List[str]] = []
 
     def get_analytics_metadata(self) -> Dict[str, Any]:
         """Get the analytics metadata for the model.
@@ -551,7 +568,6 @@ def track(
             Result of the function.
         """
         with event_handler(event) as handler:
-
             try:
                 if len(args) and isinstance(args[0], AnalyticsTrackerMixin):
                     handler.tracker = args[0]
@@ -627,10 +643,7 @@ class event_handler(object):
         if type_ is not None:
             self.metadata.update({"event_error_type": type_.__name__})
 
-        try:
-            if self.tracker:
-                self.tracker.track_event(self.event, self.metadata)
-            else:
-                track_event(self.event, self.metadata)
-        except Exception as e:
-            logger.debug(f"Analytics tracking failure: {e}")
+        if self.tracker:
+            self.tracker.track_event(self.event, self.metadata)
+        else:
+            track_event(self.event, self.metadata)
