@@ -15,7 +15,7 @@
 
 import json
 from pathlib import Path
-from typing import Any, Dict
+from typing import Any, Dict, List, Optional, Type, Union
 from uuid import UUID
 
 import yaml
@@ -25,13 +25,15 @@ from zenml.utils import io_utils
 
 
 def write_yaml(
-    file_path: str, contents: Dict[Any, Any], sort_keys: bool = True
+    file_path: str,
+    contents: Union[Dict[Any, Any], List[Any]],
+    sort_keys: bool = True,
 ) -> None:
     """Write contents as YAML format to file_path.
 
     Args:
         file_path: Path to YAML file.
-        contents: Contents of YAML file as dict.
+        contents: Contents of YAML file as dict or list.
         sort_keys: If `True`, keys are sorted alphabetically. If `False`,
             the order in which the keys were inserted into the dict will
             be preserved.
@@ -102,12 +104,31 @@ def is_yaml(file_path: str) -> bool:
     return False
 
 
-def write_json(file_path: str, contents: Dict[str, Any]) -> None:
+def comment_out_yaml(yaml_string: str) -> str:
+    """Comments out a yaml string.
+
+    Args:
+        yaml_string: The yaml string to comment out.
+
+    Returns:
+        The commented out yaml string.
+    """
+    lines = yaml_string.splitlines(keepends=True)
+    lines = ["# " + line for line in lines]
+    return "".join(lines)
+
+
+def write_json(
+    file_path: str,
+    contents: Any,
+    encoder: Optional[Type[json.JSONEncoder]] = None,
+) -> None:
     """Write contents as JSON format to file_path.
 
     Args:
         file_path: Path to JSON file.
-        contents: Contents of JSON file as dict.
+        contents: Contents of JSON file.
+        encoder: Custom JSON encoder to use when saving json.
 
     Raises:
         FileNotFoundError: if directory does not exist.
@@ -117,7 +138,13 @@ def write_json(file_path: str, contents: Dict[str, Any]) -> None:
         if not fileio.isdir(dir_):
             # Check if it is a local path, if it doesn't exist, raise Exception.
             raise FileNotFoundError(f"Directory {dir_} does not exist.")
-    io_utils.write_file_contents_as_string(file_path, json.dumps(contents))
+    io_utils.write_file_contents_as_string(
+        file_path,
+        json.dumps(
+            contents,
+            cls=encoder,
+        ),
+    )
 
 
 def read_json(file_path: str) -> Any:
