@@ -18,16 +18,9 @@ visualizations of steps and pipeline results. The `BaseVisualizer` class is at
 the root of all the other visualizers, including options to view the results of
 pipeline runs, steps and pipelines themselves.
 """
-from zenml.visualizers.base_pipeline_run_visualizer import (
-    BasePipelineRunVisualizer,
-)
-from zenml.visualizers.base_pipeline_visualizer import BasePipelineVisualizer
-from zenml.visualizers.base_step_visualizer import BaseStepVisualizer
+
 from zenml.visualizers.base_visualizer import BaseVisualizer
 
 __all__ = [
     "BaseVisualizer",
-    "BasePipelineVisualizer",
-    "BaseStepVisualizer",
-    "BasePipelineRunVisualizer",
 ]
