@@ -1,18 +1,15 @@
-"""Release [0.30.0].
+"""Release [0.33.0].
 
-Revision ID: 0.30.0
-Revises: 7834208cc3f6
-Create Date: 2022-12-09 15:46:03.980591
+Revision ID: 0.33.0
+Revises: ec0d785ca296
+Create Date: 2023-02-03 14:52:48.563695
 
 """
-import sqlmodel
-from alembic import op
-import sqlalchemy as sa
 
 
 # revision identifiers, used by Alembic.
-revision = '0.30.0'
-down_revision = '7834208cc3f6'
+revision = "0.33.0"
+down_revision = "ec0d785ca296"
 branch_labels = None
 depends_on = None
 
